# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/dataproc/v1/subcluster_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.dataproc.v1 import common_pb2 as yandex_dot_cloud_dot_dataproc_dot_v1_dot_common__pb2
from yandex.cloud.dataproc.v1 import subcluster_pb2 as yandex_dot_cloud_dot_dataproc_dot_v1_dot_subcluster__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/dataproc/v1/subcluster_service.proto',
  package='yandex.cloud.dataproc.v1',
  syntax='proto3',
  serialized_options=b'\n\034yandex.cloud.api.dataproc.v1ZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/dataproc/v1;dataproc',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1yandex/cloud/dataproc/v1/subcluster_service.proto\x12\x18yandex.cloud.dataproc.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a&yandex/cloud/operation/operation.proto\x1a%yandex/cloud/dataproc/v1/common.proto\x1a)yandex/cloud/dataproc/v1/subcluster.proto\x1a\x1dyandex/cloud/validation.proto\x1a yandex/cloud/api/operation.proto\"]\n\x14GetSubclusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12#\n\rsubcluster_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x94\x01\n\x16ListSubclustersRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"m\n\x17ListSubclustersResponse\x12\x39\n\x0bsubclusters\x18\x01 \x03(\x0b\x32$.yandex.cloud.dataproc.v1.Subcluster\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xea\x02\n\x17\x43reateSubclusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x32\n\x04role\x18\x03 \x01(\x0e\x32\x1e.yandex.cloud.dataproc.v1.RoleB\x04\xe8\xc7\x31\x01\x12<\n\tresources\x18\x04 \x01(\x0b\x32#.yandex.cloud.dataproc.v1.ResourcesB\x04\xe8\xc7\x31\x01\x12\x1f\n\tsubnet_id\x18\x05 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12 \n\x0bhosts_count\x18\x06 \x01(\x03\x42\x0b\xe8\xc7\x31\x01\xfa\xc7\x31\x03>=1\x12G\n\x12\x61utoscaling_config\x18\x07 \x01(\x0b\x32+.yandex.cloud.dataproc.v1.AutoscalingConfig\"Y\n\x18\x43reateSubclusterMetadata\x12\x1c\n\ncluster_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1f\n\rsubcluster_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"\x90\x03\n\x17UpdateSubclusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12#\n\rsubcluster_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x36\n\tresources\x18\x04 \x01(\x0b\x32#.yandex.cloud.dataproc.v1.Resources\x12/\n\x04name\x18\x05 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12 \n\x0bhosts_count\x18\x06 \x01(\x03\x42\x0b\xe8\xc7\x31\x01\xfa\xc7\x31\x03>=1\x12)\n\x14\x64\x65\x63ommission_timeout\x18\x07 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-86400\x12G\n\x12\x61utoscaling_config\x18\x08 \x01(\x0b\x32+.yandex.cloud.dataproc.v1.AutoscalingConfig\"Y\n\x18UpdateSubclusterMetadata\x12\x1c\n\ncluster_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1f\n\rsubcluster_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"\x8b\x01\n\x17\x44\x65leteSubclusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12#\n\rsubcluster_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12)\n\x14\x64\x65\x63ommission_timeout\x18\x03 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-86400\"Y\n\x18\x44\x65leteSubclusterMetadata\x12\x1c\n\ncluster_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1f\n\rsubcluster_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=502\xd9\x07\n\x11SubclusterService\x12\xa3\x01\n\x03Get\x12..yandex.cloud.dataproc.v1.GetSubclusterRequest\x1a$.yandex.cloud.dataproc.v1.Subcluster\"F\x82\xd3\xe4\x93\x02@\x12>/dataproc/v1/clusters/{cluster_id}/subclusters/{subcluster_id}\x12\xa3\x01\n\x04List\x12\x30.yandex.cloud.dataproc.v1.ListSubclustersRequest\x1a\x31.yandex.cloud.dataproc.v1.ListSubclustersResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./dataproc/v1/clusters/{cluster_id}/subclusters\x12\xc3\x01\n\x06\x43reate\x12\x31.yandex.cloud.dataproc.v1.CreateSubclusterRequest\x1a!.yandex.cloud.operation.Operation\"c\x82\xd3\xe4\x93\x02\x33\"./dataproc/v1/clusters/{cluster_id}/subclusters:\x01*\xb2\xd2*&\n\x18\x43reateSubclusterMetadata\x12\nSubcluster\x12\xd3\x01\n\x06Update\x12\x31.yandex.cloud.dataproc.v1.UpdateSubclusterRequest\x1a!.yandex.cloud.operation.Operation\"s\x82\xd3\xe4\x93\x02\x43\x32>/dataproc/v1/clusters/{cluster_id}/subclusters/{subcluster_id}:\x01*\xb2\xd2*&\n\x18UpdateSubclusterMetadata\x12\nSubcluster\x12\xdb\x01\n\x06\x44\x65lete\x12\x31.yandex.cloud.dataproc.v1.DeleteSubclusterRequest\x1a!.yandex.cloud.operation.Operation\"{\x82\xd3\xe4\x93\x02@*>/dataproc/v1/clusters/{cluster_id}/subclusters/{subcluster_id}\xb2\xd2*1\n\x18\x44\x65leteSubclusterMetadata\x12\x15google.protobuf.EmptyBe\n\x1cyandex.cloud.api.dataproc.v1ZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/dataproc/v1;dataprocb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_dataproc_dot_v1_dot_common__pb2.DESCRIPTOR,yandex_dot_cloud_dot_dataproc_dot_v1_dot_subcluster__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,])




_GETSUBCLUSTERREQUEST = _descriptor.Descriptor(
  name='GetSubclusterRequest',
  full_name='yandex.cloud.dataproc.v1.GetSubclusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.dataproc.v1.GetSubclusterRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subcluster_id', full_name='yandex.cloud.dataproc.v1.GetSubclusterRequest.subcluster_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=330,
  serialized_end=423,
)


_LISTSUBCLUSTERSREQUEST = _descriptor.Descriptor(
  name='ListSubclustersRequest',
  full_name='yandex.cloud.dataproc.v1.ListSubclustersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.dataproc.v1.ListSubclustersRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.dataproc.v1.ListSubclustersRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.dataproc.v1.ListSubclustersRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.dataproc.v1.ListSubclustersRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=426,
  serialized_end=574,
)


_LISTSUBCLUSTERSRESPONSE = _descriptor.Descriptor(
  name='ListSubclustersResponse',
  full_name='yandex.cloud.dataproc.v1.ListSubclustersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subclusters', full_name='yandex.cloud.dataproc.v1.ListSubclustersResponse.subclusters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.dataproc.v1.ListSubclustersResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=576,
  serialized_end=685,
)


_CREATESUBCLUSTERREQUEST = _descriptor.Descriptor(
  name='CreateSubclusterRequest',
  full_name='yandex.cloud.dataproc.v1.CreateSubclusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.dataproc.v1.CreateSubclusterRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.dataproc.v1.CreateSubclusterRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role', full_name='yandex.cloud.dataproc.v1.CreateSubclusterRequest.role', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.dataproc.v1.CreateSubclusterRequest.resources', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.dataproc.v1.CreateSubclusterRequest.subnet_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hosts_count', full_name='yandex.cloud.dataproc.v1.CreateSubclusterRequest.hosts_count', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\372\3071\003>=1', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='autoscaling_config', full_name='yandex.cloud.dataproc.v1.CreateSubclusterRequest.autoscaling_config', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=688,
  serialized_end=1050,
)


_CREATESUBCLUSTERMETADATA = _descriptor.Descriptor(
  name='CreateSubclusterMetadata',
  full_name='yandex.cloud.dataproc.v1.CreateSubclusterMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.dataproc.v1.CreateSubclusterMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subcluster_id', full_name='yandex.cloud.dataproc.v1.CreateSubclusterMetadata.subcluster_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1052,
  serialized_end=1141,
)


_UPDATESUBCLUSTERREQUEST = _descriptor.Descriptor(
  name='UpdateSubclusterRequest',
  full_name='yandex.cloud.dataproc.v1.UpdateSubclusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.dataproc.v1.UpdateSubclusterRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subcluster_id', full_name='yandex.cloud.dataproc.v1.UpdateSubclusterRequest.subcluster_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.dataproc.v1.UpdateSubclusterRequest.update_mask', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.dataproc.v1.UpdateSubclusterRequest.resources', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.dataproc.v1.UpdateSubclusterRequest.name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hosts_count', full_name='yandex.cloud.dataproc.v1.UpdateSubclusterRequest.hosts_count', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\372\3071\003>=1', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decommission_timeout', full_name='yandex.cloud.dataproc.v1.UpdateSubclusterRequest.decommission_timeout', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0070-86400', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='autoscaling_config', full_name='yandex.cloud.dataproc.v1.UpdateSubclusterRequest.autoscaling_config', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1144,
  serialized_end=1544,
)


_UPDATESUBCLUSTERMETADATA = _descriptor.Descriptor(
  name='UpdateSubclusterMetadata',
  full_name='yandex.cloud.dataproc.v1.UpdateSubclusterMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.dataproc.v1.UpdateSubclusterMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subcluster_id', full_name='yandex.cloud.dataproc.v1.UpdateSubclusterMetadata.subcluster_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1546,
  serialized_end=1635,
)


_DELETESUBCLUSTERREQUEST = _descriptor.Descriptor(
  name='DeleteSubclusterRequest',
  full_name='yandex.cloud.dataproc.v1.DeleteSubclusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.dataproc.v1.DeleteSubclusterRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subcluster_id', full_name='yandex.cloud.dataproc.v1.DeleteSubclusterRequest.subcluster_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decommission_timeout', full_name='yandex.cloud.dataproc.v1.DeleteSubclusterRequest.decommission_timeout', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0070-86400', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1638,
  serialized_end=1777,
)


_DELETESUBCLUSTERMETADATA = _descriptor.Descriptor(
  name='DeleteSubclusterMetadata',
  full_name='yandex.cloud.dataproc.v1.DeleteSubclusterMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.dataproc.v1.DeleteSubclusterMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subcluster_id', full_name='yandex.cloud.dataproc.v1.DeleteSubclusterMetadata.subcluster_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1779,
  serialized_end=1868,
)

_LISTSUBCLUSTERSRESPONSE.fields_by_name['subclusters'].message_type = yandex_dot_cloud_dot_dataproc_dot_v1_dot_subcluster__pb2._SUBCLUSTER
_CREATESUBCLUSTERREQUEST.fields_by_name['role'].enum_type = yandex_dot_cloud_dot_dataproc_dot_v1_dot_subcluster__pb2._ROLE
_CREATESUBCLUSTERREQUEST.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_dataproc_dot_v1_dot_common__pb2._RESOURCES
_CREATESUBCLUSTERREQUEST.fields_by_name['autoscaling_config'].message_type = yandex_dot_cloud_dot_dataproc_dot_v1_dot_subcluster__pb2._AUTOSCALINGCONFIG
_UPDATESUBCLUSTERREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATESUBCLUSTERREQUEST.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_dataproc_dot_v1_dot_common__pb2._RESOURCES
_UPDATESUBCLUSTERREQUEST.fields_by_name['autoscaling_config'].message_type = yandex_dot_cloud_dot_dataproc_dot_v1_dot_subcluster__pb2._AUTOSCALINGCONFIG
DESCRIPTOR.message_types_by_name['GetSubclusterRequest'] = _GETSUBCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['ListSubclustersRequest'] = _LISTSUBCLUSTERSREQUEST
DESCRIPTOR.message_types_by_name['ListSubclustersResponse'] = _LISTSUBCLUSTERSRESPONSE
DESCRIPTOR.message_types_by_name['CreateSubclusterRequest'] = _CREATESUBCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['CreateSubclusterMetadata'] = _CREATESUBCLUSTERMETADATA
DESCRIPTOR.message_types_by_name['UpdateSubclusterRequest'] = _UPDATESUBCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['UpdateSubclusterMetadata'] = _UPDATESUBCLUSTERMETADATA
DESCRIPTOR.message_types_by_name['DeleteSubclusterRequest'] = _DELETESUBCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['DeleteSubclusterMetadata'] = _DELETESUBCLUSTERMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetSubclusterRequest = _reflection.GeneratedProtocolMessageType('GetSubclusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSUBCLUSTERREQUEST,
  '__module__' : 'yandex.cloud.dataproc.v1.subcluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.v1.GetSubclusterRequest)
  })
_sym_db.RegisterMessage(GetSubclusterRequest)

ListSubclustersRequest = _reflection.GeneratedProtocolMessageType('ListSubclustersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSUBCLUSTERSREQUEST,
  '__module__' : 'yandex.cloud.dataproc.v1.subcluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.v1.ListSubclustersRequest)
  })
_sym_db.RegisterMessage(ListSubclustersRequest)

ListSubclustersResponse = _reflection.GeneratedProtocolMessageType('ListSubclustersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSUBCLUSTERSRESPONSE,
  '__module__' : 'yandex.cloud.dataproc.v1.subcluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.v1.ListSubclustersResponse)
  })
_sym_db.RegisterMessage(ListSubclustersResponse)

CreateSubclusterRequest = _reflection.GeneratedProtocolMessageType('CreateSubclusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESUBCLUSTERREQUEST,
  '__module__' : 'yandex.cloud.dataproc.v1.subcluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.v1.CreateSubclusterRequest)
  })
_sym_db.RegisterMessage(CreateSubclusterRequest)

CreateSubclusterMetadata = _reflection.GeneratedProtocolMessageType('CreateSubclusterMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATESUBCLUSTERMETADATA,
  '__module__' : 'yandex.cloud.dataproc.v1.subcluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.v1.CreateSubclusterMetadata)
  })
_sym_db.RegisterMessage(CreateSubclusterMetadata)

UpdateSubclusterRequest = _reflection.GeneratedProtocolMessageType('UpdateSubclusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESUBCLUSTERREQUEST,
  '__module__' : 'yandex.cloud.dataproc.v1.subcluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.v1.UpdateSubclusterRequest)
  })
_sym_db.RegisterMessage(UpdateSubclusterRequest)

UpdateSubclusterMetadata = _reflection.GeneratedProtocolMessageType('UpdateSubclusterMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESUBCLUSTERMETADATA,
  '__module__' : 'yandex.cloud.dataproc.v1.subcluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.v1.UpdateSubclusterMetadata)
  })
_sym_db.RegisterMessage(UpdateSubclusterMetadata)

DeleteSubclusterRequest = _reflection.GeneratedProtocolMessageType('DeleteSubclusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESUBCLUSTERREQUEST,
  '__module__' : 'yandex.cloud.dataproc.v1.subcluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.v1.DeleteSubclusterRequest)
  })
_sym_db.RegisterMessage(DeleteSubclusterRequest)

DeleteSubclusterMetadata = _reflection.GeneratedProtocolMessageType('DeleteSubclusterMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETESUBCLUSTERMETADATA,
  '__module__' : 'yandex.cloud.dataproc.v1.subcluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.v1.DeleteSubclusterMetadata)
  })
_sym_db.RegisterMessage(DeleteSubclusterMetadata)


DESCRIPTOR._options = None
_GETSUBCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
_GETSUBCLUSTERREQUEST.fields_by_name['subcluster_id']._options = None
_LISTSUBCLUSTERSREQUEST.fields_by_name['cluster_id']._options = None
_LISTSUBCLUSTERSREQUEST.fields_by_name['page_size']._options = None
_LISTSUBCLUSTERSREQUEST.fields_by_name['page_token']._options = None
_LISTSUBCLUSTERSREQUEST.fields_by_name['filter']._options = None
_CREATESUBCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
_CREATESUBCLUSTERREQUEST.fields_by_name['name']._options = None
_CREATESUBCLUSTERREQUEST.fields_by_name['role']._options = None
_CREATESUBCLUSTERREQUEST.fields_by_name['resources']._options = None
_CREATESUBCLUSTERREQUEST.fields_by_name['subnet_id']._options = None
_CREATESUBCLUSTERREQUEST.fields_by_name['hosts_count']._options = None
_CREATESUBCLUSTERMETADATA.fields_by_name['cluster_id']._options = None
_CREATESUBCLUSTERMETADATA.fields_by_name['subcluster_id']._options = None
_UPDATESUBCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
_UPDATESUBCLUSTERREQUEST.fields_by_name['subcluster_id']._options = None
_UPDATESUBCLUSTERREQUEST.fields_by_name['name']._options = None
_UPDATESUBCLUSTERREQUEST.fields_by_name['hosts_count']._options = None
_UPDATESUBCLUSTERREQUEST.fields_by_name['decommission_timeout']._options = None
_UPDATESUBCLUSTERMETADATA.fields_by_name['cluster_id']._options = None
_UPDATESUBCLUSTERMETADATA.fields_by_name['subcluster_id']._options = None
_DELETESUBCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
_DELETESUBCLUSTERREQUEST.fields_by_name['subcluster_id']._options = None
_DELETESUBCLUSTERREQUEST.fields_by_name['decommission_timeout']._options = None
_DELETESUBCLUSTERMETADATA.fields_by_name['cluster_id']._options = None
_DELETESUBCLUSTERMETADATA.fields_by_name['subcluster_id']._options = None

_SUBCLUSTERSERVICE = _descriptor.ServiceDescriptor(
  name='SubclusterService',
  full_name='yandex.cloud.dataproc.v1.SubclusterService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1871,
  serialized_end=2856,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.dataproc.v1.SubclusterService.Get',
    index=0,
    containing_service=None,
    input_type=_GETSUBCLUSTERREQUEST,
    output_type=yandex_dot_cloud_dot_dataproc_dot_v1_dot_subcluster__pb2._SUBCLUSTER,
    serialized_options=b'\202\323\344\223\002@\022>/dataproc/v1/clusters/{cluster_id}/subclusters/{subcluster_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.dataproc.v1.SubclusterService.List',
    index=1,
    containing_service=None,
    input_type=_LISTSUBCLUSTERSREQUEST,
    output_type=_LISTSUBCLUSTERSRESPONSE,
    serialized_options=b'\202\323\344\223\0020\022./dataproc/v1/clusters/{cluster_id}/subclusters',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.dataproc.v1.SubclusterService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATESUBCLUSTERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0023\"./dataproc/v1/clusters/{cluster_id}/subclusters:\001*\262\322*&\n\030CreateSubclusterMetadata\022\nSubcluster',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.dataproc.v1.SubclusterService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATESUBCLUSTERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002C2>/dataproc/v1/clusters/{cluster_id}/subclusters/{subcluster_id}:\001*\262\322*&\n\030UpdateSubclusterMetadata\022\nSubcluster',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.dataproc.v1.SubclusterService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETESUBCLUSTERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002@*>/dataproc/v1/clusters/{cluster_id}/subclusters/{subcluster_id}\262\322*1\n\030DeleteSubclusterMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SUBCLUSTERSERVICE)

DESCRIPTOR.services_by_name['SubclusterService'] = _SUBCLUSTERSERVICE

# @@protoc_insertion_point(module_scope)
