# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datatransfer/v1/transfer.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.datatransfer.v1 import endpoint_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/datatransfer/v1/transfer.proto',
  package='yandex.cloud.datatransfer.v1',
  syntax='proto3',
  serialized_options=b'\n yandex.cloud.api.datatransfer.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1;datatransfer',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+yandex/cloud/datatransfer/v1/transfer.proto\x12\x1cyandex.cloud.datatransfer.v1\x1a+yandex/cloud/datatransfer/v1/endpoint.proto\"\xb8\x03\n\x08Transfer\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x42\n\x06labels\x18\x06 \x03(\x0b\x32\x32.yandex.cloud.datatransfer.v1.Transfer.LabelsEntry\x12\x36\n\x06source\x18\x07 \x01(\x0b\x32&.yandex.cloud.datatransfer.v1.Endpoint\x12\x36\n\x06target\x18\x08 \x01(\x0b\x32&.yandex.cloud.datatransfer.v1.Endpoint\x12<\n\x06status\x18\n \x01(\x0e\x32,.yandex.cloud.datatransfer.v1.TransferStatus\x12\x38\n\x04type\x18\x0c \x01(\x0e\x32*.yandex.cloud.datatransfer.v1.TransferType\x12\x0f\n\x07warning\x18\x0f \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01*p\n\x0cTransferType\x12\x1d\n\x19TRANSFER_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16SNAPSHOT_AND_INCREMENT\x10\x01\x12\x11\n\rSNAPSHOT_ONLY\x10\x02\x12\x12\n\x0eINCREMENT_ONLY\x10\x03*\x9b\x01\n\x0eTransferStatus\x12\x1f\n\x1bTRANSFER_STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07\x43REATED\x10\x02\x12\x0b\n\x07RUNNING\x10\x03\x12\x0c\n\x08STOPPING\x10\x04\x12\x0b\n\x07STOPPED\x10\x05\x12\t\n\x05\x45RROR\x10\x06\x12\x10\n\x0cSNAPSHOTTING\x10\x07\x12\x08\n\x04\x44ONE\x10\x08\x42q\n yandex.cloud.api.datatransfer.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1;datatransferb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint__pb2.DESCRIPTOR,])

_TRANSFERTYPE = _descriptor.EnumDescriptor(
  name='TransferType',
  full_name='yandex.cloud.datatransfer.v1.TransferType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TRANSFER_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SNAPSHOT_AND_INCREMENT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SNAPSHOT_ONLY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INCREMENT_ONLY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=565,
  serialized_end=677,
)
_sym_db.RegisterEnumDescriptor(_TRANSFERTYPE)

TransferType = enum_type_wrapper.EnumTypeWrapper(_TRANSFERTYPE)
_TRANSFERSTATUS = _descriptor.EnumDescriptor(
  name='TransferStatus',
  full_name='yandex.cloud.datatransfer.v1.TransferStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TRANSFER_STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOPPING', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOPPED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SNAPSHOTTING', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DONE', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=680,
  serialized_end=835,
)
_sym_db.RegisterEnumDescriptor(_TRANSFERSTATUS)

TransferStatus = enum_type_wrapper.EnumTypeWrapper(_TRANSFERSTATUS)
TRANSFER_TYPE_UNSPECIFIED = 0
SNAPSHOT_AND_INCREMENT = 1
SNAPSHOT_ONLY = 2
INCREMENT_ONLY = 3
TRANSFER_STATUS_UNSPECIFIED = 0
CREATING = 1
CREATED = 2
RUNNING = 3
STOPPING = 4
STOPPED = 5
ERROR = 6
SNAPSHOTTING = 7
DONE = 8



_TRANSFER_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.datatransfer.v1.Transfer.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.datatransfer.v1.Transfer.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.datatransfer.v1.Transfer.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=518,
  serialized_end=563,
)

_TRANSFER = _descriptor.Descriptor(
  name='Transfer',
  full_name='yandex.cloud.datatransfer.v1.Transfer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.datatransfer.v1.Transfer.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.datatransfer.v1.Transfer.folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.datatransfer.v1.Transfer.name', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.datatransfer.v1.Transfer.description', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.datatransfer.v1.Transfer.labels', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='yandex.cloud.datatransfer.v1.Transfer.source', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='yandex.cloud.datatransfer.v1.Transfer.target', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.datatransfer.v1.Transfer.status', index=7,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.datatransfer.v1.Transfer.type', index=8,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='warning', full_name='yandex.cloud.datatransfer.v1.Transfer.warning', index=9,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TRANSFER_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=123,
  serialized_end=563,
)

_TRANSFER_LABELSENTRY.containing_type = _TRANSFER
_TRANSFER.fields_by_name['labels'].message_type = _TRANSFER_LABELSENTRY
_TRANSFER.fields_by_name['source'].message_type = yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint__pb2._ENDPOINT
_TRANSFER.fields_by_name['target'].message_type = yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint__pb2._ENDPOINT
_TRANSFER.fields_by_name['status'].enum_type = _TRANSFERSTATUS
_TRANSFER.fields_by_name['type'].enum_type = _TRANSFERTYPE
DESCRIPTOR.message_types_by_name['Transfer'] = _TRANSFER
DESCRIPTOR.enum_types_by_name['TransferType'] = _TRANSFERTYPE
DESCRIPTOR.enum_types_by_name['TransferStatus'] = _TRANSFERSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Transfer = _reflection.GeneratedProtocolMessageType('Transfer', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFER_LABELSENTRY,
    '__module__' : 'yandex.cloud.datatransfer.v1.transfer_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.Transfer.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _TRANSFER,
  '__module__' : 'yandex.cloud.datatransfer.v1.transfer_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.Transfer)
  })
_sym_db.RegisterMessage(Transfer)
_sym_db.RegisterMessage(Transfer.LabelsEntry)


DESCRIPTOR._options = None
_TRANSFER_LABELSENTRY._options = None
# @@protoc_insertion_point(module_scope)
