# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/agent/v1/monitoring_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/loadtesting/agent/v1/monitoring_service.proto',
  package='yandex.cloud.loadtesting.agent.v1',
  syntax='proto3',
  serialized_options=b'\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agent',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n:yandex/cloud/loadtesting/agent/v1/monitoring_service.proto\x12!yandex.cloud.loadtesting.agent.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\"\xca\x01\n\x10\x41\x64\x64MetricRequest\x12%\n\x13\x63ompute_instance_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1c\n\x06job_id\x18\x03 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x46\n\x06\x63hunks\x18\x04 \x03(\x0b\x32..yandex.cloud.loadtesting.agent.v1.MetricChunkB\x06\x82\xc8\x31\x02>0\x12#\n\x11\x61gent_instance_id\x18\x05 \x01(\tB\x08\x8a\xc8\x31\x04<=50J\x04\x08\x02\x10\x03\"\x8f\x01\n\x0bMetricChunk\x12?\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32).yandex.cloud.loadtesting.agent.v1.MetricB\x06\x82\xc8\x31\x02>0\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\x12\x0f\n\x07\x63omment\x18\x03 \x01(\t\x12\x1b\n\rinstance_host\x18\x04 \x01(\tB\x04\xe8\xc7\x31\x01\"T\n\x06Metric\x12\x19\n\x0bmetric_type\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x19\n\x0bmetric_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x14\n\x0cmetric_value\x18\x03 \x01(\x01\":\n\x11\x41\x64\x64MetricResponse\x12\x17\n\x0fmetric_trail_id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x03\x32\xc8\x01\n\x11MonitoringService\x12\xb2\x01\n\tAddMetric\x12\x33.yandex.cloud.loadtesting.agent.v1.AddMetricRequest\x1a\x34.yandex.cloud.loadtesting.agent.v1.AddMetricResponse\":\x82\xd3\xe4\x93\x02\x34\"//loadtesting/agent/v1/monitorings/reportMetrics:\x01*Bt\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agentb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_ADDMETRICREQUEST = _descriptor.Descriptor(
  name='AddMetricRequest',
  full_name='yandex.cloud.loadtesting.agent.v1.AddMetricRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='compute_instance_id', full_name='yandex.cloud.loadtesting.agent.v1.AddMetricRequest.compute_instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_id', full_name='yandex.cloud.loadtesting.agent.v1.AddMetricRequest.job_id', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chunks', full_name='yandex.cloud.loadtesting.agent.v1.AddMetricRequest.chunks', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='agent_instance_id', full_name='yandex.cloud.loadtesting.agent.v1.AddMetricRequest.agent_instance_id', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=159,
  serialized_end=361,
)


_METRICCHUNK = _descriptor.Descriptor(
  name='MetricChunk',
  full_name='yandex.cloud.loadtesting.agent.v1.MetricChunk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='yandex.cloud.loadtesting.agent.v1.MetricChunk.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='yandex.cloud.loadtesting.agent.v1.MetricChunk.timestamp', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='comment', full_name='yandex.cloud.loadtesting.agent.v1.MetricChunk.comment', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instance_host', full_name='yandex.cloud.loadtesting.agent.v1.MetricChunk.instance_host', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=364,
  serialized_end=507,
)


_METRIC = _descriptor.Descriptor(
  name='Metric',
  full_name='yandex.cloud.loadtesting.agent.v1.Metric',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metric_type', full_name='yandex.cloud.loadtesting.agent.v1.Metric.metric_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_name', full_name='yandex.cloud.loadtesting.agent.v1.Metric.metric_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_value', full_name='yandex.cloud.loadtesting.agent.v1.Metric.metric_value', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=509,
  serialized_end=593,
)


_ADDMETRICRESPONSE = _descriptor.Descriptor(
  name='AddMetricResponse',
  full_name='yandex.cloud.loadtesting.agent.v1.AddMetricResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metric_trail_id', full_name='yandex.cloud.loadtesting.agent.v1.AddMetricResponse.metric_trail_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='yandex.cloud.loadtesting.agent.v1.AddMetricResponse.code', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=595,
  serialized_end=653,
)

_ADDMETRICREQUEST.fields_by_name['chunks'].message_type = _METRICCHUNK
_METRICCHUNK.fields_by_name['data'].message_type = _METRIC
DESCRIPTOR.message_types_by_name['AddMetricRequest'] = _ADDMETRICREQUEST
DESCRIPTOR.message_types_by_name['MetricChunk'] = _METRICCHUNK
DESCRIPTOR.message_types_by_name['Metric'] = _METRIC
DESCRIPTOR.message_types_by_name['AddMetricResponse'] = _ADDMETRICRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AddMetricRequest = _reflection.GeneratedProtocolMessageType('AddMetricRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDMETRICREQUEST,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.monitoring_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.AddMetricRequest)
  })
_sym_db.RegisterMessage(AddMetricRequest)

MetricChunk = _reflection.GeneratedProtocolMessageType('MetricChunk', (_message.Message,), {
  'DESCRIPTOR' : _METRICCHUNK,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.monitoring_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.MetricChunk)
  })
_sym_db.RegisterMessage(MetricChunk)

Metric = _reflection.GeneratedProtocolMessageType('Metric', (_message.Message,), {
  'DESCRIPTOR' : _METRIC,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.monitoring_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.Metric)
  })
_sym_db.RegisterMessage(Metric)

AddMetricResponse = _reflection.GeneratedProtocolMessageType('AddMetricResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADDMETRICRESPONSE,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.monitoring_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.AddMetricResponse)
  })
_sym_db.RegisterMessage(AddMetricResponse)


DESCRIPTOR._options = None
_ADDMETRICREQUEST.fields_by_name['compute_instance_id']._options = None
_ADDMETRICREQUEST.fields_by_name['job_id']._options = None
_ADDMETRICREQUEST.fields_by_name['chunks']._options = None
_ADDMETRICREQUEST.fields_by_name['agent_instance_id']._options = None
_METRICCHUNK.fields_by_name['data']._options = None
_METRICCHUNK.fields_by_name['instance_host']._options = None
_METRIC.fields_by_name['metric_type']._options = None
_METRIC.fields_by_name['metric_name']._options = None

_MONITORINGSERVICE = _descriptor.ServiceDescriptor(
  name='MonitoringService',
  full_name='yandex.cloud.loadtesting.agent.v1.MonitoringService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=656,
  serialized_end=856,
  methods=[
  _descriptor.MethodDescriptor(
    name='AddMetric',
    full_name='yandex.cloud.loadtesting.agent.v1.MonitoringService.AddMetric',
    index=0,
    containing_service=None,
    input_type=_ADDMETRICREQUEST,
    output_type=_ADDMETRICRESPONSE,
    serialized_options=b'\202\323\344\223\0024\"//loadtesting/agent/v1/monitorings/reportMetrics:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MONITORINGSERVICE)

DESCRIPTOR.services_by_name['MonitoringService'] = _MONITORINGSERVICE

# @@protoc_insertion_point(module_scope)
