# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/agent/v1/trail_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/loadtesting/agent/v1/trail_service.proto',
  package='yandex.cloud.loadtesting.agent.v1',
  syntax='proto3',
  serialized_options=b'\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agent',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n5yandex/cloud/loadtesting/agent/v1/trail_service.proto\x12!yandex.cloud.loadtesting.agent.v1\x1a\x1cgoogle/api/annotations.proto\"\x94\x01\n\x12\x43reateTrailRequest\x12\x1b\n\x13\x63ompute_instance_id\x18\x01 \x01(\t\x12\x36\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32(.yandex.cloud.loadtesting.agent.v1.Trail\x12\x0e\n\x06job_id\x18\x03 \x01(\t\x12\x19\n\x11\x61gent_instance_id\x18\x04 \x01(\t\"\xfc\x04\n\x05Trail\x12\x0f\n\x07overall\x18\x01 \x01(\x03\x12\x0f\n\x07\x63\x61se_id\x18\x02 \x01(\t\x12\x0c\n\x04time\x18\x03 \x01(\t\x12\r\n\x05reqps\x18\x04 \x01(\x03\x12\r\n\x05resps\x18\x05 \x01(\x03\x12\x0e\n\x06\x65xpect\x18\x06 \x01(\x01\x12\r\n\x05input\x18\x07 \x01(\x03\x12\x0e\n\x06output\x18\x08 \x01(\x03\x12\x14\n\x0c\x63onnect_time\x18\t \x01(\x01\x12\x11\n\tsend_time\x18\n \x01(\x01\x12\x0f\n\x07latency\x18\x0b \x01(\x01\x12\x14\n\x0creceive_time\x18\x0c \x01(\x01\x12\x0f\n\x07threads\x18\r \x01(\x03\x12\x0b\n\x03q50\x18\x0e \x01(\x01\x12\x0b\n\x03q75\x18\x0f \x01(\x01\x12\x0b\n\x03q80\x18\x10 \x01(\x01\x12\x0b\n\x03q85\x18\x11 \x01(\x01\x12\x0b\n\x03q90\x18\x12 \x01(\x01\x12\x0b\n\x03q95\x18\x13 \x01(\x01\x12\x0b\n\x03q98\x18\x14 \x01(\x01\x12\x0b\n\x03q99\x18\x15 \x01(\x01\x12\x0c\n\x04q100\x18\x16 \x01(\x01\x12\x42\n\nhttp_codes\x18\x17 \x03(\x0b\x32..yandex.cloud.loadtesting.agent.v1.Trail.Codes\x12\x41\n\tnet_codes\x18\x18 \x03(\x0b\x32..yandex.cloud.loadtesting.agent.v1.Trail.Codes\x12J\n\x0etime_intervals\x18\x19 \x03(\x0b\x32\x32.yandex.cloud.loadtesting.agent.v1.Trail.Intervals\x1a$\n\x05\x43odes\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x03\x12\r\n\x05\x63ount\x18\x02 \x01(\x03\x1a&\n\tIntervals\x12\n\n\x02to\x18\x01 \x01(\x01\x12\r\n\x05\x63ount\x18\x02 \x01(\x03\"5\n\x13\x43reateTrailResponse\x12\x10\n\x08trail_id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x03\x32\xb1\x01\n\x0cTrailService\x12\xa0\x01\n\x06\x43reate\x12\x35.yandex.cloud.loadtesting.agent.v1.CreateTrailRequest\x1a\x36.yandex.cloud.loadtesting.agent.v1.CreateTrailResponse\"\'\x82\xd3\xe4\x93\x02!\"\x1c/loadtesting/agent/v1/trails:\x01*Bt\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agentb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_CREATETRAILREQUEST = _descriptor.Descriptor(
  name='CreateTrailRequest',
  full_name='yandex.cloud.loadtesting.agent.v1.CreateTrailRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='compute_instance_id', full_name='yandex.cloud.loadtesting.agent.v1.CreateTrailRequest.compute_instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='yandex.cloud.loadtesting.agent.v1.CreateTrailRequest.data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_id', full_name='yandex.cloud.loadtesting.agent.v1.CreateTrailRequest.job_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='agent_instance_id', full_name='yandex.cloud.loadtesting.agent.v1.CreateTrailRequest.agent_instance_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=123,
  serialized_end=271,
)


_TRAIL_CODES = _descriptor.Descriptor(
  name='Codes',
  full_name='yandex.cloud.loadtesting.agent.v1.Trail.Codes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='yandex.cloud.loadtesting.agent.v1.Trail.Codes.code', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='yandex.cloud.loadtesting.agent.v1.Trail.Codes.count', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=834,
  serialized_end=870,
)

_TRAIL_INTERVALS = _descriptor.Descriptor(
  name='Intervals',
  full_name='yandex.cloud.loadtesting.agent.v1.Trail.Intervals',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='to', full_name='yandex.cloud.loadtesting.agent.v1.Trail.Intervals.to', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='yandex.cloud.loadtesting.agent.v1.Trail.Intervals.count', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=872,
  serialized_end=910,
)

_TRAIL = _descriptor.Descriptor(
  name='Trail',
  full_name='yandex.cloud.loadtesting.agent.v1.Trail',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='overall', full_name='yandex.cloud.loadtesting.agent.v1.Trail.overall', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='case_id', full_name='yandex.cloud.loadtesting.agent.v1.Trail.case_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='yandex.cloud.loadtesting.agent.v1.Trail.time', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reqps', full_name='yandex.cloud.loadtesting.agent.v1.Trail.reqps', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resps', full_name='yandex.cloud.loadtesting.agent.v1.Trail.resps', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expect', full_name='yandex.cloud.loadtesting.agent.v1.Trail.expect', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input', full_name='yandex.cloud.loadtesting.agent.v1.Trail.input', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output', full_name='yandex.cloud.loadtesting.agent.v1.Trail.output', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connect_time', full_name='yandex.cloud.loadtesting.agent.v1.Trail.connect_time', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='send_time', full_name='yandex.cloud.loadtesting.agent.v1.Trail.send_time', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latency', full_name='yandex.cloud.loadtesting.agent.v1.Trail.latency', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receive_time', full_name='yandex.cloud.loadtesting.agent.v1.Trail.receive_time', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='threads', full_name='yandex.cloud.loadtesting.agent.v1.Trail.threads', index=12,
      number=13, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='q50', full_name='yandex.cloud.loadtesting.agent.v1.Trail.q50', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='q75', full_name='yandex.cloud.loadtesting.agent.v1.Trail.q75', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='q80', full_name='yandex.cloud.loadtesting.agent.v1.Trail.q80', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='q85', full_name='yandex.cloud.loadtesting.agent.v1.Trail.q85', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='q90', full_name='yandex.cloud.loadtesting.agent.v1.Trail.q90', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='q95', full_name='yandex.cloud.loadtesting.agent.v1.Trail.q95', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='q98', full_name='yandex.cloud.loadtesting.agent.v1.Trail.q98', index=19,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='q99', full_name='yandex.cloud.loadtesting.agent.v1.Trail.q99', index=20,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='q100', full_name='yandex.cloud.loadtesting.agent.v1.Trail.q100', index=21,
      number=22, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_codes', full_name='yandex.cloud.loadtesting.agent.v1.Trail.http_codes', index=22,
      number=23, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='net_codes', full_name='yandex.cloud.loadtesting.agent.v1.Trail.net_codes', index=23,
      number=24, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_intervals', full_name='yandex.cloud.loadtesting.agent.v1.Trail.time_intervals', index=24,
      number=25, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TRAIL_CODES, _TRAIL_INTERVALS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=274,
  serialized_end=910,
)


_CREATETRAILRESPONSE = _descriptor.Descriptor(
  name='CreateTrailResponse',
  full_name='yandex.cloud.loadtesting.agent.v1.CreateTrailResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trail_id', full_name='yandex.cloud.loadtesting.agent.v1.CreateTrailResponse.trail_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='yandex.cloud.loadtesting.agent.v1.CreateTrailResponse.code', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=912,
  serialized_end=965,
)

_CREATETRAILREQUEST.fields_by_name['data'].message_type = _TRAIL
_TRAIL_CODES.containing_type = _TRAIL
_TRAIL_INTERVALS.containing_type = _TRAIL
_TRAIL.fields_by_name['http_codes'].message_type = _TRAIL_CODES
_TRAIL.fields_by_name['net_codes'].message_type = _TRAIL_CODES
_TRAIL.fields_by_name['time_intervals'].message_type = _TRAIL_INTERVALS
DESCRIPTOR.message_types_by_name['CreateTrailRequest'] = _CREATETRAILREQUEST
DESCRIPTOR.message_types_by_name['Trail'] = _TRAIL
DESCRIPTOR.message_types_by_name['CreateTrailResponse'] = _CREATETRAILRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateTrailRequest = _reflection.GeneratedProtocolMessageType('CreateTrailRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATETRAILREQUEST,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.trail_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.CreateTrailRequest)
  })
_sym_db.RegisterMessage(CreateTrailRequest)

Trail = _reflection.GeneratedProtocolMessageType('Trail', (_message.Message,), {

  'Codes' : _reflection.GeneratedProtocolMessageType('Codes', (_message.Message,), {
    'DESCRIPTOR' : _TRAIL_CODES,
    '__module__' : 'yandex.cloud.loadtesting.agent.v1.trail_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.Trail.Codes)
    })
  ,

  'Intervals' : _reflection.GeneratedProtocolMessageType('Intervals', (_message.Message,), {
    'DESCRIPTOR' : _TRAIL_INTERVALS,
    '__module__' : 'yandex.cloud.loadtesting.agent.v1.trail_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.Trail.Intervals)
    })
  ,
  'DESCRIPTOR' : _TRAIL,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.trail_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.Trail)
  })
_sym_db.RegisterMessage(Trail)
_sym_db.RegisterMessage(Trail.Codes)
_sym_db.RegisterMessage(Trail.Intervals)

CreateTrailResponse = _reflection.GeneratedProtocolMessageType('CreateTrailResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATETRAILRESPONSE,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.trail_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.CreateTrailResponse)
  })
_sym_db.RegisterMessage(CreateTrailResponse)


DESCRIPTOR._options = None

_TRAILSERVICE = _descriptor.ServiceDescriptor(
  name='TrailService',
  full_name='yandex.cloud.loadtesting.agent.v1.TrailService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=968,
  serialized_end=1145,
  methods=[
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.loadtesting.agent.v1.TrailService.Create',
    index=0,
    containing_service=None,
    input_type=_CREATETRAILREQUEST,
    output_type=_CREATETRAILRESPONSE,
    serialized_options=b'\202\323\344\223\002!\"\034/loadtesting/agent/v1/trails:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TRAILSERVICE)

DESCRIPTOR.services_by_name['TrailService'] = _TRAILSERVICE

# @@protoc_insertion_point(module_scope)
