# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/vpc/v1/network_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.vpc.v1 import network_pb2 as yandex_dot_cloud_dot_vpc_dot_v1_dot_network__pb2
from yandex.cloud.vpc.v1 import subnet_pb2 as yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__pb2
from yandex.cloud.vpc.v1 import security_group_pb2 as yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__pb2
from yandex.cloud.vpc.v1 import route_table_pb2 as yandex_dot_cloud_dot_vpc_dot_v1_dot_route__table__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/vpc/v1/network_service.proto',
  package='yandex.cloud.vpc.v1',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.vpc.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1;vpc',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)yandex/cloud/vpc/v1/network_service.proto\x12\x13yandex.cloud.vpc.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a!yandex/cloud/vpc/v1/network.proto\x1a yandex/cloud/vpc/v1/subnet.proto\x1a(yandex/cloud/vpc/v1/security_group.proto\x1a%yandex/cloud/vpc/v1/route_table.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"5\n\x11GetNetworkRequest\x12 \n\nnetwork_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x90\x01\n\x13ListNetworksRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"_\n\x14ListNetworksResponse\x12.\n\x08networks\x18\x01 \x03(\x0b\x32\x1c.yandex.cloud.vpc.v1.Network\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xc0\x02\n\x14\x43reateNetworkRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x86\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x35.yandex.cloud.vpc.v1.CreateNetworkRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15\x43reateNetworkMetadata\x12\x12\n\nnetwork_id\x18\x01 \x01(\t\"\xf2\x02\n\x14UpdateNetworkRequest\x12 \n\nnetwork_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x86\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x35.yandex.cloud.vpc.v1.UpdateNetworkRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15UpdateNetworkMetadata\x12\x12\n\nnetwork_id\x18\x01 \x01(\t\"8\n\x14\x44\x65leteNetworkRequest\x12 \n\nnetwork_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x44\x65leteNetworkMetadata\x12\x12\n\nnetwork_id\x18\x01 \x01(\t\"{\n\x19ListNetworkSubnetsRequest\x12 \n\nnetwork_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"c\n\x1aListNetworkSubnetsResponse\x12,\n\x07subnets\x18\x01 \x03(\x0b\x32\x1b.yandex.cloud.vpc.v1.Subnet\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x82\x01\n ListNetworkSecurityGroupsRequest\x12 \n\nnetwork_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"y\n!ListNetworkSecurityGroupsResponse\x12;\n\x0fsecurity_groups\x18\x01 \x03(\x0b\x32\".yandex.cloud.vpc.v1.SecurityGroup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x7f\n\x1dListNetworkRouteTablesRequest\x12 \n\nnetwork_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"p\n\x1eListNetworkRouteTablesResponse\x12\x35\n\x0croute_tables\x18\x01 \x03(\x0b\x32\x1f.yandex.cloud.vpc.v1.RouteTable\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"~\n\x1cListNetworkOperationsRequest\x12 \n\nnetwork_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"o\n\x1dListNetworkOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"c\n\x12MoveNetworkRequest\x12 \n\nnetwork_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x13MoveNetworkMetadata\x12\x12\n\nnetwork_id\x18\x01 \x01(\t2\xce\x0c\n\x0eNetworkService\x12r\n\x03Get\x12&.yandex.cloud.vpc.v1.GetNetworkRequest\x1a\x1c.yandex.cloud.vpc.v1.Network\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/vpc/v1/networks/{network_id}\x12u\n\x04List\x12(.yandex.cloud.vpc.v1.ListNetworksRequest\x1a).yandex.cloud.vpc.v1.ListNetworksResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/vpc/v1/networks\x12\x97\x01\n\x06\x43reate\x12).yandex.cloud.vpc.v1.CreateNetworkRequest\x1a!.yandex.cloud.operation.Operation\"?\x82\xd3\xe4\x93\x02\x15\"\x10/vpc/v1/networks:\x01*\xb2\xd2* \n\x15\x43reateNetworkMetadata\x12\x07Network\x12\xa4\x01\n\x06Update\x12).yandex.cloud.vpc.v1.UpdateNetworkRequest\x1a!.yandex.cloud.operation.Operation\"L\x82\xd3\xe4\x93\x02\"2\x1d/vpc/v1/networks/{network_id}:\x01*\xb2\xd2* \n\x15UpdateNetworkMetadata\x12\x07Network\x12\xaf\x01\n\x06\x44\x65lete\x12).yandex.cloud.vpc.v1.DeleteNetworkRequest\x1a!.yandex.cloud.operation.Operation\"W\x82\xd3\xe4\x93\x02\x1f*\x1d/vpc/v1/networks/{network_id}\xb2\xd2*.\n\x15\x44\x65leteNetworkMetadata\x12\x15google.protobuf.Empty\x12\x9d\x01\n\x0bListSubnets\x12..yandex.cloud.vpc.v1.ListNetworkSubnetsRequest\x1a/.yandex.cloud.vpc.v1.ListNetworkSubnetsResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/vpc/v1/networks/{network_id}/subnets\x12\xba\x01\n\x12ListSecurityGroups\x12\x35.yandex.cloud.vpc.v1.ListNetworkSecurityGroupsRequest\x1a\x36.yandex.cloud.vpc.v1.ListNetworkSecurityGroupsResponse\"5\x82\xd3\xe4\x93\x02/\x12-/vpc/v1/networks/{network_id}/security_groups\x12\xae\x01\n\x0fListRouteTables\x12\x32.yandex.cloud.vpc.v1.ListNetworkRouteTablesRequest\x1a\x33.yandex.cloud.vpc.v1.ListNetworkRouteTablesResponse\"2\x82\xd3\xe4\x93\x02,\x12*/vpc/v1/networks/{network_id}/route_tables\x12\xa9\x01\n\x0eListOperations\x12\x31.yandex.cloud.vpc.v1.ListNetworkOperationsRequest\x1a\x32.yandex.cloud.vpc.v1.ListNetworkOperationsResponse\"0\x82\xd3\xe4\x93\x02*\x12(/vpc/v1/networks/{network_id}/operations\x12\xa3\x01\n\x04Move\x12\'.yandex.cloud.vpc.v1.MoveNetworkRequest\x1a!.yandex.cloud.operation.Operation\"O\x82\xd3\xe4\x93\x02\'\"\"/vpc/v1/networks/{network_id}:move:\x01*\xb2\xd2*\x1e\n\x13MoveNetworkMetadata\x12\x07NetworkBV\n\x17yandex.cloud.api.vpc.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1;vpcb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_vpc_dot_v1_dot_network__pb2.DESCRIPTOR,yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__pb2.DESCRIPTOR,yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__pb2.DESCRIPTOR,yandex_dot_cloud_dot_vpc_dot_v1_dot_route__table__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETNETWORKREQUEST = _descriptor.Descriptor(
  name='GetNetworkRequest',
  full_name='yandex.cloud.vpc.v1.GetNetworkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='network_id', full_name='yandex.cloud.vpc.v1.GetNetworkRequest.network_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=385,
  serialized_end=438,
)


_LISTNETWORKSREQUEST = _descriptor.Descriptor(
  name='ListNetworksRequest',
  full_name='yandex.cloud.vpc.v1.ListNetworksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.vpc.v1.ListNetworksRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.vpc.v1.ListNetworksRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.vpc.v1.ListNetworksRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.vpc.v1.ListNetworksRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=441,
  serialized_end=585,
)


_LISTNETWORKSRESPONSE = _descriptor.Descriptor(
  name='ListNetworksResponse',
  full_name='yandex.cloud.vpc.v1.ListNetworksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='networks', full_name='yandex.cloud.vpc.v1.ListNetworksResponse.networks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.vpc.v1.ListNetworksResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=587,
  serialized_end=682,
)


_CREATENETWORKREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.vpc.v1.CreateNetworkRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.vpc.v1.CreateNetworkRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.vpc.v1.CreateNetworkRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=960,
  serialized_end=1005,
)

_CREATENETWORKREQUEST = _descriptor.Descriptor(
  name='CreateNetworkRequest',
  full_name='yandex.cloud.vpc.v1.CreateNetworkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.vpc.v1.CreateNetworkRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.vpc.v1.CreateNetworkRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.vpc.v1.CreateNetworkRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.vpc.v1.CreateNetworkRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATENETWORKREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=685,
  serialized_end=1005,
)


_CREATENETWORKMETADATA = _descriptor.Descriptor(
  name='CreateNetworkMetadata',
  full_name='yandex.cloud.vpc.v1.CreateNetworkMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='network_id', full_name='yandex.cloud.vpc.v1.CreateNetworkMetadata.network_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1007,
  serialized_end=1050,
)


_UPDATENETWORKREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.vpc.v1.UpdateNetworkRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.vpc.v1.UpdateNetworkRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.vpc.v1.UpdateNetworkRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=960,
  serialized_end=1005,
)

_UPDATENETWORKREQUEST = _descriptor.Descriptor(
  name='UpdateNetworkRequest',
  full_name='yandex.cloud.vpc.v1.UpdateNetworkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='network_id', full_name='yandex.cloud.vpc.v1.UpdateNetworkRequest.network_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.vpc.v1.UpdateNetworkRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.vpc.v1.UpdateNetworkRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.vpc.v1.UpdateNetworkRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.vpc.v1.UpdateNetworkRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATENETWORKREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1053,
  serialized_end=1423,
)


_UPDATENETWORKMETADATA = _descriptor.Descriptor(
  name='UpdateNetworkMetadata',
  full_name='yandex.cloud.vpc.v1.UpdateNetworkMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='network_id', full_name='yandex.cloud.vpc.v1.UpdateNetworkMetadata.network_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1425,
  serialized_end=1468,
)


_DELETENETWORKREQUEST = _descriptor.Descriptor(
  name='DeleteNetworkRequest',
  full_name='yandex.cloud.vpc.v1.DeleteNetworkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='network_id', full_name='yandex.cloud.vpc.v1.DeleteNetworkRequest.network_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1470,
  serialized_end=1526,
)


_DELETENETWORKMETADATA = _descriptor.Descriptor(
  name='DeleteNetworkMetadata',
  full_name='yandex.cloud.vpc.v1.DeleteNetworkMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='network_id', full_name='yandex.cloud.vpc.v1.DeleteNetworkMetadata.network_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1528,
  serialized_end=1571,
)


_LISTNETWORKSUBNETSREQUEST = _descriptor.Descriptor(
  name='ListNetworkSubnetsRequest',
  full_name='yandex.cloud.vpc.v1.ListNetworkSubnetsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='network_id', full_name='yandex.cloud.vpc.v1.ListNetworkSubnetsRequest.network_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.vpc.v1.ListNetworkSubnetsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.vpc.v1.ListNetworkSubnetsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1573,
  serialized_end=1696,
)


_LISTNETWORKSUBNETSRESPONSE = _descriptor.Descriptor(
  name='ListNetworkSubnetsResponse',
  full_name='yandex.cloud.vpc.v1.ListNetworkSubnetsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subnets', full_name='yandex.cloud.vpc.v1.ListNetworkSubnetsResponse.subnets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.vpc.v1.ListNetworkSubnetsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1698,
  serialized_end=1797,
)


_LISTNETWORKSECURITYGROUPSREQUEST = _descriptor.Descriptor(
  name='ListNetworkSecurityGroupsRequest',
  full_name='yandex.cloud.vpc.v1.ListNetworkSecurityGroupsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='network_id', full_name='yandex.cloud.vpc.v1.ListNetworkSecurityGroupsRequest.network_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.vpc.v1.ListNetworkSecurityGroupsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.vpc.v1.ListNetworkSecurityGroupsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1800,
  serialized_end=1930,
)


_LISTNETWORKSECURITYGROUPSRESPONSE = _descriptor.Descriptor(
  name='ListNetworkSecurityGroupsResponse',
  full_name='yandex.cloud.vpc.v1.ListNetworkSecurityGroupsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='security_groups', full_name='yandex.cloud.vpc.v1.ListNetworkSecurityGroupsResponse.security_groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.vpc.v1.ListNetworkSecurityGroupsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1932,
  serialized_end=2053,
)


_LISTNETWORKROUTETABLESREQUEST = _descriptor.Descriptor(
  name='ListNetworkRouteTablesRequest',
  full_name='yandex.cloud.vpc.v1.ListNetworkRouteTablesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='network_id', full_name='yandex.cloud.vpc.v1.ListNetworkRouteTablesRequest.network_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.vpc.v1.ListNetworkRouteTablesRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.vpc.v1.ListNetworkRouteTablesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2055,
  serialized_end=2182,
)


_LISTNETWORKROUTETABLESRESPONSE = _descriptor.Descriptor(
  name='ListNetworkRouteTablesResponse',
  full_name='yandex.cloud.vpc.v1.ListNetworkRouteTablesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='route_tables', full_name='yandex.cloud.vpc.v1.ListNetworkRouteTablesResponse.route_tables', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.vpc.v1.ListNetworkRouteTablesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2184,
  serialized_end=2296,
)


_LISTNETWORKOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListNetworkOperationsRequest',
  full_name='yandex.cloud.vpc.v1.ListNetworkOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='network_id', full_name='yandex.cloud.vpc.v1.ListNetworkOperationsRequest.network_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.vpc.v1.ListNetworkOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.vpc.v1.ListNetworkOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2298,
  serialized_end=2424,
)


_LISTNETWORKOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListNetworkOperationsResponse',
  full_name='yandex.cloud.vpc.v1.ListNetworkOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.vpc.v1.ListNetworkOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.vpc.v1.ListNetworkOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2426,
  serialized_end=2537,
)


_MOVENETWORKREQUEST = _descriptor.Descriptor(
  name='MoveNetworkRequest',
  full_name='yandex.cloud.vpc.v1.MoveNetworkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='network_id', full_name='yandex.cloud.vpc.v1.MoveNetworkRequest.network_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_folder_id', full_name='yandex.cloud.vpc.v1.MoveNetworkRequest.destination_folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2539,
  serialized_end=2638,
)


_MOVENETWORKMETADATA = _descriptor.Descriptor(
  name='MoveNetworkMetadata',
  full_name='yandex.cloud.vpc.v1.MoveNetworkMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='network_id', full_name='yandex.cloud.vpc.v1.MoveNetworkMetadata.network_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2640,
  serialized_end=2681,
)

_LISTNETWORKSRESPONSE.fields_by_name['networks'].message_type = yandex_dot_cloud_dot_vpc_dot_v1_dot_network__pb2._NETWORK
_CREATENETWORKREQUEST_LABELSENTRY.containing_type = _CREATENETWORKREQUEST
_CREATENETWORKREQUEST.fields_by_name['labels'].message_type = _CREATENETWORKREQUEST_LABELSENTRY
_UPDATENETWORKREQUEST_LABELSENTRY.containing_type = _UPDATENETWORKREQUEST
_UPDATENETWORKREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATENETWORKREQUEST.fields_by_name['labels'].message_type = _UPDATENETWORKREQUEST_LABELSENTRY
_LISTNETWORKSUBNETSRESPONSE.fields_by_name['subnets'].message_type = yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__pb2._SUBNET
_LISTNETWORKSECURITYGROUPSRESPONSE.fields_by_name['security_groups'].message_type = yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__pb2._SECURITYGROUP
_LISTNETWORKROUTETABLESRESPONSE.fields_by_name['route_tables'].message_type = yandex_dot_cloud_dot_vpc_dot_v1_dot_route__table__pb2._ROUTETABLE
_LISTNETWORKOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['GetNetworkRequest'] = _GETNETWORKREQUEST
DESCRIPTOR.message_types_by_name['ListNetworksRequest'] = _LISTNETWORKSREQUEST
DESCRIPTOR.message_types_by_name['ListNetworksResponse'] = _LISTNETWORKSRESPONSE
DESCRIPTOR.message_types_by_name['CreateNetworkRequest'] = _CREATENETWORKREQUEST
DESCRIPTOR.message_types_by_name['CreateNetworkMetadata'] = _CREATENETWORKMETADATA
DESCRIPTOR.message_types_by_name['UpdateNetworkRequest'] = _UPDATENETWORKREQUEST
DESCRIPTOR.message_types_by_name['UpdateNetworkMetadata'] = _UPDATENETWORKMETADATA
DESCRIPTOR.message_types_by_name['DeleteNetworkRequest'] = _DELETENETWORKREQUEST
DESCRIPTOR.message_types_by_name['DeleteNetworkMetadata'] = _DELETENETWORKMETADATA
DESCRIPTOR.message_types_by_name['ListNetworkSubnetsRequest'] = _LISTNETWORKSUBNETSREQUEST
DESCRIPTOR.message_types_by_name['ListNetworkSubnetsResponse'] = _LISTNETWORKSUBNETSRESPONSE
DESCRIPTOR.message_types_by_name['ListNetworkSecurityGroupsRequest'] = _LISTNETWORKSECURITYGROUPSREQUEST
DESCRIPTOR.message_types_by_name['ListNetworkSecurityGroupsResponse'] = _LISTNETWORKSECURITYGROUPSRESPONSE
DESCRIPTOR.message_types_by_name['ListNetworkRouteTablesRequest'] = _LISTNETWORKROUTETABLESREQUEST
DESCRIPTOR.message_types_by_name['ListNetworkRouteTablesResponse'] = _LISTNETWORKROUTETABLESRESPONSE
DESCRIPTOR.message_types_by_name['ListNetworkOperationsRequest'] = _LISTNETWORKOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListNetworkOperationsResponse'] = _LISTNETWORKOPERATIONSRESPONSE
DESCRIPTOR.message_types_by_name['MoveNetworkRequest'] = _MOVENETWORKREQUEST
DESCRIPTOR.message_types_by_name['MoveNetworkMetadata'] = _MOVENETWORKMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetNetworkRequest = _reflection.GeneratedProtocolMessageType('GetNetworkRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNETWORKREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.network_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.GetNetworkRequest)
  })
_sym_db.RegisterMessage(GetNetworkRequest)

ListNetworksRequest = _reflection.GeneratedProtocolMessageType('ListNetworksRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTNETWORKSREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.network_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.ListNetworksRequest)
  })
_sym_db.RegisterMessage(ListNetworksRequest)

ListNetworksResponse = _reflection.GeneratedProtocolMessageType('ListNetworksResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTNETWORKSRESPONSE,
  '__module__' : 'yandex.cloud.vpc.v1.network_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.ListNetworksResponse)
  })
_sym_db.RegisterMessage(ListNetworksResponse)

CreateNetworkRequest = _reflection.GeneratedProtocolMessageType('CreateNetworkRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATENETWORKREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.vpc.v1.network_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.CreateNetworkRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATENETWORKREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.network_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.CreateNetworkRequest)
  })
_sym_db.RegisterMessage(CreateNetworkRequest)
_sym_db.RegisterMessage(CreateNetworkRequest.LabelsEntry)

CreateNetworkMetadata = _reflection.GeneratedProtocolMessageType('CreateNetworkMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATENETWORKMETADATA,
  '__module__' : 'yandex.cloud.vpc.v1.network_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.CreateNetworkMetadata)
  })
_sym_db.RegisterMessage(CreateNetworkMetadata)

UpdateNetworkRequest = _reflection.GeneratedProtocolMessageType('UpdateNetworkRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATENETWORKREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.vpc.v1.network_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.UpdateNetworkRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATENETWORKREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.network_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.UpdateNetworkRequest)
  })
_sym_db.RegisterMessage(UpdateNetworkRequest)
_sym_db.RegisterMessage(UpdateNetworkRequest.LabelsEntry)

UpdateNetworkMetadata = _reflection.GeneratedProtocolMessageType('UpdateNetworkMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENETWORKMETADATA,
  '__module__' : 'yandex.cloud.vpc.v1.network_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.UpdateNetworkMetadata)
  })
_sym_db.RegisterMessage(UpdateNetworkMetadata)

DeleteNetworkRequest = _reflection.GeneratedProtocolMessageType('DeleteNetworkRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETENETWORKREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.network_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.DeleteNetworkRequest)
  })
_sym_db.RegisterMessage(DeleteNetworkRequest)

DeleteNetworkMetadata = _reflection.GeneratedProtocolMessageType('DeleteNetworkMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETENETWORKMETADATA,
  '__module__' : 'yandex.cloud.vpc.v1.network_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.DeleteNetworkMetadata)
  })
_sym_db.RegisterMessage(DeleteNetworkMetadata)

ListNetworkSubnetsRequest = _reflection.GeneratedProtocolMessageType('ListNetworkSubnetsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTNETWORKSUBNETSREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.network_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.ListNetworkSubnetsRequest)
  })
_sym_db.RegisterMessage(ListNetworkSubnetsRequest)

ListNetworkSubnetsResponse = _reflection.GeneratedProtocolMessageType('ListNetworkSubnetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTNETWORKSUBNETSRESPONSE,
  '__module__' : 'yandex.cloud.vpc.v1.network_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.ListNetworkSubnetsResponse)
  })
_sym_db.RegisterMessage(ListNetworkSubnetsResponse)

ListNetworkSecurityGroupsRequest = _reflection.GeneratedProtocolMessageType('ListNetworkSecurityGroupsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTNETWORKSECURITYGROUPSREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.network_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.ListNetworkSecurityGroupsRequest)
  })
_sym_db.RegisterMessage(ListNetworkSecurityGroupsRequest)

ListNetworkSecurityGroupsResponse = _reflection.GeneratedProtocolMessageType('ListNetworkSecurityGroupsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTNETWORKSECURITYGROUPSRESPONSE,
  '__module__' : 'yandex.cloud.vpc.v1.network_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.ListNetworkSecurityGroupsResponse)
  })
_sym_db.RegisterMessage(ListNetworkSecurityGroupsResponse)

ListNetworkRouteTablesRequest = _reflection.GeneratedProtocolMessageType('ListNetworkRouteTablesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTNETWORKROUTETABLESREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.network_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.ListNetworkRouteTablesRequest)
  })
_sym_db.RegisterMessage(ListNetworkRouteTablesRequest)

ListNetworkRouteTablesResponse = _reflection.GeneratedProtocolMessageType('ListNetworkRouteTablesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTNETWORKROUTETABLESRESPONSE,
  '__module__' : 'yandex.cloud.vpc.v1.network_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.ListNetworkRouteTablesResponse)
  })
_sym_db.RegisterMessage(ListNetworkRouteTablesResponse)

ListNetworkOperationsRequest = _reflection.GeneratedProtocolMessageType('ListNetworkOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTNETWORKOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.network_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.ListNetworkOperationsRequest)
  })
_sym_db.RegisterMessage(ListNetworkOperationsRequest)

ListNetworkOperationsResponse = _reflection.GeneratedProtocolMessageType('ListNetworkOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTNETWORKOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.vpc.v1.network_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.ListNetworkOperationsResponse)
  })
_sym_db.RegisterMessage(ListNetworkOperationsResponse)

MoveNetworkRequest = _reflection.GeneratedProtocolMessageType('MoveNetworkRequest', (_message.Message,), {
  'DESCRIPTOR' : _MOVENETWORKREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.network_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.MoveNetworkRequest)
  })
_sym_db.RegisterMessage(MoveNetworkRequest)

MoveNetworkMetadata = _reflection.GeneratedProtocolMessageType('MoveNetworkMetadata', (_message.Message,), {
  'DESCRIPTOR' : _MOVENETWORKMETADATA,
  '__module__' : 'yandex.cloud.vpc.v1.network_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.MoveNetworkMetadata)
  })
_sym_db.RegisterMessage(MoveNetworkMetadata)


DESCRIPTOR._options = None
_GETNETWORKREQUEST.fields_by_name['network_id']._options = None
_LISTNETWORKSREQUEST.fields_by_name['folder_id']._options = None
_LISTNETWORKSREQUEST.fields_by_name['page_size']._options = None
_LISTNETWORKSREQUEST.fields_by_name['page_token']._options = None
_LISTNETWORKSREQUEST.fields_by_name['filter']._options = None
_CREATENETWORKREQUEST_LABELSENTRY._options = None
_CREATENETWORKREQUEST.fields_by_name['folder_id']._options = None
_CREATENETWORKREQUEST.fields_by_name['name']._options = None
_CREATENETWORKREQUEST.fields_by_name['description']._options = None
_CREATENETWORKREQUEST.fields_by_name['labels']._options = None
_UPDATENETWORKREQUEST_LABELSENTRY._options = None
_UPDATENETWORKREQUEST.fields_by_name['network_id']._options = None
_UPDATENETWORKREQUEST.fields_by_name['name']._options = None
_UPDATENETWORKREQUEST.fields_by_name['description']._options = None
_UPDATENETWORKREQUEST.fields_by_name['labels']._options = None
_DELETENETWORKREQUEST.fields_by_name['network_id']._options = None
_LISTNETWORKSUBNETSREQUEST.fields_by_name['network_id']._options = None
_LISTNETWORKSUBNETSREQUEST.fields_by_name['page_size']._options = None
_LISTNETWORKSUBNETSREQUEST.fields_by_name['page_token']._options = None
_LISTNETWORKSECURITYGROUPSREQUEST.fields_by_name['network_id']._options = None
_LISTNETWORKSECURITYGROUPSREQUEST.fields_by_name['page_size']._options = None
_LISTNETWORKSECURITYGROUPSREQUEST.fields_by_name['page_token']._options = None
_LISTNETWORKROUTETABLESREQUEST.fields_by_name['network_id']._options = None
_LISTNETWORKROUTETABLESREQUEST.fields_by_name['page_size']._options = None
_LISTNETWORKROUTETABLESREQUEST.fields_by_name['page_token']._options = None
_LISTNETWORKOPERATIONSREQUEST.fields_by_name['network_id']._options = None
_LISTNETWORKOPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTNETWORKOPERATIONSREQUEST.fields_by_name['page_token']._options = None
_MOVENETWORKREQUEST.fields_by_name['network_id']._options = None
_MOVENETWORKREQUEST.fields_by_name['destination_folder_id']._options = None

_NETWORKSERVICE = _descriptor.ServiceDescriptor(
  name='NetworkService',
  full_name='yandex.cloud.vpc.v1.NetworkService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2684,
  serialized_end=4298,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.vpc.v1.NetworkService.Get',
    index=0,
    containing_service=None,
    input_type=_GETNETWORKREQUEST,
    output_type=yandex_dot_cloud_dot_vpc_dot_v1_dot_network__pb2._NETWORK,
    serialized_options=b'\202\323\344\223\002\037\022\035/vpc/v1/networks/{network_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.vpc.v1.NetworkService.List',
    index=1,
    containing_service=None,
    input_type=_LISTNETWORKSREQUEST,
    output_type=_LISTNETWORKSRESPONSE,
    serialized_options=b'\202\323\344\223\002\022\022\020/vpc/v1/networks',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.vpc.v1.NetworkService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATENETWORKREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\025\"\020/vpc/v1/networks:\001*\262\322* \n\025CreateNetworkMetadata\022\007Network',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.vpc.v1.NetworkService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATENETWORKREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\"2\035/vpc/v1/networks/{network_id}:\001*\262\322* \n\025UpdateNetworkMetadata\022\007Network',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.vpc.v1.NetworkService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETENETWORKREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\037*\035/vpc/v1/networks/{network_id}\262\322*.\n\025DeleteNetworkMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListSubnets',
    full_name='yandex.cloud.vpc.v1.NetworkService.ListSubnets',
    index=5,
    containing_service=None,
    input_type=_LISTNETWORKSUBNETSREQUEST,
    output_type=_LISTNETWORKSUBNETSRESPONSE,
    serialized_options=b'\202\323\344\223\002\'\022%/vpc/v1/networks/{network_id}/subnets',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListSecurityGroups',
    full_name='yandex.cloud.vpc.v1.NetworkService.ListSecurityGroups',
    index=6,
    containing_service=None,
    input_type=_LISTNETWORKSECURITYGROUPSREQUEST,
    output_type=_LISTNETWORKSECURITYGROUPSRESPONSE,
    serialized_options=b'\202\323\344\223\002/\022-/vpc/v1/networks/{network_id}/security_groups',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListRouteTables',
    full_name='yandex.cloud.vpc.v1.NetworkService.ListRouteTables',
    index=7,
    containing_service=None,
    input_type=_LISTNETWORKROUTETABLESREQUEST,
    output_type=_LISTNETWORKROUTETABLESRESPONSE,
    serialized_options=b'\202\323\344\223\002,\022*/vpc/v1/networks/{network_id}/route_tables',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.vpc.v1.NetworkService.ListOperations',
    index=8,
    containing_service=None,
    input_type=_LISTNETWORKOPERATIONSREQUEST,
    output_type=_LISTNETWORKOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002*\022(/vpc/v1/networks/{network_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Move',
    full_name='yandex.cloud.vpc.v1.NetworkService.Move',
    index=9,
    containing_service=None,
    input_type=_MOVENETWORKREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\'\"\"/vpc/v1/networks/{network_id}:move:\001*\262\322*\036\n\023MoveNetworkMetadata\022\007Network',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_NETWORKSERVICE)

DESCRIPTOR.services_by_name['NetworkService'] = _NETWORKSERVICE

# @@protoc_insertion_point(module_scope)
