# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/agent/v1/agent_registration_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/loadtesting/agent/v1/agent_registration_service.proto',
  package='yandex.cloud.loadtesting.agent.v1',
  syntax='proto3',
  serialized_options=b'\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agent',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nByandex/cloud/loadtesting/agent/v1/agent_registration_service.proto\x12!yandex.cloud.loadtesting.agent.v1\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1cgoogle/api/annotations.proto\".\n\x0fRegisterRequest\x12\x1b\n\x13\x63ompute_instance_id\x18\x01 \x01(\t\"-\n\x10RegisterResponse\x12\x19\n\x11\x61gent_instance_id\x18\x01 \x01(\t\"s\n\x1c\x45xternalAgentRegisterRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x1b\n\x13\x63ompute_instance_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x15\n\ragent_version\x18\x04 \x01(\t\":\n\x1d\x45xternalAgentRegisterMetadata\x12\x19\n\x11\x61gent_instance_id\x18\x01 \x01(\t2\xb2\x03\n\x18\x41gentRegistrationService\x12\xa5\x01\n\x08Register\x12\x32.yandex.cloud.loadtesting.agent.v1.RegisterRequest\x1a\x33.yandex.cloud.loadtesting.agent.v1.RegisterResponse\"0\x82\xd3\xe4\x93\x02*\"%/loadtesting/agent/v1/agents/register:\x01*\x12\xed\x01\n\x15\x45xternalAgentRegister\x12?.yandex.cloud.loadtesting.agent.v1.ExternalAgentRegisterRequest\x1a!.yandex.cloud.operation.Operation\"p\x82\xd3\xe4\x93\x02\x38\"3/loadtesting/agent/v1/agents/externalAgentsRegister:\x01*\xb2\xd2*.\n\x1d\x45xternalAgentRegisterMetadata\x12\rAgentInstanceBt\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agentb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_REGISTERREQUEST = _descriptor.Descriptor(
  name='RegisterRequest',
  full_name='yandex.cloud.loadtesting.agent.v1.RegisterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='compute_instance_id', full_name='yandex.cloud.loadtesting.agent.v1.RegisterRequest.compute_instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=209,
  serialized_end=255,
)


_REGISTERRESPONSE = _descriptor.Descriptor(
  name='RegisterResponse',
  full_name='yandex.cloud.loadtesting.agent.v1.RegisterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='agent_instance_id', full_name='yandex.cloud.loadtesting.agent.v1.RegisterResponse.agent_instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=257,
  serialized_end=302,
)


_EXTERNALAGENTREGISTERREQUEST = _descriptor.Descriptor(
  name='ExternalAgentRegisterRequest',
  full_name='yandex.cloud.loadtesting.agent.v1.ExternalAgentRegisterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.loadtesting.agent.v1.ExternalAgentRegisterRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compute_instance_id', full_name='yandex.cloud.loadtesting.agent.v1.ExternalAgentRegisterRequest.compute_instance_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.loadtesting.agent.v1.ExternalAgentRegisterRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='agent_version', full_name='yandex.cloud.loadtesting.agent.v1.ExternalAgentRegisterRequest.agent_version', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=304,
  serialized_end=419,
)


_EXTERNALAGENTREGISTERMETADATA = _descriptor.Descriptor(
  name='ExternalAgentRegisterMetadata',
  full_name='yandex.cloud.loadtesting.agent.v1.ExternalAgentRegisterMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='agent_instance_id', full_name='yandex.cloud.loadtesting.agent.v1.ExternalAgentRegisterMetadata.agent_instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=421,
  serialized_end=479,
)

DESCRIPTOR.message_types_by_name['RegisterRequest'] = _REGISTERREQUEST
DESCRIPTOR.message_types_by_name['RegisterResponse'] = _REGISTERRESPONSE
DESCRIPTOR.message_types_by_name['ExternalAgentRegisterRequest'] = _EXTERNALAGENTREGISTERREQUEST
DESCRIPTOR.message_types_by_name['ExternalAgentRegisterMetadata'] = _EXTERNALAGENTREGISTERMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RegisterRequest = _reflection.GeneratedProtocolMessageType('RegisterRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERREQUEST,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.agent_registration_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.RegisterRequest)
  })
_sym_db.RegisterMessage(RegisterRequest)

RegisterResponse = _reflection.GeneratedProtocolMessageType('RegisterResponse', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERRESPONSE,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.agent_registration_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.RegisterResponse)
  })
_sym_db.RegisterMessage(RegisterResponse)

ExternalAgentRegisterRequest = _reflection.GeneratedProtocolMessageType('ExternalAgentRegisterRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXTERNALAGENTREGISTERREQUEST,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.agent_registration_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.ExternalAgentRegisterRequest)
  })
_sym_db.RegisterMessage(ExternalAgentRegisterRequest)

ExternalAgentRegisterMetadata = _reflection.GeneratedProtocolMessageType('ExternalAgentRegisterMetadata', (_message.Message,), {
  'DESCRIPTOR' : _EXTERNALAGENTREGISTERMETADATA,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.agent_registration_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.ExternalAgentRegisterMetadata)
  })
_sym_db.RegisterMessage(ExternalAgentRegisterMetadata)


DESCRIPTOR._options = None

_AGENTREGISTRATIONSERVICE = _descriptor.ServiceDescriptor(
  name='AgentRegistrationService',
  full_name='yandex.cloud.loadtesting.agent.v1.AgentRegistrationService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=482,
  serialized_end=916,
  methods=[
  _descriptor.MethodDescriptor(
    name='Register',
    full_name='yandex.cloud.loadtesting.agent.v1.AgentRegistrationService.Register',
    index=0,
    containing_service=None,
    input_type=_REGISTERREQUEST,
    output_type=_REGISTERRESPONSE,
    serialized_options=b'\202\323\344\223\002*\"%/loadtesting/agent/v1/agents/register:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ExternalAgentRegister',
    full_name='yandex.cloud.loadtesting.agent.v1.AgentRegistrationService.ExternalAgentRegister',
    index=1,
    containing_service=None,
    input_type=_EXTERNALAGENTREGISTERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0028\"3/loadtesting/agent/v1/agents/externalAgentsRegister:\001*\262\322*.\n\035ExternalAgentRegisterMetadata\022\rAgentInstance',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_AGENTREGISTRATIONSERVICE)

DESCRIPTOR.services_by_name['AgentRegistrationService'] = _AGENTREGISTRATIONSERVICE

# @@protoc_insertion_point(module_scope)
