# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/billing/v1/budget.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/billing/v1/budget.proto',
  package='yandex.cloud.billing.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billing',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$yandex/cloud/billing/v1/budget.proto\x12\x17yandex.cloud.billing.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\x86\x03\n\x06\x42udget\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1a\n\x12\x62illing_account_id\x18\x04 \x01(\t\x12\x35\n\x06status\x18\x05 \x01(\x0e\x32%.yandex.cloud.billing.v1.BudgetStatus\x12>\n\x0b\x63ost_budget\x18\x06 \x01(\x0b\x32\'.yandex.cloud.billing.v1.CostBudgetSpecH\x00\x12\x44\n\x0e\x65xpense_budget\x18\x07 \x01(\x0b\x32*.yandex.cloud.billing.v1.ExpenseBudgetSpecH\x00\x12\x44\n\x0e\x62\x61lance_budget\x18\x08 \x01(\x0b\x32*.yandex.cloud.billing.v1.BalanceBudgetSpecH\x00\x42\x13\n\x0b\x62udget_spec\x12\x04\xc0\xc1\x31\x01\"\xd7\x02\n\x0e\x43ostBudgetSpec\x12\x14\n\x06\x61mount\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12.\n\x1dnotification_user_account_ids\x18\x02 \x03(\tB\x07\x82\xc8\x31\x03>=1\x12?\n\x0fthreshold_rules\x18\x03 \x03(\x0b\x32&.yandex.cloud.billing.v1.ThresholdRule\x12:\n\x06\x66ilter\x18\x04 \x01(\x0b\x32*.yandex.cloud.billing.v1.ConsumptionFilter\x12@\n\x0creset_period\x18\x05 \x01(\x0e\x32(.yandex.cloud.billing.v1.ResetPeriodTypeH\x00\x12\x14\n\nstart_date\x18\x06 \x01(\tH\x00\x12\x16\n\x08\x65nd_date\x18\x07 \x01(\tB\x04\xe8\xc7\x31\x01\x42\x12\n\nstart_type\x12\x04\xc0\xc1\x31\x01\"\xda\x02\n\x11\x45xpenseBudgetSpec\x12\x14\n\x06\x61mount\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12.\n\x1dnotification_user_account_ids\x18\x02 \x03(\tB\x07\x82\xc8\x31\x03>=1\x12?\n\x0fthreshold_rules\x18\x03 \x03(\x0b\x32&.yandex.cloud.billing.v1.ThresholdRule\x12:\n\x06\x66ilter\x18\x04 \x01(\x0b\x32*.yandex.cloud.billing.v1.ConsumptionFilter\x12@\n\x0creset_period\x18\x05 \x01(\x0e\x32(.yandex.cloud.billing.v1.ResetPeriodTypeH\x00\x12\x14\n\nstart_date\x18\x06 \x01(\tH\x00\x12\x16\n\x08\x65nd_date\x18\x07 \x01(\tB\x04\xe8\xc7\x31\x01\x42\x12\n\nstart_type\x12\x04\xc0\xc1\x31\x01\"\xc6\x01\n\x11\x42\x61lanceBudgetSpec\x12\x14\n\x06\x61mount\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12.\n\x1dnotification_user_account_ids\x18\x02 \x03(\tB\x07\x82\xc8\x31\x03>=1\x12?\n\x0fthreshold_rules\x18\x03 \x03(\x0b\x32&.yandex.cloud.billing.v1.ThresholdRule\x12\x12\n\nstart_date\x18\x04 \x01(\t\x12\x16\n\x08\x65nd_date\x18\x05 \x01(\tB\x04\xe8\xc7\x31\x01\"\x7f\n\x11\x43onsumptionFilter\x12\x13\n\x0bservice_ids\x18\x01 \x03(\t\x12U\n\x15\x63loud_folders_filters\x18\x02 \x03(\x0b\x32\x36.yandex.cloud.billing.v1.CloudFoldersConsumptionFilter\"E\n\x1d\x43loudFoldersConsumptionFilter\x12\x10\n\x08\x63loud_id\x18\x01 \x01(\t\x12\x12\n\nfolder_ids\x18\x02 \x03(\t\"\x88\x01\n\rThresholdRule\x12:\n\x04type\x18\x01 \x01(\x0e\x32&.yandex.cloud.billing.v1.ThresholdTypeB\x04\xe8\xc7\x31\x01\x12\x14\n\x06\x61mount\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12%\n\x1dnotification_user_account_ids\x18\x03 \x03(\t*U\n\x0c\x42udgetStatus\x12\x1d\n\x19\x42UDGET_STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x46INISHED\x10\x03*\\\n\x0fResetPeriodType\x12!\n\x1dRESET_PERIOD_TYPE_UNSPECIFIED\x10\x00\x12\x0b\n\x07MONTHLY\x10\x01\x12\x0b\n\x07QUARTER\x10\x02\x12\x0c\n\x08\x41NNUALLY\x10\x03*H\n\rThresholdType\x12\x1e\n\x1aTHRESHOLD_TYPE_UNSPECIFIED\x10\x00\x12\x0b\n\x07PERCENT\x10\x01\x12\n\n\x06\x41MOUNT\x10\x02\x42\x62\n\x1byandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billingb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])

_BUDGETSTATUS = _descriptor.EnumDescriptor(
  name='BudgetStatus',
  full_name='yandex.cloud.billing.v1.BudgetStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BUDGET_STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FINISHED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1757,
  serialized_end=1842,
)
_sym_db.RegisterEnumDescriptor(_BUDGETSTATUS)

BudgetStatus = enum_type_wrapper.EnumTypeWrapper(_BUDGETSTATUS)
_RESETPERIODTYPE = _descriptor.EnumDescriptor(
  name='ResetPeriodType',
  full_name='yandex.cloud.billing.v1.ResetPeriodType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESET_PERIOD_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MONTHLY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='QUARTER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ANNUALLY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1844,
  serialized_end=1936,
)
_sym_db.RegisterEnumDescriptor(_RESETPERIODTYPE)

ResetPeriodType = enum_type_wrapper.EnumTypeWrapper(_RESETPERIODTYPE)
_THRESHOLDTYPE = _descriptor.EnumDescriptor(
  name='ThresholdType',
  full_name='yandex.cloud.billing.v1.ThresholdType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='THRESHOLD_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERCENT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AMOUNT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1938,
  serialized_end=2010,
)
_sym_db.RegisterEnumDescriptor(_THRESHOLDTYPE)

ThresholdType = enum_type_wrapper.EnumTypeWrapper(_THRESHOLDTYPE)
BUDGET_STATUS_UNSPECIFIED = 0
CREATING = 1
ACTIVE = 2
FINISHED = 3
RESET_PERIOD_TYPE_UNSPECIFIED = 0
MONTHLY = 1
QUARTER = 2
ANNUALLY = 3
THRESHOLD_TYPE_UNSPECIFIED = 0
PERCENT = 1
AMOUNT = 2



_BUDGET = _descriptor.Descriptor(
  name='Budget',
  full_name='yandex.cloud.billing.v1.Budget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.billing.v1.Budget.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.billing.v1.Budget.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.billing.v1.Budget.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='billing_account_id', full_name='yandex.cloud.billing.v1.Budget.billing_account_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.billing.v1.Budget.status', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cost_budget', full_name='yandex.cloud.billing.v1.Budget.cost_budget', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expense_budget', full_name='yandex.cloud.billing.v1.Budget.expense_budget', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='balance_budget', full_name='yandex.cloud.billing.v1.Budget.balance_budget', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='budget_spec', full_name='yandex.cloud.billing.v1.Budget.budget_spec',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=130,
  serialized_end=520,
)


_COSTBUDGETSPEC = _descriptor.Descriptor(
  name='CostBudgetSpec',
  full_name='yandex.cloud.billing.v1.CostBudgetSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount', full_name='yandex.cloud.billing.v1.CostBudgetSpec.amount', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notification_user_account_ids', full_name='yandex.cloud.billing.v1.CostBudgetSpec.notification_user_account_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\003>=1', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='threshold_rules', full_name='yandex.cloud.billing.v1.CostBudgetSpec.threshold_rules', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.billing.v1.CostBudgetSpec.filter', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reset_period', full_name='yandex.cloud.billing.v1.CostBudgetSpec.reset_period', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_date', full_name='yandex.cloud.billing.v1.CostBudgetSpec.start_date', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_date', full_name='yandex.cloud.billing.v1.CostBudgetSpec.end_date', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='start_type', full_name='yandex.cloud.billing.v1.CostBudgetSpec.start_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=523,
  serialized_end=866,
)


_EXPENSEBUDGETSPEC = _descriptor.Descriptor(
  name='ExpenseBudgetSpec',
  full_name='yandex.cloud.billing.v1.ExpenseBudgetSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount', full_name='yandex.cloud.billing.v1.ExpenseBudgetSpec.amount', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notification_user_account_ids', full_name='yandex.cloud.billing.v1.ExpenseBudgetSpec.notification_user_account_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\003>=1', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='threshold_rules', full_name='yandex.cloud.billing.v1.ExpenseBudgetSpec.threshold_rules', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.billing.v1.ExpenseBudgetSpec.filter', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reset_period', full_name='yandex.cloud.billing.v1.ExpenseBudgetSpec.reset_period', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_date', full_name='yandex.cloud.billing.v1.ExpenseBudgetSpec.start_date', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_date', full_name='yandex.cloud.billing.v1.ExpenseBudgetSpec.end_date', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='start_type', full_name='yandex.cloud.billing.v1.ExpenseBudgetSpec.start_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=869,
  serialized_end=1215,
)


_BALANCEBUDGETSPEC = _descriptor.Descriptor(
  name='BalanceBudgetSpec',
  full_name='yandex.cloud.billing.v1.BalanceBudgetSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount', full_name='yandex.cloud.billing.v1.BalanceBudgetSpec.amount', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notification_user_account_ids', full_name='yandex.cloud.billing.v1.BalanceBudgetSpec.notification_user_account_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\003>=1', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='threshold_rules', full_name='yandex.cloud.billing.v1.BalanceBudgetSpec.threshold_rules', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_date', full_name='yandex.cloud.billing.v1.BalanceBudgetSpec.start_date', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_date', full_name='yandex.cloud.billing.v1.BalanceBudgetSpec.end_date', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1218,
  serialized_end=1416,
)


_CONSUMPTIONFILTER = _descriptor.Descriptor(
  name='ConsumptionFilter',
  full_name='yandex.cloud.billing.v1.ConsumptionFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_ids', full_name='yandex.cloud.billing.v1.ConsumptionFilter.service_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cloud_folders_filters', full_name='yandex.cloud.billing.v1.ConsumptionFilter.cloud_folders_filters', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1418,
  serialized_end=1545,
)


_CLOUDFOLDERSCONSUMPTIONFILTER = _descriptor.Descriptor(
  name='CloudFoldersConsumptionFilter',
  full_name='yandex.cloud.billing.v1.CloudFoldersConsumptionFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cloud_id', full_name='yandex.cloud.billing.v1.CloudFoldersConsumptionFilter.cloud_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_ids', full_name='yandex.cloud.billing.v1.CloudFoldersConsumptionFilter.folder_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1547,
  serialized_end=1616,
)


_THRESHOLDRULE = _descriptor.Descriptor(
  name='ThresholdRule',
  full_name='yandex.cloud.billing.v1.ThresholdRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.billing.v1.ThresholdRule.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='yandex.cloud.billing.v1.ThresholdRule.amount', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notification_user_account_ids', full_name='yandex.cloud.billing.v1.ThresholdRule.notification_user_account_ids', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1619,
  serialized_end=1755,
)

_BUDGET.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BUDGET.fields_by_name['status'].enum_type = _BUDGETSTATUS
_BUDGET.fields_by_name['cost_budget'].message_type = _COSTBUDGETSPEC
_BUDGET.fields_by_name['expense_budget'].message_type = _EXPENSEBUDGETSPEC
_BUDGET.fields_by_name['balance_budget'].message_type = _BALANCEBUDGETSPEC
_BUDGET.oneofs_by_name['budget_spec'].fields.append(
  _BUDGET.fields_by_name['cost_budget'])
_BUDGET.fields_by_name['cost_budget'].containing_oneof = _BUDGET.oneofs_by_name['budget_spec']
_BUDGET.oneofs_by_name['budget_spec'].fields.append(
  _BUDGET.fields_by_name['expense_budget'])
_BUDGET.fields_by_name['expense_budget'].containing_oneof = _BUDGET.oneofs_by_name['budget_spec']
_BUDGET.oneofs_by_name['budget_spec'].fields.append(
  _BUDGET.fields_by_name['balance_budget'])
_BUDGET.fields_by_name['balance_budget'].containing_oneof = _BUDGET.oneofs_by_name['budget_spec']
_COSTBUDGETSPEC.fields_by_name['threshold_rules'].message_type = _THRESHOLDRULE
_COSTBUDGETSPEC.fields_by_name['filter'].message_type = _CONSUMPTIONFILTER
_COSTBUDGETSPEC.fields_by_name['reset_period'].enum_type = _RESETPERIODTYPE
_COSTBUDGETSPEC.oneofs_by_name['start_type'].fields.append(
  _COSTBUDGETSPEC.fields_by_name['reset_period'])
_COSTBUDGETSPEC.fields_by_name['reset_period'].containing_oneof = _COSTBUDGETSPEC.oneofs_by_name['start_type']
_COSTBUDGETSPEC.oneofs_by_name['start_type'].fields.append(
  _COSTBUDGETSPEC.fields_by_name['start_date'])
_COSTBUDGETSPEC.fields_by_name['start_date'].containing_oneof = _COSTBUDGETSPEC.oneofs_by_name['start_type']
_EXPENSEBUDGETSPEC.fields_by_name['threshold_rules'].message_type = _THRESHOLDRULE
_EXPENSEBUDGETSPEC.fields_by_name['filter'].message_type = _CONSUMPTIONFILTER
_EXPENSEBUDGETSPEC.fields_by_name['reset_period'].enum_type = _RESETPERIODTYPE
_EXPENSEBUDGETSPEC.oneofs_by_name['start_type'].fields.append(
  _EXPENSEBUDGETSPEC.fields_by_name['reset_period'])
_EXPENSEBUDGETSPEC.fields_by_name['reset_period'].containing_oneof = _EXPENSEBUDGETSPEC.oneofs_by_name['start_type']
_EXPENSEBUDGETSPEC.oneofs_by_name['start_type'].fields.append(
  _EXPENSEBUDGETSPEC.fields_by_name['start_date'])
_EXPENSEBUDGETSPEC.fields_by_name['start_date'].containing_oneof = _EXPENSEBUDGETSPEC.oneofs_by_name['start_type']
_BALANCEBUDGETSPEC.fields_by_name['threshold_rules'].message_type = _THRESHOLDRULE
_CONSUMPTIONFILTER.fields_by_name['cloud_folders_filters'].message_type = _CLOUDFOLDERSCONSUMPTIONFILTER
_THRESHOLDRULE.fields_by_name['type'].enum_type = _THRESHOLDTYPE
DESCRIPTOR.message_types_by_name['Budget'] = _BUDGET
DESCRIPTOR.message_types_by_name['CostBudgetSpec'] = _COSTBUDGETSPEC
DESCRIPTOR.message_types_by_name['ExpenseBudgetSpec'] = _EXPENSEBUDGETSPEC
DESCRIPTOR.message_types_by_name['BalanceBudgetSpec'] = _BALANCEBUDGETSPEC
DESCRIPTOR.message_types_by_name['ConsumptionFilter'] = _CONSUMPTIONFILTER
DESCRIPTOR.message_types_by_name['CloudFoldersConsumptionFilter'] = _CLOUDFOLDERSCONSUMPTIONFILTER
DESCRIPTOR.message_types_by_name['ThresholdRule'] = _THRESHOLDRULE
DESCRIPTOR.enum_types_by_name['BudgetStatus'] = _BUDGETSTATUS
DESCRIPTOR.enum_types_by_name['ResetPeriodType'] = _RESETPERIODTYPE
DESCRIPTOR.enum_types_by_name['ThresholdType'] = _THRESHOLDTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Budget = _reflection.GeneratedProtocolMessageType('Budget', (_message.Message,), {
  'DESCRIPTOR' : _BUDGET,
  '__module__' : 'yandex.cloud.billing.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.Budget)
  })
_sym_db.RegisterMessage(Budget)

CostBudgetSpec = _reflection.GeneratedProtocolMessageType('CostBudgetSpec', (_message.Message,), {
  'DESCRIPTOR' : _COSTBUDGETSPEC,
  '__module__' : 'yandex.cloud.billing.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.CostBudgetSpec)
  })
_sym_db.RegisterMessage(CostBudgetSpec)

ExpenseBudgetSpec = _reflection.GeneratedProtocolMessageType('ExpenseBudgetSpec', (_message.Message,), {
  'DESCRIPTOR' : _EXPENSEBUDGETSPEC,
  '__module__' : 'yandex.cloud.billing.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.ExpenseBudgetSpec)
  })
_sym_db.RegisterMessage(ExpenseBudgetSpec)

BalanceBudgetSpec = _reflection.GeneratedProtocolMessageType('BalanceBudgetSpec', (_message.Message,), {
  'DESCRIPTOR' : _BALANCEBUDGETSPEC,
  '__module__' : 'yandex.cloud.billing.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.BalanceBudgetSpec)
  })
_sym_db.RegisterMessage(BalanceBudgetSpec)

ConsumptionFilter = _reflection.GeneratedProtocolMessageType('ConsumptionFilter', (_message.Message,), {
  'DESCRIPTOR' : _CONSUMPTIONFILTER,
  '__module__' : 'yandex.cloud.billing.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.ConsumptionFilter)
  })
_sym_db.RegisterMessage(ConsumptionFilter)

CloudFoldersConsumptionFilter = _reflection.GeneratedProtocolMessageType('CloudFoldersConsumptionFilter', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDFOLDERSCONSUMPTIONFILTER,
  '__module__' : 'yandex.cloud.billing.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.CloudFoldersConsumptionFilter)
  })
_sym_db.RegisterMessage(CloudFoldersConsumptionFilter)

ThresholdRule = _reflection.GeneratedProtocolMessageType('ThresholdRule', (_message.Message,), {
  'DESCRIPTOR' : _THRESHOLDRULE,
  '__module__' : 'yandex.cloud.billing.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.ThresholdRule)
  })
_sym_db.RegisterMessage(ThresholdRule)


DESCRIPTOR._options = None
_BUDGET.oneofs_by_name['budget_spec']._options = None
_COSTBUDGETSPEC.oneofs_by_name['start_type']._options = None
_COSTBUDGETSPEC.fields_by_name['amount']._options = None
_COSTBUDGETSPEC.fields_by_name['notification_user_account_ids']._options = None
_COSTBUDGETSPEC.fields_by_name['end_date']._options = None
_EXPENSEBUDGETSPEC.oneofs_by_name['start_type']._options = None
_EXPENSEBUDGETSPEC.fields_by_name['amount']._options = None
_EXPENSEBUDGETSPEC.fields_by_name['notification_user_account_ids']._options = None
_EXPENSEBUDGETSPEC.fields_by_name['end_date']._options = None
_BALANCEBUDGETSPEC.fields_by_name['amount']._options = None
_BALANCEBUDGETSPEC.fields_by_name['notification_user_account_ids']._options = None
_BALANCEBUDGETSPEC.fields_by_name['end_date']._options = None
_THRESHOLDRULE.fields_by_name['type']._options = None
_THRESHOLDRULE.fields_by_name['amount']._options = None
# @@protoc_insertion_point(module_scope)
