# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datatransfer/v1/endpoint/clickhouse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yandex.cloud.datatransfer.v1.endpoint import common_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/datatransfer/v1/endpoint/clickhouse.proto',
  package='yandex.cloud.datatransfer.v1.endpoint',
  syntax='proto3',
  serialized_options=b'\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\252\002%Yandex.Cloud.Datatransfer.V1.EndPoint',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n6yandex/cloud/datatransfer/v1/endpoint/clickhouse.proto\x12%yandex.cloud.datatransfer.v1.endpoint\x1a\x1bgoogle/protobuf/empty.proto\x1a\x32yandex/cloud/datatransfer/v1/endpoint/common.proto\".\n\x0f\x43lickhouseShard\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05hosts\x18\x02 \x03(\t\"\xc7\x01\n\x13OnPremiseClickhouse\x12\x46\n\x06shards\x18\x01 \x03(\x0b\x32\x36.yandex.cloud.datatransfer.v1.endpoint.ClickhouseShard\x12\x11\n\thttp_port\x18\x03 \x01(\x03\x12\x13\n\x0bnative_port\x18\x04 \x01(\x03\x12@\n\x08tls_mode\x18\x08 \x01(\x0b\x32..yandex.cloud.datatransfer.v1.endpoint.TLSMode\"\xf5\x01\n\x1b\x43lickhouseConnectionOptions\x12\x18\n\x0emdb_cluster_id\x18\x05 \x01(\tH\x00\x12P\n\non_premise\x18\x02 \x01(\x0b\x32:.yandex.cloud.datatransfer.v1.endpoint.OnPremiseClickhouseH\x00\x12\x10\n\x08\x64\x61tabase\x18\x08 \x01(\t\x12\x0c\n\x04user\x18\x06 \x01(\t\x12?\n\x08password\x18\x07 \x01(\x0b\x32-.yandex.cloud.datatransfer.v1.endpoint.SecretB\t\n\x07\x61\x64\x64ress\"\x86\x01\n\x14\x43lickhouseConnection\x12`\n\x12\x63onnection_options\x18\x01 \x01(\x0b\x32\x42.yandex.cloud.datatransfer.v1.endpoint.ClickhouseConnectionOptionsH\x00\x42\x0c\n\nconnection\"\xcd\x04\n\x12\x43lickhouseSharding\x12\x66\n\x11\x63olumn_value_hash\x18\x01 \x01(\x0b\x32I.yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.ColumnValueHashH\x00\x12\x66\n\x0e\x63ustom_mapping\x18\x02 \x01(\x0b\x32L.yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.ColumnValueMappingH\x00\x12-\n\x0btransfer_id\x18\x03 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x1a&\n\x0f\x43olumnValueHash\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x1a\x83\x02\n\x12\x43olumnValueMapping\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x12j\n\x07mapping\x18\x02 \x03(\x0b\x32Y.yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.ColumnValueMapping.ValueToShard\x1al\n\x0cValueToShard\x12H\n\x0c\x63olumn_value\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.datatransfer.v1.endpoint.ColumnValue\x12\x12\n\nshard_name\x18\x02 \x01(\tB\n\n\x08sharding\"\xbf\x01\n\x10\x43lickhouseSource\x12O\n\nconnection\x18\x01 \x01(\x0b\x32;.yandex.cloud.datatransfer.v1.endpoint.ClickhouseConnection\x12\x11\n\tsubnet_id\x18\t \x01(\t\x12\x17\n\x0fsecurity_groups\x18\n \x03(\t\x12\x16\n\x0einclude_tables\x18\x07 \x03(\t\x12\x16\n\x0e\x65xclude_tables\x18\x08 \x03(\t\"\x98\x03\n\x10\x43lickhouseTarget\x12O\n\nconnection\x18\x02 \x01(\x0b\x32;.yandex.cloud.datatransfer.v1.endpoint.ClickhouseConnection\x12\x11\n\tsubnet_id\x18\x0c \x01(\t\x12\x17\n\x0fsecurity_groups\x18\x33 \x03(\t\x12\x1f\n\x17\x63lickhouse_cluster_name\x18\x32 \x01(\t\x12\x41\n\talt_names\x18\x11 \x03(\x0b\x32..yandex.cloud.datatransfer.v1.endpoint.AltName\x12K\n\x08sharding\x18\x16 \x01(\x0b\x32\x39.yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding\x12V\n\x0e\x63leanup_policy\x18\x15 \x01(\x0e\x32>.yandex.cloud.datatransfer.v1.endpoint.ClickhouseCleanupPolicy*\xb8\x01\n\x17\x43lickhouseCleanupPolicy\x12)\n%CLICKHOUSE_CLEANUP_POLICY_UNSPECIFIED\x10\x00\x12&\n\"CLICKHOUSE_CLEANUP_POLICY_DISABLED\x10\x01\x12\"\n\x1e\x43LICKHOUSE_CLEANUP_POLICY_DROP\x10\x02\x12&\n\"CLICKHOUSE_CLEANUP_POLICY_TRUNCATE\x10\x03\x42\xa7\x01\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\xaa\x02%Yandex.Cloud.Datatransfer.V1.EndPointb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2.DESCRIPTOR,])

_CLICKHOUSECLEANUPPOLICY = _descriptor.EnumDescriptor(
  name='ClickhouseCleanupPolicy',
  full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseCleanupPolicy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CLICKHOUSE_CLEANUP_POLICY_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLICKHOUSE_CLEANUP_POLICY_DISABLED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLICKHOUSE_CLEANUP_POLICY_DROP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLICKHOUSE_CLEANUP_POLICY_TRUNCATE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2011,
  serialized_end=2195,
)
_sym_db.RegisterEnumDescriptor(_CLICKHOUSECLEANUPPOLICY)

ClickhouseCleanupPolicy = enum_type_wrapper.EnumTypeWrapper(_CLICKHOUSECLEANUPPOLICY)
CLICKHOUSE_CLEANUP_POLICY_UNSPECIFIED = 0
CLICKHOUSE_CLEANUP_POLICY_DISABLED = 1
CLICKHOUSE_CLEANUP_POLICY_DROP = 2
CLICKHOUSE_CLEANUP_POLICY_TRUNCATE = 3



_CLICKHOUSESHARD = _descriptor.Descriptor(
  name='ClickhouseShard',
  full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseShard',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseShard.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hosts', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseShard.hosts', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=178,
  serialized_end=224,
)


_ONPREMISECLICKHOUSE = _descriptor.Descriptor(
  name='OnPremiseClickhouse',
  full_name='yandex.cloud.datatransfer.v1.endpoint.OnPremiseClickhouse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='shards', full_name='yandex.cloud.datatransfer.v1.endpoint.OnPremiseClickhouse.shards', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_port', full_name='yandex.cloud.datatransfer.v1.endpoint.OnPremiseClickhouse.http_port', index=1,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='native_port', full_name='yandex.cloud.datatransfer.v1.endpoint.OnPremiseClickhouse.native_port', index=2,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tls_mode', full_name='yandex.cloud.datatransfer.v1.endpoint.OnPremiseClickhouse.tls_mode', index=3,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=227,
  serialized_end=426,
)


_CLICKHOUSECONNECTIONOPTIONS = _descriptor.Descriptor(
  name='ClickhouseConnectionOptions',
  full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseConnectionOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mdb_cluster_id', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseConnectionOptions.mdb_cluster_id', index=0,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on_premise', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseConnectionOptions.on_premise', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseConnectionOptions.database', index=2,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseConnectionOptions.user', index=3,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseConnectionOptions.password', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='address', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseConnectionOptions.address',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=429,
  serialized_end=674,
)


_CLICKHOUSECONNECTION = _descriptor.Descriptor(
  name='ClickhouseConnection',
  full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseConnection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection_options', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseConnection.connection_options', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='connection', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseConnection.connection',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=677,
  serialized_end=811,
)


_CLICKHOUSESHARDING_COLUMNVALUEHASH = _descriptor.Descriptor(
  name='ColumnValueHash',
  full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.ColumnValueHash',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='column_name', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.ColumnValueHash.column_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1091,
  serialized_end=1129,
)

_CLICKHOUSESHARDING_COLUMNVALUEMAPPING_VALUETOSHARD = _descriptor.Descriptor(
  name='ValueToShard',
  full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.ColumnValueMapping.ValueToShard',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='column_value', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.ColumnValueMapping.ValueToShard.column_value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shard_name', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.ColumnValueMapping.ValueToShard.shard_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1283,
  serialized_end=1391,
)

_CLICKHOUSESHARDING_COLUMNVALUEMAPPING = _descriptor.Descriptor(
  name='ColumnValueMapping',
  full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.ColumnValueMapping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='column_name', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.ColumnValueMapping.column_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mapping', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.ColumnValueMapping.mapping', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CLICKHOUSESHARDING_COLUMNVALUEMAPPING_VALUETOSHARD, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1132,
  serialized_end=1391,
)

_CLICKHOUSESHARDING = _descriptor.Descriptor(
  name='ClickhouseSharding',
  full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='column_value_hash', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.column_value_hash', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_mapping', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.custom_mapping', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transfer_id', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.transfer_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CLICKHOUSESHARDING_COLUMNVALUEHASH, _CLICKHOUSESHARDING_COLUMNVALUEMAPPING, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='sharding', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.sharding',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=814,
  serialized_end=1403,
)


_CLICKHOUSESOURCE = _descriptor.Descriptor(
  name='ClickhouseSource',
  full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSource.connection', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSource.subnet_id', index=1,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_groups', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSource.security_groups', index=2,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_tables', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSource.include_tables', index=3,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exclude_tables', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseSource.exclude_tables', index=4,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1406,
  serialized_end=1597,
)


_CLICKHOUSETARGET = _descriptor.Descriptor(
  name='ClickhouseTarget',
  full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseTarget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseTarget.connection', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseTarget.subnet_id', index=1,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_groups', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseTarget.security_groups', index=2,
      number=51, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clickhouse_cluster_name', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseTarget.clickhouse_cluster_name', index=3,
      number=50, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alt_names', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseTarget.alt_names', index=4,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sharding', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseTarget.sharding', index=5,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cleanup_policy', full_name='yandex.cloud.datatransfer.v1.endpoint.ClickhouseTarget.cleanup_policy', index=6,
      number=21, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1600,
  serialized_end=2008,
)

_ONPREMISECLICKHOUSE.fields_by_name['shards'].message_type = _CLICKHOUSESHARD
_ONPREMISECLICKHOUSE.fields_by_name['tls_mode'].message_type = yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2._TLSMODE
_CLICKHOUSECONNECTIONOPTIONS.fields_by_name['on_premise'].message_type = _ONPREMISECLICKHOUSE
_CLICKHOUSECONNECTIONOPTIONS.fields_by_name['password'].message_type = yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2._SECRET
_CLICKHOUSECONNECTIONOPTIONS.oneofs_by_name['address'].fields.append(
  _CLICKHOUSECONNECTIONOPTIONS.fields_by_name['mdb_cluster_id'])
_CLICKHOUSECONNECTIONOPTIONS.fields_by_name['mdb_cluster_id'].containing_oneof = _CLICKHOUSECONNECTIONOPTIONS.oneofs_by_name['address']
_CLICKHOUSECONNECTIONOPTIONS.oneofs_by_name['address'].fields.append(
  _CLICKHOUSECONNECTIONOPTIONS.fields_by_name['on_premise'])
_CLICKHOUSECONNECTIONOPTIONS.fields_by_name['on_premise'].containing_oneof = _CLICKHOUSECONNECTIONOPTIONS.oneofs_by_name['address']
_CLICKHOUSECONNECTION.fields_by_name['connection_options'].message_type = _CLICKHOUSECONNECTIONOPTIONS
_CLICKHOUSECONNECTION.oneofs_by_name['connection'].fields.append(
  _CLICKHOUSECONNECTION.fields_by_name['connection_options'])
_CLICKHOUSECONNECTION.fields_by_name['connection_options'].containing_oneof = _CLICKHOUSECONNECTION.oneofs_by_name['connection']
_CLICKHOUSESHARDING_COLUMNVALUEHASH.containing_type = _CLICKHOUSESHARDING
_CLICKHOUSESHARDING_COLUMNVALUEMAPPING_VALUETOSHARD.fields_by_name['column_value'].message_type = yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2._COLUMNVALUE
_CLICKHOUSESHARDING_COLUMNVALUEMAPPING_VALUETOSHARD.containing_type = _CLICKHOUSESHARDING_COLUMNVALUEMAPPING
_CLICKHOUSESHARDING_COLUMNVALUEMAPPING.fields_by_name['mapping'].message_type = _CLICKHOUSESHARDING_COLUMNVALUEMAPPING_VALUETOSHARD
_CLICKHOUSESHARDING_COLUMNVALUEMAPPING.containing_type = _CLICKHOUSESHARDING
_CLICKHOUSESHARDING.fields_by_name['column_value_hash'].message_type = _CLICKHOUSESHARDING_COLUMNVALUEHASH
_CLICKHOUSESHARDING.fields_by_name['custom_mapping'].message_type = _CLICKHOUSESHARDING_COLUMNVALUEMAPPING
_CLICKHOUSESHARDING.fields_by_name['transfer_id'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_CLICKHOUSESHARDING.oneofs_by_name['sharding'].fields.append(
  _CLICKHOUSESHARDING.fields_by_name['column_value_hash'])
_CLICKHOUSESHARDING.fields_by_name['column_value_hash'].containing_oneof = _CLICKHOUSESHARDING.oneofs_by_name['sharding']
_CLICKHOUSESHARDING.oneofs_by_name['sharding'].fields.append(
  _CLICKHOUSESHARDING.fields_by_name['custom_mapping'])
_CLICKHOUSESHARDING.fields_by_name['custom_mapping'].containing_oneof = _CLICKHOUSESHARDING.oneofs_by_name['sharding']
_CLICKHOUSESHARDING.oneofs_by_name['sharding'].fields.append(
  _CLICKHOUSESHARDING.fields_by_name['transfer_id'])
_CLICKHOUSESHARDING.fields_by_name['transfer_id'].containing_oneof = _CLICKHOUSESHARDING.oneofs_by_name['sharding']
_CLICKHOUSESOURCE.fields_by_name['connection'].message_type = _CLICKHOUSECONNECTION
_CLICKHOUSETARGET.fields_by_name['connection'].message_type = _CLICKHOUSECONNECTION
_CLICKHOUSETARGET.fields_by_name['alt_names'].message_type = yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2._ALTNAME
_CLICKHOUSETARGET.fields_by_name['sharding'].message_type = _CLICKHOUSESHARDING
_CLICKHOUSETARGET.fields_by_name['cleanup_policy'].enum_type = _CLICKHOUSECLEANUPPOLICY
DESCRIPTOR.message_types_by_name['ClickhouseShard'] = _CLICKHOUSESHARD
DESCRIPTOR.message_types_by_name['OnPremiseClickhouse'] = _ONPREMISECLICKHOUSE
DESCRIPTOR.message_types_by_name['ClickhouseConnectionOptions'] = _CLICKHOUSECONNECTIONOPTIONS
DESCRIPTOR.message_types_by_name['ClickhouseConnection'] = _CLICKHOUSECONNECTION
DESCRIPTOR.message_types_by_name['ClickhouseSharding'] = _CLICKHOUSESHARDING
DESCRIPTOR.message_types_by_name['ClickhouseSource'] = _CLICKHOUSESOURCE
DESCRIPTOR.message_types_by_name['ClickhouseTarget'] = _CLICKHOUSETARGET
DESCRIPTOR.enum_types_by_name['ClickhouseCleanupPolicy'] = _CLICKHOUSECLEANUPPOLICY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClickhouseShard = _reflection.GeneratedProtocolMessageType('ClickhouseShard', (_message.Message,), {
  'DESCRIPTOR' : _CLICKHOUSESHARD,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.clickhouse_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.ClickhouseShard)
  })
_sym_db.RegisterMessage(ClickhouseShard)

OnPremiseClickhouse = _reflection.GeneratedProtocolMessageType('OnPremiseClickhouse', (_message.Message,), {
  'DESCRIPTOR' : _ONPREMISECLICKHOUSE,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.clickhouse_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.OnPremiseClickhouse)
  })
_sym_db.RegisterMessage(OnPremiseClickhouse)

ClickhouseConnectionOptions = _reflection.GeneratedProtocolMessageType('ClickhouseConnectionOptions', (_message.Message,), {
  'DESCRIPTOR' : _CLICKHOUSECONNECTIONOPTIONS,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.clickhouse_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.ClickhouseConnectionOptions)
  })
_sym_db.RegisterMessage(ClickhouseConnectionOptions)

ClickhouseConnection = _reflection.GeneratedProtocolMessageType('ClickhouseConnection', (_message.Message,), {
  'DESCRIPTOR' : _CLICKHOUSECONNECTION,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.clickhouse_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.ClickhouseConnection)
  })
_sym_db.RegisterMessage(ClickhouseConnection)

ClickhouseSharding = _reflection.GeneratedProtocolMessageType('ClickhouseSharding', (_message.Message,), {

  'ColumnValueHash' : _reflection.GeneratedProtocolMessageType('ColumnValueHash', (_message.Message,), {
    'DESCRIPTOR' : _CLICKHOUSESHARDING_COLUMNVALUEHASH,
    '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.clickhouse_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.ColumnValueHash)
    })
  ,

  'ColumnValueMapping' : _reflection.GeneratedProtocolMessageType('ColumnValueMapping', (_message.Message,), {

    'ValueToShard' : _reflection.GeneratedProtocolMessageType('ValueToShard', (_message.Message,), {
      'DESCRIPTOR' : _CLICKHOUSESHARDING_COLUMNVALUEMAPPING_VALUETOSHARD,
      '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.clickhouse_pb2'
      # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.ColumnValueMapping.ValueToShard)
      })
    ,
    'DESCRIPTOR' : _CLICKHOUSESHARDING_COLUMNVALUEMAPPING,
    '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.clickhouse_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.ColumnValueMapping)
    })
  ,
  'DESCRIPTOR' : _CLICKHOUSESHARDING,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.clickhouse_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding)
  })
_sym_db.RegisterMessage(ClickhouseSharding)
_sym_db.RegisterMessage(ClickhouseSharding.ColumnValueHash)
_sym_db.RegisterMessage(ClickhouseSharding.ColumnValueMapping)
_sym_db.RegisterMessage(ClickhouseSharding.ColumnValueMapping.ValueToShard)

ClickhouseSource = _reflection.GeneratedProtocolMessageType('ClickhouseSource', (_message.Message,), {
  'DESCRIPTOR' : _CLICKHOUSESOURCE,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.clickhouse_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.ClickhouseSource)
  })
_sym_db.RegisterMessage(ClickhouseSource)

ClickhouseTarget = _reflection.GeneratedProtocolMessageType('ClickhouseTarget', (_message.Message,), {
  'DESCRIPTOR' : _CLICKHOUSETARGET,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.clickhouse_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.ClickhouseTarget)
  })
_sym_db.RegisterMessage(ClickhouseTarget)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
