# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datatransfer/v1/endpoint/ydb.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/datatransfer/v1/endpoint/ydb.proto',
  package='yandex.cloud.datatransfer.v1.endpoint',
  syntax='proto3',
  serialized_options=b'\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\252\002%Yandex.Cloud.Datatransfer.V1.EndPoint',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/yandex/cloud/datatransfer/v1/endpoint/ydb.proto\x12%yandex.cloud.datatransfer.v1.endpoint\"\x9e\x01\n\tYdbSource\x12\x10\n\x08\x64\x61tabase\x18\x01 \x01(\t\x12\x10\n\x08instance\x18\x02 \x01(\t\x12\x1a\n\x12service_account_id\x18\x06 \x01(\t\x12\r\n\x05paths\x18\x05 \x03(\t\x12\x11\n\tsubnet_id\x18\x1e \x01(\t\x12\x17\n\x0fsecurity_groups\x18\" \x03(\t\x12\x16\n\x0esa_key_content\x18! \x01(\t\"\xee\x01\n\tYdbTarget\x12\x10\n\x08\x64\x61tabase\x18\x01 \x01(\t\x12\x10\n\x08instance\x18\x02 \x01(\t\x12\x1a\n\x12service_account_id\x18\x0b \x01(\t\x12\x0c\n\x04path\x18\n \x01(\t\x12\x11\n\tsubnet_id\x18\x1e \x01(\t\x12\x17\n\x0fsecurity_groups\x18! \x03(\t\x12\x16\n\x0esa_key_content\x18  \x01(\t\x12O\n\x0e\x63leanup_policy\x18\x15 \x01(\x0e\x32\x37.yandex.cloud.datatransfer.v1.endpoint.YdbCleanupPolicy*t\n\x10YdbCleanupPolicy\x12\"\n\x1eYDB_CLEANUP_POLICY_UNSPECIFIED\x10\x00\x12\x1f\n\x1bYDB_CLEANUP_POLICY_DISABLED\x10\x01\x12\x1b\n\x17YDB_CLEANUP_POLICY_DROP\x10\x02\x42\xa7\x01\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\xaa\x02%Yandex.Cloud.Datatransfer.V1.EndPointb\x06proto3'
)

_YDBCLEANUPPOLICY = _descriptor.EnumDescriptor(
  name='YdbCleanupPolicy',
  full_name='yandex.cloud.datatransfer.v1.endpoint.YdbCleanupPolicy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='YDB_CLEANUP_POLICY_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YDB_CLEANUP_POLICY_DISABLED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YDB_CLEANUP_POLICY_DROP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=492,
  serialized_end=608,
)
_sym_db.RegisterEnumDescriptor(_YDBCLEANUPPOLICY)

YdbCleanupPolicy = enum_type_wrapper.EnumTypeWrapper(_YDBCLEANUPPOLICY)
YDB_CLEANUP_POLICY_UNSPECIFIED = 0
YDB_CLEANUP_POLICY_DISABLED = 1
YDB_CLEANUP_POLICY_DROP = 2



_YDBSOURCE = _descriptor.Descriptor(
  name='YdbSource',
  full_name='yandex.cloud.datatransfer.v1.endpoint.YdbSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='database', full_name='yandex.cloud.datatransfer.v1.endpoint.YdbSource.database', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instance', full_name='yandex.cloud.datatransfer.v1.endpoint.YdbSource.instance', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.datatransfer.v1.endpoint.YdbSource.service_account_id', index=2,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='paths', full_name='yandex.cloud.datatransfer.v1.endpoint.YdbSource.paths', index=3,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.datatransfer.v1.endpoint.YdbSource.subnet_id', index=4,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_groups', full_name='yandex.cloud.datatransfer.v1.endpoint.YdbSource.security_groups', index=5,
      number=34, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sa_key_content', full_name='yandex.cloud.datatransfer.v1.endpoint.YdbSource.sa_key_content', index=6,
      number=33, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=91,
  serialized_end=249,
)


_YDBTARGET = _descriptor.Descriptor(
  name='YdbTarget',
  full_name='yandex.cloud.datatransfer.v1.endpoint.YdbTarget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='database', full_name='yandex.cloud.datatransfer.v1.endpoint.YdbTarget.database', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instance', full_name='yandex.cloud.datatransfer.v1.endpoint.YdbTarget.instance', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.datatransfer.v1.endpoint.YdbTarget.service_account_id', index=2,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='yandex.cloud.datatransfer.v1.endpoint.YdbTarget.path', index=3,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.datatransfer.v1.endpoint.YdbTarget.subnet_id', index=4,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_groups', full_name='yandex.cloud.datatransfer.v1.endpoint.YdbTarget.security_groups', index=5,
      number=33, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sa_key_content', full_name='yandex.cloud.datatransfer.v1.endpoint.YdbTarget.sa_key_content', index=6,
      number=32, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cleanup_policy', full_name='yandex.cloud.datatransfer.v1.endpoint.YdbTarget.cleanup_policy', index=7,
      number=21, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=490,
)

_YDBTARGET.fields_by_name['cleanup_policy'].enum_type = _YDBCLEANUPPOLICY
DESCRIPTOR.message_types_by_name['YdbSource'] = _YDBSOURCE
DESCRIPTOR.message_types_by_name['YdbTarget'] = _YDBTARGET
DESCRIPTOR.enum_types_by_name['YdbCleanupPolicy'] = _YDBCLEANUPPOLICY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

YdbSource = _reflection.GeneratedProtocolMessageType('YdbSource', (_message.Message,), {
  'DESCRIPTOR' : _YDBSOURCE,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.ydb_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.YdbSource)
  })
_sym_db.RegisterMessage(YdbSource)

YdbTarget = _reflection.GeneratedProtocolMessageType('YdbTarget', (_message.Message,), {
  'DESCRIPTOR' : _YDBTARGET,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.ydb_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.YdbTarget)
  })
_sym_db.RegisterMessage(YdbTarget)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
