# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.lockbox.v1 import secret_pb2 as yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__pb2
from yandex.cloud.lockbox.v1 import secret_service_pb2 as yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class SecretServiceStub(object):
    """A set of methods for managing secrets.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.lockbox.v1.SecretService/Get',
                request_serializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.GetSecretRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__pb2.Secret.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.lockbox.v1.SecretService/List',
                request_serializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListSecretsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListSecretsResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/yandex.cloud.lockbox.v1.SecretService/Create',
                request_serializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.CreateSecretRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/yandex.cloud.lockbox.v1.SecretService/Update',
                request_serializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.UpdateSecretRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/yandex.cloud.lockbox.v1.SecretService/Delete',
                request_serializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.DeleteSecretRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Activate = channel.unary_unary(
                '/yandex.cloud.lockbox.v1.SecretService/Activate',
                request_serializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ActivateSecretRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Deactivate = channel.unary_unary(
                '/yandex.cloud.lockbox.v1.SecretService/Deactivate',
                request_serializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.DeactivateSecretRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListVersions = channel.unary_unary(
                '/yandex.cloud.lockbox.v1.SecretService/ListVersions',
                request_serializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListVersionsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListVersionsResponse.FromString,
                )
        self.AddVersion = channel.unary_unary(
                '/yandex.cloud.lockbox.v1.SecretService/AddVersion',
                request_serializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.AddVersionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ScheduleVersionDestruction = channel.unary_unary(
                '/yandex.cloud.lockbox.v1.SecretService/ScheduleVersionDestruction',
                request_serializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ScheduleVersionDestructionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.CancelVersionDestruction = channel.unary_unary(
                '/yandex.cloud.lockbox.v1.SecretService/CancelVersionDestruction',
                request_serializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.CancelVersionDestructionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListOperations = channel.unary_unary(
                '/yandex.cloud.lockbox.v1.SecretService/ListOperations',
                request_serializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListSecretOperationsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListSecretOperationsResponse.FromString,
                )
        self.ListAccessBindings = channel.unary_unary(
                '/yandex.cloud.lockbox.v1.SecretService/ListAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
                )
        self.SetAccessBindings = channel.unary_unary(
                '/yandex.cloud.lockbox.v1.SecretService/SetAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.UpdateAccessBindings = channel.unary_unary(
                '/yandex.cloud.lockbox.v1.SecretService/UpdateAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )


class SecretServiceServicer(object):
    """A set of methods for managing secrets.
    """

    def Get(self, request, context):
        """Returns the specified secret.

        To get the list of all available secrets, make a [List] request.
        Use [PayloadService.Get] to get the payload (confidential data themselves) of the secret.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of secrets in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a secret in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the specified secret.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified secret.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Activate(self, request, context):
        """Activates the specified secret.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Deactivate(self, request, context):
        """Deactivates the specified secret.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListVersions(self, request, context):
        """Retrieves the list of versions of the specified secret.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddVersion(self, request, context):
        """Adds new version based on a previous one.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ScheduleVersionDestruction(self, request, context):
        """Schedules the specified version for destruction.

        Scheduled destruction can be cancelled with the [SecretService.CancelVersionDestruction] method.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelVersionDestruction(self, request, context):
        """Cancels previously scheduled version destruction, if the version hasn't been destroyed yet.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOperations(self, request, context):
        """Lists operations for the specified secret.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAccessBindings(self, request, context):
        """Lists existing access bindings for the specified secret.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAccessBindings(self, request, context):
        """Sets access bindings for the secret.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccessBindings(self, request, context):
        """Updates access bindings for the secret.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SecretServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.GetSecretRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__pb2.Secret.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListSecretsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListSecretsResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.CreateSecretRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.UpdateSecretRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.DeleteSecretRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Activate': grpc.unary_unary_rpc_method_handler(
                    servicer.Activate,
                    request_deserializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ActivateSecretRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Deactivate': grpc.unary_unary_rpc_method_handler(
                    servicer.Deactivate,
                    request_deserializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.DeactivateSecretRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListVersions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListVersions,
                    request_deserializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListVersionsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListVersionsResponse.SerializeToString,
            ),
            'AddVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.AddVersion,
                    request_deserializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.AddVersionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ScheduleVersionDestruction': grpc.unary_unary_rpc_method_handler(
                    servicer.ScheduleVersionDestruction,
                    request_deserializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ScheduleVersionDestructionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'CancelVersionDestruction': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelVersionDestruction,
                    request_deserializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.CancelVersionDestructionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListOperations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOperations,
                    request_deserializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListSecretOperationsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListSecretOperationsResponse.SerializeToString,
            ),
            'ListAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.SerializeToString,
            ),
            'SetAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.lockbox.v1.SecretService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SecretService(object):
    """A set of methods for managing secrets.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.lockbox.v1.SecretService/Get',
            yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.GetSecretRequest.SerializeToString,
            yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__pb2.Secret.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.lockbox.v1.SecretService/List',
            yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListSecretsRequest.SerializeToString,
            yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListSecretsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.lockbox.v1.SecretService/Create',
            yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.CreateSecretRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.lockbox.v1.SecretService/Update',
            yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.UpdateSecretRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.lockbox.v1.SecretService/Delete',
            yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.DeleteSecretRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Activate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.lockbox.v1.SecretService/Activate',
            yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ActivateSecretRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Deactivate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.lockbox.v1.SecretService/Deactivate',
            yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.DeactivateSecretRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListVersions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.lockbox.v1.SecretService/ListVersions',
            yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListVersionsRequest.SerializeToString,
            yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListVersionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.lockbox.v1.SecretService/AddVersion',
            yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.AddVersionRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ScheduleVersionDestruction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.lockbox.v1.SecretService/ScheduleVersionDestruction',
            yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ScheduleVersionDestructionRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelVersionDestruction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.lockbox.v1.SecretService/CancelVersionDestruction',
            yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.CancelVersionDestructionRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOperations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.lockbox.v1.SecretService/ListOperations',
            yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListSecretOperationsRequest.SerializeToString,
            yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListSecretOperationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.lockbox.v1.SecretService/ListAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.lockbox.v1.SecretService/SetAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.lockbox.v1.SecretService/UpdateAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
