# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/compute/v1/placement_group_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.compute.v1 import instance_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2
from yandex.cloud.compute.v1 import placement_group_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_placement__group__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/compute/v1/placement_group_service.proto',
  package='yandex.cloud.compute.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n5yandex/cloud/compute/v1/placement_group_service.proto\x12\x17yandex.cloud.compute.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/compute/v1/instance.proto\x1a-yandex/cloud/compute/v1/placement_group.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"6\n\x18GetPlacementGroupRequest\x12\x1a\n\x12placement_group_id\x18\x01 \x01(\t\"f\n\x1aListPlacementGroupsRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\"y\n\x1bListPlacementGroupsResponse\x12\x41\n\x10placement_groups\x18\x01 \x03(\x0b\x32\'.yandex.cloud.compute.v1.PlacementGroup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xa4\x03\n\x1b\x43reatePlacementGroupRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12P\n\x06labels\x18\x04 \x03(\x0b\x32@.yandex.cloud.compute.v1.CreatePlacementGroupRequest.LabelsEntry\x12U\n\x19spread_placement_strategy\x18\x05 \x01(\x0b\x32\x30.yandex.cloud.compute.v1.SpreadPlacementStrategyH\x00\x12[\n\x1cpartition_placement_strategy\x18\x06 \x01(\x0b\x32\x33.yandex.cloud.compute.v1.PartitionPlacementStrategyH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x1a\n\x12placement_strategy\x12\x04\xc0\xc1\x31\x01\":\n\x1c\x43reatePlacementGroupMetadata\x12\x1a\n\x12placement_group_id\x18\x01 \x01(\t\"\x8e\x02\n\x1bUpdatePlacementGroupRequest\x12\x1a\n\x12placement_group_id\x18\x01 \x01(\t\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12P\n\x06labels\x18\x05 \x03(\x0b\x32@.yandex.cloud.compute.v1.UpdatePlacementGroupRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\":\n\x1cUpdatePlacementGroupMetadata\x12\x1a\n\x12placement_group_id\x18\x01 \x01(\t\"9\n\x1b\x44\x65letePlacementGroupRequest\x12\x1a\n\x12placement_group_id\x18\x01 \x01(\t\":\n\x1c\x44\x65letePlacementGroupMetadata\x12\x1a\n\x12placement_group_id\x18\x01 \x01(\t\"g\n\"ListPlacementGroupInstancesRequest\x12\x1a\n\x12placement_group_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"t\n#ListPlacementGroupInstancesResponse\x12\x34\n\tinstances\x18\x01 \x03(\x0b\x32!.yandex.cloud.compute.v1.Instance\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"h\n#ListPlacementGroupOperationsRequest\x12\x1a\n\x12placement_group_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"v\n$ListPlacementGroupOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xdc\n\n\x15PlacementGroupService\x12\x9b\x01\n\x03Get\x12\x31.yandex.cloud.compute.v1.GetPlacementGroupRequest\x1a\'.yandex.cloud.compute.v1.PlacementGroup\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/compute/v1/placementGroups/{placement_group_id}\x12\x96\x01\n\x04List\x12\x33.yandex.cloud.compute.v1.ListPlacementGroupsRequest\x1a\x34.yandex.cloud.compute.v1.ListPlacementGroupsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/compute/v1/placementGroups\x12\xbb\x01\n\x06\x43reate\x12\x34.yandex.cloud.compute.v1.CreatePlacementGroupRequest\x1a!.yandex.cloud.operation.Operation\"X\x82\xd3\xe4\x93\x02 \"\x1b/compute/v1/placementGroups:\x01*\xb2\xd2*.\n\x1c\x43reatePlacementGroupMetadata\x12\x0ePlacementGroup\x12\xd0\x01\n\x06Update\x12\x34.yandex.cloud.compute.v1.UpdatePlacementGroupRequest\x1a!.yandex.cloud.operation.Operation\"m\x82\xd3\xe4\x93\x02\x35\x32\x30/compute/v1/placementGroups/{placement_group_id}:\x01*\xb2\xd2*.\n\x1cUpdatePlacementGroupMetadata\x12\x0ePlacementGroup\x12\xd4\x01\n\x06\x44\x65lete\x12\x34.yandex.cloud.compute.v1.DeletePlacementGroupRequest\x1a!.yandex.cloud.operation.Operation\"q\x82\xd3\xe4\x93\x02\x32*0/compute/v1/placementGroups/{placement_group_id}\xb2\xd2*5\n\x1c\x44\x65letePlacementGroupMetadata\x12\x15google.protobuf.Empty\x12\xce\x01\n\rListInstances\x12;.yandex.cloud.compute.v1.ListPlacementGroupInstancesRequest\x1a<.yandex.cloud.compute.v1.ListPlacementGroupInstancesResponse\"B\x82\xd3\xe4\x93\x02<\x12:/compute/v1/placementGroups/{placement_group_id}/instances\x12\xd2\x01\n\x0eListOperations\x12<.yandex.cloud.compute.v1.ListPlacementGroupOperationsRequest\x1a=.yandex.cloud.compute.v1.ListPlacementGroupOperationsResponse\"C\x82\xd3\xe4\x93\x02=\x12;/compute/v1/placementGroups/{placement_group_id}/operationsBb\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2.DESCRIPTOR,yandex_dot_cloud_dot_compute_dot_v1_dot_placement__group__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETPLACEMENTGROUPREQUEST = _descriptor.Descriptor(
  name='GetPlacementGroupRequest',
  full_name='yandex.cloud.compute.v1.GetPlacementGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_group_id', full_name='yandex.cloud.compute.v1.GetPlacementGroupRequest.placement_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=338,
  serialized_end=392,
)


_LISTPLACEMENTGROUPSREQUEST = _descriptor.Descriptor(
  name='ListPlacementGroupsRequest',
  full_name='yandex.cloud.compute.v1.ListPlacementGroupsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.compute.v1.ListPlacementGroupsRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.compute.v1.ListPlacementGroupsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.compute.v1.ListPlacementGroupsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.compute.v1.ListPlacementGroupsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=394,
  serialized_end=496,
)


_LISTPLACEMENTGROUPSRESPONSE = _descriptor.Descriptor(
  name='ListPlacementGroupsResponse',
  full_name='yandex.cloud.compute.v1.ListPlacementGroupsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_groups', full_name='yandex.cloud.compute.v1.ListPlacementGroupsResponse.placement_groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.compute.v1.ListPlacementGroupsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=498,
  serialized_end=619,
)


_CREATEPLACEMENTGROUPREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.compute.v1.CreatePlacementGroupRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.CreatePlacementGroupRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.CreatePlacementGroupRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=969,
  serialized_end=1014,
)

_CREATEPLACEMENTGROUPREQUEST = _descriptor.Descriptor(
  name='CreatePlacementGroupRequest',
  full_name='yandex.cloud.compute.v1.CreatePlacementGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.compute.v1.CreatePlacementGroupRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.compute.v1.CreatePlacementGroupRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.compute.v1.CreatePlacementGroupRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.compute.v1.CreatePlacementGroupRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spread_placement_strategy', full_name='yandex.cloud.compute.v1.CreatePlacementGroupRequest.spread_placement_strategy', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_placement_strategy', full_name='yandex.cloud.compute.v1.CreatePlacementGroupRequest.partition_placement_strategy', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATEPLACEMENTGROUPREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='placement_strategy', full_name='yandex.cloud.compute.v1.CreatePlacementGroupRequest.placement_strategy',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=622,
  serialized_end=1042,
)


_CREATEPLACEMENTGROUPMETADATA = _descriptor.Descriptor(
  name='CreatePlacementGroupMetadata',
  full_name='yandex.cloud.compute.v1.CreatePlacementGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_group_id', full_name='yandex.cloud.compute.v1.CreatePlacementGroupMetadata.placement_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1044,
  serialized_end=1102,
)


_UPDATEPLACEMENTGROUPREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.compute.v1.UpdatePlacementGroupRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.UpdatePlacementGroupRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.UpdatePlacementGroupRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=969,
  serialized_end=1014,
)

_UPDATEPLACEMENTGROUPREQUEST = _descriptor.Descriptor(
  name='UpdatePlacementGroupRequest',
  full_name='yandex.cloud.compute.v1.UpdatePlacementGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_group_id', full_name='yandex.cloud.compute.v1.UpdatePlacementGroupRequest.placement_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.compute.v1.UpdatePlacementGroupRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.compute.v1.UpdatePlacementGroupRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.compute.v1.UpdatePlacementGroupRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.compute.v1.UpdatePlacementGroupRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATEPLACEMENTGROUPREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1105,
  serialized_end=1375,
)


_UPDATEPLACEMENTGROUPMETADATA = _descriptor.Descriptor(
  name='UpdatePlacementGroupMetadata',
  full_name='yandex.cloud.compute.v1.UpdatePlacementGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_group_id', full_name='yandex.cloud.compute.v1.UpdatePlacementGroupMetadata.placement_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1377,
  serialized_end=1435,
)


_DELETEPLACEMENTGROUPREQUEST = _descriptor.Descriptor(
  name='DeletePlacementGroupRequest',
  full_name='yandex.cloud.compute.v1.DeletePlacementGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_group_id', full_name='yandex.cloud.compute.v1.DeletePlacementGroupRequest.placement_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1437,
  serialized_end=1494,
)


_DELETEPLACEMENTGROUPMETADATA = _descriptor.Descriptor(
  name='DeletePlacementGroupMetadata',
  full_name='yandex.cloud.compute.v1.DeletePlacementGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_group_id', full_name='yandex.cloud.compute.v1.DeletePlacementGroupMetadata.placement_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1496,
  serialized_end=1554,
)


_LISTPLACEMENTGROUPINSTANCESREQUEST = _descriptor.Descriptor(
  name='ListPlacementGroupInstancesRequest',
  full_name='yandex.cloud.compute.v1.ListPlacementGroupInstancesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_group_id', full_name='yandex.cloud.compute.v1.ListPlacementGroupInstancesRequest.placement_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.compute.v1.ListPlacementGroupInstancesRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.compute.v1.ListPlacementGroupInstancesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1556,
  serialized_end=1659,
)


_LISTPLACEMENTGROUPINSTANCESRESPONSE = _descriptor.Descriptor(
  name='ListPlacementGroupInstancesResponse',
  full_name='yandex.cloud.compute.v1.ListPlacementGroupInstancesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instances', full_name='yandex.cloud.compute.v1.ListPlacementGroupInstancesResponse.instances', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.compute.v1.ListPlacementGroupInstancesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1661,
  serialized_end=1777,
)


_LISTPLACEMENTGROUPOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListPlacementGroupOperationsRequest',
  full_name='yandex.cloud.compute.v1.ListPlacementGroupOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_group_id', full_name='yandex.cloud.compute.v1.ListPlacementGroupOperationsRequest.placement_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.compute.v1.ListPlacementGroupOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.compute.v1.ListPlacementGroupOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1779,
  serialized_end=1883,
)


_LISTPLACEMENTGROUPOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListPlacementGroupOperationsResponse',
  full_name='yandex.cloud.compute.v1.ListPlacementGroupOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.compute.v1.ListPlacementGroupOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.compute.v1.ListPlacementGroupOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1885,
  serialized_end=2003,
)

_LISTPLACEMENTGROUPSRESPONSE.fields_by_name['placement_groups'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_placement__group__pb2._PLACEMENTGROUP
_CREATEPLACEMENTGROUPREQUEST_LABELSENTRY.containing_type = _CREATEPLACEMENTGROUPREQUEST
_CREATEPLACEMENTGROUPREQUEST.fields_by_name['labels'].message_type = _CREATEPLACEMENTGROUPREQUEST_LABELSENTRY
_CREATEPLACEMENTGROUPREQUEST.fields_by_name['spread_placement_strategy'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_placement__group__pb2._SPREADPLACEMENTSTRATEGY
_CREATEPLACEMENTGROUPREQUEST.fields_by_name['partition_placement_strategy'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_placement__group__pb2._PARTITIONPLACEMENTSTRATEGY
_CREATEPLACEMENTGROUPREQUEST.oneofs_by_name['placement_strategy'].fields.append(
  _CREATEPLACEMENTGROUPREQUEST.fields_by_name['spread_placement_strategy'])
_CREATEPLACEMENTGROUPREQUEST.fields_by_name['spread_placement_strategy'].containing_oneof = _CREATEPLACEMENTGROUPREQUEST.oneofs_by_name['placement_strategy']
_CREATEPLACEMENTGROUPREQUEST.oneofs_by_name['placement_strategy'].fields.append(
  _CREATEPLACEMENTGROUPREQUEST.fields_by_name['partition_placement_strategy'])
_CREATEPLACEMENTGROUPREQUEST.fields_by_name['partition_placement_strategy'].containing_oneof = _CREATEPLACEMENTGROUPREQUEST.oneofs_by_name['placement_strategy']
_UPDATEPLACEMENTGROUPREQUEST_LABELSENTRY.containing_type = _UPDATEPLACEMENTGROUPREQUEST
_UPDATEPLACEMENTGROUPREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEPLACEMENTGROUPREQUEST.fields_by_name['labels'].message_type = _UPDATEPLACEMENTGROUPREQUEST_LABELSENTRY
_LISTPLACEMENTGROUPINSTANCESRESPONSE.fields_by_name['instances'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2._INSTANCE
_LISTPLACEMENTGROUPOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['GetPlacementGroupRequest'] = _GETPLACEMENTGROUPREQUEST
DESCRIPTOR.message_types_by_name['ListPlacementGroupsRequest'] = _LISTPLACEMENTGROUPSREQUEST
DESCRIPTOR.message_types_by_name['ListPlacementGroupsResponse'] = _LISTPLACEMENTGROUPSRESPONSE
DESCRIPTOR.message_types_by_name['CreatePlacementGroupRequest'] = _CREATEPLACEMENTGROUPREQUEST
DESCRIPTOR.message_types_by_name['CreatePlacementGroupMetadata'] = _CREATEPLACEMENTGROUPMETADATA
DESCRIPTOR.message_types_by_name['UpdatePlacementGroupRequest'] = _UPDATEPLACEMENTGROUPREQUEST
DESCRIPTOR.message_types_by_name['UpdatePlacementGroupMetadata'] = _UPDATEPLACEMENTGROUPMETADATA
DESCRIPTOR.message_types_by_name['DeletePlacementGroupRequest'] = _DELETEPLACEMENTGROUPREQUEST
DESCRIPTOR.message_types_by_name['DeletePlacementGroupMetadata'] = _DELETEPLACEMENTGROUPMETADATA
DESCRIPTOR.message_types_by_name['ListPlacementGroupInstancesRequest'] = _LISTPLACEMENTGROUPINSTANCESREQUEST
DESCRIPTOR.message_types_by_name['ListPlacementGroupInstancesResponse'] = _LISTPLACEMENTGROUPINSTANCESRESPONSE
DESCRIPTOR.message_types_by_name['ListPlacementGroupOperationsRequest'] = _LISTPLACEMENTGROUPOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListPlacementGroupOperationsResponse'] = _LISTPLACEMENTGROUPOPERATIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetPlacementGroupRequest = _reflection.GeneratedProtocolMessageType('GetPlacementGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPLACEMENTGROUPREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.placement_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.GetPlacementGroupRequest)
  })
_sym_db.RegisterMessage(GetPlacementGroupRequest)

ListPlacementGroupsRequest = _reflection.GeneratedProtocolMessageType('ListPlacementGroupsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPLACEMENTGROUPSREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.placement_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListPlacementGroupsRequest)
  })
_sym_db.RegisterMessage(ListPlacementGroupsRequest)

ListPlacementGroupsResponse = _reflection.GeneratedProtocolMessageType('ListPlacementGroupsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPLACEMENTGROUPSRESPONSE,
  '__module__' : 'yandex.cloud.compute.v1.placement_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListPlacementGroupsResponse)
  })
_sym_db.RegisterMessage(ListPlacementGroupsResponse)

CreatePlacementGroupRequest = _reflection.GeneratedProtocolMessageType('CreatePlacementGroupRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEPLACEMENTGROUPREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.compute.v1.placement_group_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.CreatePlacementGroupRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEPLACEMENTGROUPREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.placement_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.CreatePlacementGroupRequest)
  })
_sym_db.RegisterMessage(CreatePlacementGroupRequest)
_sym_db.RegisterMessage(CreatePlacementGroupRequest.LabelsEntry)

CreatePlacementGroupMetadata = _reflection.GeneratedProtocolMessageType('CreatePlacementGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPLACEMENTGROUPMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.placement_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.CreatePlacementGroupMetadata)
  })
_sym_db.RegisterMessage(CreatePlacementGroupMetadata)

UpdatePlacementGroupRequest = _reflection.GeneratedProtocolMessageType('UpdatePlacementGroupRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEPLACEMENTGROUPREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.compute.v1.placement_group_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdatePlacementGroupRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATEPLACEMENTGROUPREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.placement_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdatePlacementGroupRequest)
  })
_sym_db.RegisterMessage(UpdatePlacementGroupRequest)
_sym_db.RegisterMessage(UpdatePlacementGroupRequest.LabelsEntry)

UpdatePlacementGroupMetadata = _reflection.GeneratedProtocolMessageType('UpdatePlacementGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPLACEMENTGROUPMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.placement_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdatePlacementGroupMetadata)
  })
_sym_db.RegisterMessage(UpdatePlacementGroupMetadata)

DeletePlacementGroupRequest = _reflection.GeneratedProtocolMessageType('DeletePlacementGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPLACEMENTGROUPREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.placement_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.DeletePlacementGroupRequest)
  })
_sym_db.RegisterMessage(DeletePlacementGroupRequest)

DeletePlacementGroupMetadata = _reflection.GeneratedProtocolMessageType('DeletePlacementGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPLACEMENTGROUPMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.placement_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.DeletePlacementGroupMetadata)
  })
_sym_db.RegisterMessage(DeletePlacementGroupMetadata)

ListPlacementGroupInstancesRequest = _reflection.GeneratedProtocolMessageType('ListPlacementGroupInstancesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPLACEMENTGROUPINSTANCESREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.placement_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListPlacementGroupInstancesRequest)
  })
_sym_db.RegisterMessage(ListPlacementGroupInstancesRequest)

ListPlacementGroupInstancesResponse = _reflection.GeneratedProtocolMessageType('ListPlacementGroupInstancesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPLACEMENTGROUPINSTANCESRESPONSE,
  '__module__' : 'yandex.cloud.compute.v1.placement_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListPlacementGroupInstancesResponse)
  })
_sym_db.RegisterMessage(ListPlacementGroupInstancesResponse)

ListPlacementGroupOperationsRequest = _reflection.GeneratedProtocolMessageType('ListPlacementGroupOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPLACEMENTGROUPOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.placement_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListPlacementGroupOperationsRequest)
  })
_sym_db.RegisterMessage(ListPlacementGroupOperationsRequest)

ListPlacementGroupOperationsResponse = _reflection.GeneratedProtocolMessageType('ListPlacementGroupOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPLACEMENTGROUPOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.compute.v1.placement_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListPlacementGroupOperationsResponse)
  })
_sym_db.RegisterMessage(ListPlacementGroupOperationsResponse)


DESCRIPTOR._options = None
_CREATEPLACEMENTGROUPREQUEST_LABELSENTRY._options = None
_CREATEPLACEMENTGROUPREQUEST.oneofs_by_name['placement_strategy']._options = None
_UPDATEPLACEMENTGROUPREQUEST_LABELSENTRY._options = None

_PLACEMENTGROUPSERVICE = _descriptor.ServiceDescriptor(
  name='PlacementGroupService',
  full_name='yandex.cloud.compute.v1.PlacementGroupService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2006,
  serialized_end=3378,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.compute.v1.PlacementGroupService.Get',
    index=0,
    containing_service=None,
    input_type=_GETPLACEMENTGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_compute_dot_v1_dot_placement__group__pb2._PLACEMENTGROUP,
    serialized_options=b'\202\323\344\223\0022\0220/compute/v1/placementGroups/{placement_group_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.compute.v1.PlacementGroupService.List',
    index=1,
    containing_service=None,
    input_type=_LISTPLACEMENTGROUPSREQUEST,
    output_type=_LISTPLACEMENTGROUPSRESPONSE,
    serialized_options=b'\202\323\344\223\002\035\022\033/compute/v1/placementGroups',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.compute.v1.PlacementGroupService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEPLACEMENTGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002 \"\033/compute/v1/placementGroups:\001*\262\322*.\n\034CreatePlacementGroupMetadata\022\016PlacementGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.compute.v1.PlacementGroupService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATEPLACEMENTGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002520/compute/v1/placementGroups/{placement_group_id}:\001*\262\322*.\n\034UpdatePlacementGroupMetadata\022\016PlacementGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.compute.v1.PlacementGroupService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETEPLACEMENTGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0022*0/compute/v1/placementGroups/{placement_group_id}\262\322*5\n\034DeletePlacementGroupMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListInstances',
    full_name='yandex.cloud.compute.v1.PlacementGroupService.ListInstances',
    index=5,
    containing_service=None,
    input_type=_LISTPLACEMENTGROUPINSTANCESREQUEST,
    output_type=_LISTPLACEMENTGROUPINSTANCESRESPONSE,
    serialized_options=b'\202\323\344\223\002<\022:/compute/v1/placementGroups/{placement_group_id}/instances',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.compute.v1.PlacementGroupService.ListOperations',
    index=6,
    containing_service=None,
    input_type=_LISTPLACEMENTGROUPOPERATIONSREQUEST,
    output_type=_LISTPLACEMENTGROUPOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002=\022;/compute/v1/placementGroups/{placement_group_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PLACEMENTGROUPSERVICE)

DESCRIPTOR.services_by_name['PlacementGroupService'] = _PLACEMENTGROUPSERVICE

# @@protoc_insertion_point(module_scope)
