# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/agent/v1/agent.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/loadtesting/agent/v1/agent.proto',
  package='yandex.cloud.loadtesting.agent.v1',
  syntax='proto3',
  serialized_options=b'\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agent',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-yandex/cloud/loadtesting/agent/v1/agent.proto\x12!yandex.cloud.loadtesting.agent.v1\"\x1b\n\rAgentInstance\x12\n\n\x02id\x18\x01 \x01(\tBt\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agentb\x06proto3'
)




_AGENTINSTANCE = _descriptor.Descriptor(
  name='AgentInstance',
  full_name='yandex.cloud.loadtesting.agent.v1.AgentInstance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.loadtesting.agent.v1.AgentInstance.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=84,
  serialized_end=111,
)

DESCRIPTOR.message_types_by_name['AgentInstance'] = _AGENTINSTANCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AgentInstance = _reflection.GeneratedProtocolMessageType('AgentInstance', (_message.Message,), {
  'DESCRIPTOR' : _AGENTINSTANCE,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.AgentInstance)
  })
_sym_db.RegisterMessage(AgentInstance)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
