# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/dns/v1/dns_zone.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/dns/v1/dns_zone.proto',
  package='yandex.cloud.dns.v1',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.dns.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/dns/v1;dns',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"yandex/cloud/dns/v1/dns_zone.proto\x12\x13yandex.cloud.dns.v1\x1a\x1dyandex/cloud/validation.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xf8\x02\n\x07\x44nsZone\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x38\n\x06labels\x18\x06 \x03(\x0b\x32(.yandex.cloud.dns.v1.DnsZone.LabelsEntry\x12\x0c\n\x04zone\x18\x07 \x01(\t\x12\x42\n\x12private_visibility\x18\x08 \x01(\x0b\x32&.yandex.cloud.dns.v1.PrivateVisibility\x12@\n\x11public_visibility\x18\t \x01(\x0b\x32%.yandex.cloud.dns.v1.PublicVisibility\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x81\x01\n\tRecordSet\x12\x17\n\x04name\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05\x31-254\x12\x16\n\x04type\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04\x31-20\x12\x1d\n\x03ttl\x18\x03 \x01(\x03\x42\x10\xfa\xc7\x31\x0c\x30-2147483647\x12$\n\x04\x64\x61ta\x18\x04 \x03(\tB\x16\x82\xc8\x31\x05\x31-100\x8a\xc8\x31\x05\x31-255\x90\xc8\x31\x01\"=\n\x11PrivateVisibility\x12(\n\x0bnetwork_ids\x18\x01 \x03(\tB\x13\x82\xc8\x31\x05\x30-100\x8a\xc8\x31\x02\x32\x30\x90\xc8\x31\x01\"\x12\n\x10PublicVisibilityBV\n\x17yandex.cloud.api.dns.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/dns/v1;dnsb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_DNSZONE_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.dns.v1.DnsZone.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.dns.v1.DnsZone.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.dns.v1.DnsZone.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=455,
  serialized_end=500,
)

_DNSZONE = _descriptor.Descriptor(
  name='DnsZone',
  full_name='yandex.cloud.dns.v1.DnsZone',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.dns.v1.DnsZone.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.dns.v1.DnsZone.folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.dns.v1.DnsZone.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.dns.v1.DnsZone.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.dns.v1.DnsZone.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.dns.v1.DnsZone.labels', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zone', full_name='yandex.cloud.dns.v1.DnsZone.zone', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='private_visibility', full_name='yandex.cloud.dns.v1.DnsZone.private_visibility', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='public_visibility', full_name='yandex.cloud.dns.v1.DnsZone.public_visibility', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DNSZONE_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=500,
)


_RECORDSET = _descriptor.Descriptor(
  name='RecordSet',
  full_name='yandex.cloud.dns.v1.RecordSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.dns.v1.RecordSet.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\0051-254', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.dns.v1.RecordSet.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\0041-20', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ttl', full_name='yandex.cloud.dns.v1.RecordSet.ttl', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0140-2147483647', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='yandex.cloud.dns.v1.RecordSet.data', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\0051-100\212\3101\0051-255\220\3101\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=503,
  serialized_end=632,
)


_PRIVATEVISIBILITY = _descriptor.Descriptor(
  name='PrivateVisibility',
  full_name='yandex.cloud.dns.v1.PrivateVisibility',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='network_ids', full_name='yandex.cloud.dns.v1.PrivateVisibility.network_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\0050-100\212\3101\00220\220\3101\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=634,
  serialized_end=695,
)


_PUBLICVISIBILITY = _descriptor.Descriptor(
  name='PublicVisibility',
  full_name='yandex.cloud.dns.v1.PublicVisibility',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=697,
  serialized_end=715,
)

_DNSZONE_LABELSENTRY.containing_type = _DNSZONE
_DNSZONE.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DNSZONE.fields_by_name['labels'].message_type = _DNSZONE_LABELSENTRY
_DNSZONE.fields_by_name['private_visibility'].message_type = _PRIVATEVISIBILITY
_DNSZONE.fields_by_name['public_visibility'].message_type = _PUBLICVISIBILITY
DESCRIPTOR.message_types_by_name['DnsZone'] = _DNSZONE
DESCRIPTOR.message_types_by_name['RecordSet'] = _RECORDSET
DESCRIPTOR.message_types_by_name['PrivateVisibility'] = _PRIVATEVISIBILITY
DESCRIPTOR.message_types_by_name['PublicVisibility'] = _PUBLICVISIBILITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DnsZone = _reflection.GeneratedProtocolMessageType('DnsZone', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DNSZONE_LABELSENTRY,
    '__module__' : 'yandex.cloud.dns.v1.dns_zone_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.dns.v1.DnsZone.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _DNSZONE,
  '__module__' : 'yandex.cloud.dns.v1.dns_zone_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dns.v1.DnsZone)
  })
_sym_db.RegisterMessage(DnsZone)
_sym_db.RegisterMessage(DnsZone.LabelsEntry)

RecordSet = _reflection.GeneratedProtocolMessageType('RecordSet', (_message.Message,), {
  'DESCRIPTOR' : _RECORDSET,
  '__module__' : 'yandex.cloud.dns.v1.dns_zone_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dns.v1.RecordSet)
  })
_sym_db.RegisterMessage(RecordSet)

PrivateVisibility = _reflection.GeneratedProtocolMessageType('PrivateVisibility', (_message.Message,), {
  'DESCRIPTOR' : _PRIVATEVISIBILITY,
  '__module__' : 'yandex.cloud.dns.v1.dns_zone_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dns.v1.PrivateVisibility)
  })
_sym_db.RegisterMessage(PrivateVisibility)

PublicVisibility = _reflection.GeneratedProtocolMessageType('PublicVisibility', (_message.Message,), {
  'DESCRIPTOR' : _PUBLICVISIBILITY,
  '__module__' : 'yandex.cloud.dns.v1.dns_zone_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dns.v1.PublicVisibility)
  })
_sym_db.RegisterMessage(PublicVisibility)


DESCRIPTOR._options = None
_DNSZONE_LABELSENTRY._options = None
_RECORDSET.fields_by_name['name']._options = None
_RECORDSET.fields_by_name['type']._options = None
_RECORDSET.fields_by_name['ttl']._options = None
_RECORDSET.fields_by_name['data']._options = None
_PRIVATEVISIBILITY.fields_by_name['network_ids']._options = None
# @@protoc_insertion_point(module_scope)
