# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/agent/v1/job_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/loadtesting/agent/v1/job_service.proto',
  package='yandex.cloud.loadtesting.agent.v1',
  syntax='proto3',
  serialized_options=b'\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agent',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n3yandex/cloud/loadtesting/agent/v1/job_service.proto\x12!yandex.cloud.loadtesting.agent.v1\x1a\x1cgoogle/api/annotations.proto\"\xe4\x02\n\x03Job\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\t\x12\x35\n\x04\x61mmo\x18\x03 \x01(\x0b\x32\'.yandex.cloud.loadtesting.agent.v1.File\x12\x1c\n\x14logging_log_group_id\x18\x04 \x01(\t\x12\x43\n\ttest_data\x18\x05 \x01(\x0b\x32\x30.yandex.cloud.loadtesting.agent.v1.StorageObject\x12\x46\n\x0c\x64\x61ta_payload\x18\x06 \x03(\x0b\x32\x30.yandex.cloud.loadtesting.agent.v1.TestDataEntry\x12_\n\x18\x61rtifact_upload_settings\x18\x07 \x01(\x0b\x32=.yandex.cloud.loadtesting.agent.v1.TestArtifactUploadSettings\"%\n\x04\x46ile\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\"O\n\rStorageObject\x12\x1d\n\x15object_storage_bucket\x18\x01 \x01(\t\x12\x1f\n\x17object_storage_filename\x18\x02 \x01(\t\"}\n\rTestDataEntry\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0cis_transient\x18\x02 \x01(\x08\x12H\n\x0estorage_object\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.loadtesting.agent.v1.StorageObject\"\x8c\x01\n\x1aTestArtifactUploadSettings\x12\x15\n\routput_bucket\x18\x01 \x01(\t\x12\x13\n\x0boutput_name\x18\x02 \x01(\t\x12\x12\n\nis_archive\x18\x03 \x01(\x08\x12\x16\n\x0e\x66ilter_include\x18\x04 \x03(\t\x12\x16\n\x0e\x66ilter_exclude\x18\x05 \x03(\t\"3\n\x13GetJobTransientFile\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"W\n\rGetJobRequest\x12\x1b\n\x13\x63ompute_instance_id\x18\x01 \x01(\t\x12\x19\n\x11\x61gent_instance_id\x18\x02 \x01(\t\x12\x0e\n\x06job_id\x18\x03 \x01(\t\"\xe9\x02\n\x15\x43laimJobStatusRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12R\n\x06status\x18\x02 \x01(\x0e\x32\x42.yandex.cloud.loadtesting.agent.v1.ClaimJobStatusRequest.JobStatus\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"\xdc\x01\n\tJobStatus\x12\x1a\n\x16JOB_STATUS_UNSPECIFIED\x10\x00\x12\x10\n\x0cPOST_PROCESS\x10\x01\x12\r\n\tINITIATED\x10\x02\x12\r\n\tPREPARING\x10\x03\x12\r\n\tNOT_FOUND\x10\x04\x12\x0b\n\x07RUNNING\x10\x05\x12\r\n\tFINISHING\x10\x06\x12\x0c\n\x08\x46INISHED\x10\x07\x12\x0b\n\x07STOPPED\x10\x08\x12\n\n\x06\x46\x41ILED\x10\t\x12\x0f\n\x0b\x41UTOSTOPPED\x10\n\x12 \n\x1cWAITING_FOR_A_COMMAND_TO_RUN\x10\x0b\"&\n\x16\x43laimJobStatusResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x03\"\"\n\x10JobSignalRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"\xc9\x01\n\x11JobSignalResponse\x12K\n\x06signal\x18\x01 \x01(\x0e\x32;.yandex.cloud.loadtesting.agent.v1.JobSignalResponse.Signal\x12\x15\n\rwait_duration\x18\x02 \x01(\x01\x12\x0e\n\x06run_in\x18\x03 \x01(\x01\"@\n\x06Signal\x12\x16\n\x12SIGNAL_UNSPECIFIED\x10\x00\x12\x08\n\x04STOP\x10\x01\x12\x08\n\x04WAIT\x10\x02\x12\n\n\x06RUN_IN\x10\x03\x32\xfb\x05\n\nJobService\x12\xbe\x01\n\x0b\x43laimStatus\x12\x38.yandex.cloud.loadtesting.agent.v1.ClaimJobStatusRequest\x1a\x39.yandex.cloud.loadtesting.agent.v1.ClaimJobStatusResponse\":\x82\xd3\xe4\x93\x02\x34\"//loadtesting/agent/v1/jobs/{job_id}/claimStatus:\x01*\x12\xc7\x01\n\x03Get\x12\x30.yandex.cloud.loadtesting.agent.v1.GetJobRequest\x1a&.yandex.cloud.loadtesting.agent.v1.Job\"f\x82\xd3\xe4\x93\x02`\x12\x37/loadtesting/agent/v1/agents/{agent_instance_id}/getJobZ%\x12#/loadtesting/agent/v1/jobs/{job_id}\x12\xad\x01\n\tGetSignal\x12\x33.yandex.cloud.loadtesting.agent.v1.JobSignalRequest\x1a\x34.yandex.cloud.loadtesting.agent.v1.JobSignalResponse\"5\x82\xd3\xe4\x93\x02/\x12-/loadtesting/agent/v1/jobs/{job_id}/getSignal\x12\xb1\x01\n\x10GetTransientFile\x12\x36.yandex.cloud.loadtesting.agent.v1.GetJobTransientFile\x1a\'.yandex.cloud.loadtesting.agent.v1.File\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/loadtesting/agent/v1/jobs/{job_id}/getTransientFileBt\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agentb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_CLAIMJOBSTATUSREQUEST_JOBSTATUS = _descriptor.EnumDescriptor(
  name='JobStatus',
  full_name='yandex.cloud.loadtesting.agent.v1.ClaimJobStatusRequest.JobStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='JOB_STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POST_PROCESS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INITIATED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREPARING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_FOUND', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FINISHING', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FINISHED', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOPPED', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUTOSTOPPED', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WAITING_FOR_A_COMMAND_TO_RUN', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1153,
  serialized_end=1373,
)
_sym_db.RegisterEnumDescriptor(_CLAIMJOBSTATUSREQUEST_JOBSTATUS)

_JOBSIGNALRESPONSE_SIGNAL = _descriptor.EnumDescriptor(
  name='Signal',
  full_name='yandex.cloud.loadtesting.agent.v1.JobSignalResponse.Signal',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SIGNAL_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WAIT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUN_IN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1589,
  serialized_end=1653,
)
_sym_db.RegisterEnumDescriptor(_JOBSIGNALRESPONSE_SIGNAL)


_JOB = _descriptor.Descriptor(
  name='Job',
  full_name='yandex.cloud.loadtesting.agent.v1.Job',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.loadtesting.agent.v1.Job.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='yandex.cloud.loadtesting.agent.v1.Job.config', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ammo', full_name='yandex.cloud.loadtesting.agent.v1.Job.ammo', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='logging_log_group_id', full_name='yandex.cloud.loadtesting.agent.v1.Job.logging_log_group_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='test_data', full_name='yandex.cloud.loadtesting.agent.v1.Job.test_data', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_payload', full_name='yandex.cloud.loadtesting.agent.v1.Job.data_payload', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='artifact_upload_settings', full_name='yandex.cloud.loadtesting.agent.v1.Job.artifact_upload_settings', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=477,
)


_FILE = _descriptor.Descriptor(
  name='File',
  full_name='yandex.cloud.loadtesting.agent.v1.File',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.loadtesting.agent.v1.File.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='yandex.cloud.loadtesting.agent.v1.File.content', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=479,
  serialized_end=516,
)


_STORAGEOBJECT = _descriptor.Descriptor(
  name='StorageObject',
  full_name='yandex.cloud.loadtesting.agent.v1.StorageObject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='object_storage_bucket', full_name='yandex.cloud.loadtesting.agent.v1.StorageObject.object_storage_bucket', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_storage_filename', full_name='yandex.cloud.loadtesting.agent.v1.StorageObject.object_storage_filename', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=518,
  serialized_end=597,
)


_TESTDATAENTRY = _descriptor.Descriptor(
  name='TestDataEntry',
  full_name='yandex.cloud.loadtesting.agent.v1.TestDataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.loadtesting.agent.v1.TestDataEntry.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_transient', full_name='yandex.cloud.loadtesting.agent.v1.TestDataEntry.is_transient', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_object', full_name='yandex.cloud.loadtesting.agent.v1.TestDataEntry.storage_object', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=599,
  serialized_end=724,
)


_TESTARTIFACTUPLOADSETTINGS = _descriptor.Descriptor(
  name='TestArtifactUploadSettings',
  full_name='yandex.cloud.loadtesting.agent.v1.TestArtifactUploadSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='output_bucket', full_name='yandex.cloud.loadtesting.agent.v1.TestArtifactUploadSettings.output_bucket', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_name', full_name='yandex.cloud.loadtesting.agent.v1.TestArtifactUploadSettings.output_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_archive', full_name='yandex.cloud.loadtesting.agent.v1.TestArtifactUploadSettings.is_archive', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_include', full_name='yandex.cloud.loadtesting.agent.v1.TestArtifactUploadSettings.filter_include', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_exclude', full_name='yandex.cloud.loadtesting.agent.v1.TestArtifactUploadSettings.filter_exclude', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=727,
  serialized_end=867,
)


_GETJOBTRANSIENTFILE = _descriptor.Descriptor(
  name='GetJobTransientFile',
  full_name='yandex.cloud.loadtesting.agent.v1.GetJobTransientFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_id', full_name='yandex.cloud.loadtesting.agent.v1.GetJobTransientFile.job_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.loadtesting.agent.v1.GetJobTransientFile.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=869,
  serialized_end=920,
)


_GETJOBREQUEST = _descriptor.Descriptor(
  name='GetJobRequest',
  full_name='yandex.cloud.loadtesting.agent.v1.GetJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='compute_instance_id', full_name='yandex.cloud.loadtesting.agent.v1.GetJobRequest.compute_instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='agent_instance_id', full_name='yandex.cloud.loadtesting.agent.v1.GetJobRequest.agent_instance_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_id', full_name='yandex.cloud.loadtesting.agent.v1.GetJobRequest.job_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=922,
  serialized_end=1009,
)


_CLAIMJOBSTATUSREQUEST = _descriptor.Descriptor(
  name='ClaimJobStatusRequest',
  full_name='yandex.cloud.loadtesting.agent.v1.ClaimJobStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_id', full_name='yandex.cloud.loadtesting.agent.v1.ClaimJobStatusRequest.job_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.loadtesting.agent.v1.ClaimJobStatusRequest.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='yandex.cloud.loadtesting.agent.v1.ClaimJobStatusRequest.error', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLAIMJOBSTATUSREQUEST_JOBSTATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1012,
  serialized_end=1373,
)


_CLAIMJOBSTATUSRESPONSE = _descriptor.Descriptor(
  name='ClaimJobStatusResponse',
  full_name='yandex.cloud.loadtesting.agent.v1.ClaimJobStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='yandex.cloud.loadtesting.agent.v1.ClaimJobStatusResponse.code', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1375,
  serialized_end=1413,
)


_JOBSIGNALREQUEST = _descriptor.Descriptor(
  name='JobSignalRequest',
  full_name='yandex.cloud.loadtesting.agent.v1.JobSignalRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_id', full_name='yandex.cloud.loadtesting.agent.v1.JobSignalRequest.job_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1415,
  serialized_end=1449,
)


_JOBSIGNALRESPONSE = _descriptor.Descriptor(
  name='JobSignalResponse',
  full_name='yandex.cloud.loadtesting.agent.v1.JobSignalResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='signal', full_name='yandex.cloud.loadtesting.agent.v1.JobSignalResponse.signal', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wait_duration', full_name='yandex.cloud.loadtesting.agent.v1.JobSignalResponse.wait_duration', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='run_in', full_name='yandex.cloud.loadtesting.agent.v1.JobSignalResponse.run_in', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _JOBSIGNALRESPONSE_SIGNAL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1452,
  serialized_end=1653,
)

_JOB.fields_by_name['ammo'].message_type = _FILE
_JOB.fields_by_name['test_data'].message_type = _STORAGEOBJECT
_JOB.fields_by_name['data_payload'].message_type = _TESTDATAENTRY
_JOB.fields_by_name['artifact_upload_settings'].message_type = _TESTARTIFACTUPLOADSETTINGS
_TESTDATAENTRY.fields_by_name['storage_object'].message_type = _STORAGEOBJECT
_CLAIMJOBSTATUSREQUEST.fields_by_name['status'].enum_type = _CLAIMJOBSTATUSREQUEST_JOBSTATUS
_CLAIMJOBSTATUSREQUEST_JOBSTATUS.containing_type = _CLAIMJOBSTATUSREQUEST
_JOBSIGNALRESPONSE.fields_by_name['signal'].enum_type = _JOBSIGNALRESPONSE_SIGNAL
_JOBSIGNALRESPONSE_SIGNAL.containing_type = _JOBSIGNALRESPONSE
DESCRIPTOR.message_types_by_name['Job'] = _JOB
DESCRIPTOR.message_types_by_name['File'] = _FILE
DESCRIPTOR.message_types_by_name['StorageObject'] = _STORAGEOBJECT
DESCRIPTOR.message_types_by_name['TestDataEntry'] = _TESTDATAENTRY
DESCRIPTOR.message_types_by_name['TestArtifactUploadSettings'] = _TESTARTIFACTUPLOADSETTINGS
DESCRIPTOR.message_types_by_name['GetJobTransientFile'] = _GETJOBTRANSIENTFILE
DESCRIPTOR.message_types_by_name['GetJobRequest'] = _GETJOBREQUEST
DESCRIPTOR.message_types_by_name['ClaimJobStatusRequest'] = _CLAIMJOBSTATUSREQUEST
DESCRIPTOR.message_types_by_name['ClaimJobStatusResponse'] = _CLAIMJOBSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['JobSignalRequest'] = _JOBSIGNALREQUEST
DESCRIPTOR.message_types_by_name['JobSignalResponse'] = _JOBSIGNALRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Job = _reflection.GeneratedProtocolMessageType('Job', (_message.Message,), {
  'DESCRIPTOR' : _JOB,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.job_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.Job)
  })
_sym_db.RegisterMessage(Job)

File = _reflection.GeneratedProtocolMessageType('File', (_message.Message,), {
  'DESCRIPTOR' : _FILE,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.job_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.File)
  })
_sym_db.RegisterMessage(File)

StorageObject = _reflection.GeneratedProtocolMessageType('StorageObject', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEOBJECT,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.job_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.StorageObject)
  })
_sym_db.RegisterMessage(StorageObject)

TestDataEntry = _reflection.GeneratedProtocolMessageType('TestDataEntry', (_message.Message,), {
  'DESCRIPTOR' : _TESTDATAENTRY,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.job_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.TestDataEntry)
  })
_sym_db.RegisterMessage(TestDataEntry)

TestArtifactUploadSettings = _reflection.GeneratedProtocolMessageType('TestArtifactUploadSettings', (_message.Message,), {
  'DESCRIPTOR' : _TESTARTIFACTUPLOADSETTINGS,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.job_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.TestArtifactUploadSettings)
  })
_sym_db.RegisterMessage(TestArtifactUploadSettings)

GetJobTransientFile = _reflection.GeneratedProtocolMessageType('GetJobTransientFile', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBTRANSIENTFILE,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.job_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.GetJobTransientFile)
  })
_sym_db.RegisterMessage(GetJobTransientFile)

GetJobRequest = _reflection.GeneratedProtocolMessageType('GetJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBREQUEST,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.job_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.GetJobRequest)
  })
_sym_db.RegisterMessage(GetJobRequest)

ClaimJobStatusRequest = _reflection.GeneratedProtocolMessageType('ClaimJobStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLAIMJOBSTATUSREQUEST,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.job_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.ClaimJobStatusRequest)
  })
_sym_db.RegisterMessage(ClaimJobStatusRequest)

ClaimJobStatusResponse = _reflection.GeneratedProtocolMessageType('ClaimJobStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _CLAIMJOBSTATUSRESPONSE,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.job_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.ClaimJobStatusResponse)
  })
_sym_db.RegisterMessage(ClaimJobStatusResponse)

JobSignalRequest = _reflection.GeneratedProtocolMessageType('JobSignalRequest', (_message.Message,), {
  'DESCRIPTOR' : _JOBSIGNALREQUEST,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.job_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.JobSignalRequest)
  })
_sym_db.RegisterMessage(JobSignalRequest)

JobSignalResponse = _reflection.GeneratedProtocolMessageType('JobSignalResponse', (_message.Message,), {
  'DESCRIPTOR' : _JOBSIGNALRESPONSE,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.job_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.JobSignalResponse)
  })
_sym_db.RegisterMessage(JobSignalResponse)


DESCRIPTOR._options = None

_JOBSERVICE = _descriptor.ServiceDescriptor(
  name='JobService',
  full_name='yandex.cloud.loadtesting.agent.v1.JobService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1656,
  serialized_end=2419,
  methods=[
  _descriptor.MethodDescriptor(
    name='ClaimStatus',
    full_name='yandex.cloud.loadtesting.agent.v1.JobService.ClaimStatus',
    index=0,
    containing_service=None,
    input_type=_CLAIMJOBSTATUSREQUEST,
    output_type=_CLAIMJOBSTATUSRESPONSE,
    serialized_options=b'\202\323\344\223\0024\"//loadtesting/agent/v1/jobs/{job_id}/claimStatus:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.loadtesting.agent.v1.JobService.Get',
    index=1,
    containing_service=None,
    input_type=_GETJOBREQUEST,
    output_type=_JOB,
    serialized_options=b'\202\323\344\223\002`\0227/loadtesting/agent/v1/agents/{agent_instance_id}/getJobZ%\022#/loadtesting/agent/v1/jobs/{job_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSignal',
    full_name='yandex.cloud.loadtesting.agent.v1.JobService.GetSignal',
    index=2,
    containing_service=None,
    input_type=_JOBSIGNALREQUEST,
    output_type=_JOBSIGNALRESPONSE,
    serialized_options=b'\202\323\344\223\002/\022-/loadtesting/agent/v1/jobs/{job_id}/getSignal',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTransientFile',
    full_name='yandex.cloud.loadtesting.agent.v1.JobService.GetTransientFile',
    index=3,
    containing_service=None,
    input_type=_GETJOBTRANSIENTFILE,
    output_type=_FILE,
    serialized_options=b'\202\323\344\223\0026\0224/loadtesting/agent/v1/jobs/{job_id}/getTransientFile',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_JOBSERVICE)

DESCRIPTOR.services_by_name['JobService'] = _JOBSERVICE

# @@protoc_insertion_point(module_scope)
