# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/monitoring/v3/unit_format.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/monitoring/v3/unit_format.proto',
  package='yandex.cloud.monitoring.v3',
  syntax='proto3',
  serialized_options=b'\n\036yandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoring',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,yandex/cloud/monitoring/v3/unit_format.proto\x12\x1ayandex.cloud.monitoring.v3*\xa0\x11\n\nUnitFormat\x12\x1b\n\x17UNIT_FORMAT_UNSPECIFIED\x10\x00\x12\r\n\tUNIT_NONE\x10\x01\x12\x0e\n\nUNIT_COUNT\x10\x02\x12\x10\n\x0cUNIT_PERCENT\x10\x03\x12\x15\n\x11UNIT_PERCENT_UNIT\x10\x04\x12\x14\n\x10UNIT_NANOSECONDS\x10\x05\x12\x15\n\x11UNIT_MICROSECONDS\x10\x06\x12\x15\n\x11UNIT_MILLISECONDS\x10\x07\x12\x10\n\x0cUNIT_SECONDS\x10\x08\x12\x10\n\x0cUNIT_MINUTES\x10\t\x12\x0e\n\nUNIT_HOURS\x10\n\x12\r\n\tUNIT_DAYS\x10\x0b\x12\x10\n\x0cUNIT_BITS_SI\x10\x0c\x12\x11\n\rUNIT_BYTES_SI\x10\r\x12\x12\n\x0eUNIT_KILOBYTES\x10\x0e\x12\x12\n\x0eUNIT_MEGABYTES\x10\x0f\x12\x12\n\x0eUNIT_GIGABYTES\x10\x10\x12\x12\n\x0eUNIT_TERABYTES\x10\x11\x12\x12\n\x0eUNIT_PETABYTES\x10\x12\x12\x11\n\rUNIT_EXABYTES\x10\x13\x12\x11\n\rUNIT_BITS_IEC\x10\x14\x12\x12\n\x0eUNIT_BYTES_IEC\x10\x15\x12\x12\n\x0eUNIT_KIBIBYTES\x10\x16\x12\x12\n\x0eUNIT_MEBIBYTES\x10\x17\x12\x12\n\x0eUNIT_GIBIBYTES\x10\x18\x12\x12\n\x0eUNIT_TEBIBYTES\x10\x19\x12\x12\n\x0eUNIT_PEBIBYTES\x10\x1a\x12\x12\n\x0eUNIT_EXBIBYTES\x10\x1b\x12\x1c\n\x18UNIT_REQUESTS_PER_SECOND\x10\x1c\x12\x1e\n\x1aUNIT_OPERATIONS_PER_SECOND\x10\x1d\x12\x1a\n\x16UNIT_WRITES_PER_SECOND\x10\x1e\x12\x19\n\x15UNIT_READS_PER_SECOND\x10\x1f\x12\x1b\n\x17UNIT_PACKETS_PER_SECOND\x10 \x12!\n\x1dUNIT_IO_OPERATIONS_PER_SECOND\x10!\x12\x1a\n\x16UNIT_COUNTS_PER_SECOND\x10\"\x12\x1b\n\x17UNIT_BITS_SI_PER_SECOND\x10#\x12\x1c\n\x18UNIT_BYTES_SI_PER_SECOND\x10$\x12\x1c\n\x18UNIT_KILOBITS_PER_SECOND\x10%\x12\x1d\n\x19UNIT_KILOBYTES_PER_SECOND\x10&\x12\x1c\n\x18UNIT_MEGABITS_PER_SECOND\x10\'\x12\x1d\n\x19UNIT_MEGABYTES_PER_SECOND\x10(\x12\x1c\n\x18UNIT_GIGABITS_PER_SECOND\x10)\x12\x1d\n\x19UNIT_GIGABYTES_PER_SECOND\x10*\x12\x1c\n\x18UNIT_TERABITS_PER_SECOND\x10+\x12\x1d\n\x19UNIT_TERABYTES_PER_SECOND\x10,\x12\x1c\n\x18UNIT_PETABITS_PER_SECOND\x10-\x12\x1d\n\x19UNIT_PETABYTES_PER_SECOND\x10.\x12\x1c\n\x18UNIT_BITS_IEC_PER_SECOND\x10/\x12\x1d\n\x19UNIT_BYTES_IEC_PER_SECOND\x10\x30\x12\x1c\n\x18UNIT_KIBIBITS_PER_SECOND\x10\x31\x12\x1d\n\x19UNIT_KIBIBYTES_PER_SECOND\x10\x32\x12\x1c\n\x18UNIT_MEBIBITS_PER_SECOND\x10\x33\x12\x1d\n\x19UNIT_MEBIBYTES_PER_SECOND\x10\x34\x12\x1c\n\x18UNIT_GIBIBITS_PER_SECOND\x10\x35\x12\x1d\n\x19UNIT_GIBIBYTES_PER_SECOND\x10\x36\x12\x1c\n\x18UNIT_TEBIBITS_PER_SECOND\x10\x37\x12\x1d\n\x19UNIT_TEBIBYTES_PER_SECOND\x10\x38\x12\x1c\n\x18UNIT_PEBIBITS_PER_SECOND\x10\x39\x12\x1d\n\x19UNIT_PEBIBYTES_PER_SECOND\x10:\x12\x15\n\x11UNIT_DATETIME_UTC\x10;\x12\x17\n\x13UNIT_DATETIME_LOCAL\x10<\x12\x0e\n\nUNIT_HERTZ\x10=\x12\x12\n\x0eUNIT_KILOHERTZ\x10>\x12\x12\n\x0eUNIT_MEGAHERTZ\x10?\x12\x12\n\x0eUNIT_GIGAHERTZ\x10@\x12\x0f\n\x0bUNIT_DOLLAR\x10\x41\x12\r\n\tUNIT_EURO\x10\x42\x12\x0f\n\x0bUNIT_ROUBLE\x10\x43\x12\x10\n\x0cUNIT_CELSIUS\x10\x44\x12\x13\n\x0fUNIT_FAHRENHEIT\x10\x45\x12\x0f\n\x0bUNIT_KELVIN\x10\x46\x12\x18\n\x14UNIT_FLOP_PER_SECOND\x10G\x12\x1c\n\x18UNIT_KILOFLOP_PER_SECOND\x10H\x12\x1c\n\x18UNIT_MEGAFLOP_PER_SECOND\x10I\x12\x1c\n\x18UNIT_GIGAFLOP_PER_SECOND\x10J\x12\x1c\n\x18UNIT_PETAFLOP_PER_SECOND\x10K\x12\x1b\n\x17UNIT_EXAFLOP_PER_SECOND\x10L\x12\x1a\n\x16UNIT_METERS_PER_SECOND\x10M\x12\x1c\n\x18UNIT_KILOMETERS_PER_HOUR\x10N\x12\x17\n\x13UNIT_MILES_PER_HOUR\x10O\x12\x13\n\x0fUNIT_MILLIMETER\x10P\x12\x13\n\x0fUNIT_CENTIMETER\x10Q\x12\x0e\n\nUNIT_METER\x10R\x12\x12\n\x0eUNIT_KILOMETER\x10S\x12\r\n\tUNIT_MILE\x10T\x12\x0c\n\x08UNIT_PPM\x10U\x12\x1a\n\x16UNIT_EVENTS_PER_SECOND\x10V\x12\x10\n\x0cUNIT_PACKETS\x10W\x12\x0c\n\x08UNIT_DBM\x10X\x12\x14\n\x10UNIT_VIRTUAL_CPU\x10Y\x12\x1c\n\x18UNIT_MESSAGES_PER_SECOND\x10ZBk\n\x1eyandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoringb\x06proto3'
)

_UNITFORMAT = _descriptor.EnumDescriptor(
  name='UnitFormat',
  full_name='yandex.cloud.monitoring.v3.UnitFormat',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNIT_FORMAT_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_NONE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_COUNT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_PERCENT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_PERCENT_UNIT', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_NANOSECONDS', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_MICROSECONDS', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_MILLISECONDS', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_SECONDS', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_MINUTES', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_HOURS', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_DAYS', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_BITS_SI', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_BYTES_SI', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_KILOBYTES', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_MEGABYTES', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_GIGABYTES', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_TERABYTES', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_PETABYTES', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_EXABYTES', index=19, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_BITS_IEC', index=20, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_BYTES_IEC', index=21, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_KIBIBYTES', index=22, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_MEBIBYTES', index=23, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_GIBIBYTES', index=24, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_TEBIBYTES', index=25, number=25,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_PEBIBYTES', index=26, number=26,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_EXBIBYTES', index=27, number=27,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_REQUESTS_PER_SECOND', index=28, number=28,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_OPERATIONS_PER_SECOND', index=29, number=29,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_WRITES_PER_SECOND', index=30, number=30,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_READS_PER_SECOND', index=31, number=31,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_PACKETS_PER_SECOND', index=32, number=32,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_IO_OPERATIONS_PER_SECOND', index=33, number=33,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_COUNTS_PER_SECOND', index=34, number=34,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_BITS_SI_PER_SECOND', index=35, number=35,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_BYTES_SI_PER_SECOND', index=36, number=36,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_KILOBITS_PER_SECOND', index=37, number=37,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_KILOBYTES_PER_SECOND', index=38, number=38,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_MEGABITS_PER_SECOND', index=39, number=39,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_MEGABYTES_PER_SECOND', index=40, number=40,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_GIGABITS_PER_SECOND', index=41, number=41,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_GIGABYTES_PER_SECOND', index=42, number=42,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_TERABITS_PER_SECOND', index=43, number=43,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_TERABYTES_PER_SECOND', index=44, number=44,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_PETABITS_PER_SECOND', index=45, number=45,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_PETABYTES_PER_SECOND', index=46, number=46,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_BITS_IEC_PER_SECOND', index=47, number=47,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_BYTES_IEC_PER_SECOND', index=48, number=48,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_KIBIBITS_PER_SECOND', index=49, number=49,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_KIBIBYTES_PER_SECOND', index=50, number=50,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_MEBIBITS_PER_SECOND', index=51, number=51,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_MEBIBYTES_PER_SECOND', index=52, number=52,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_GIBIBITS_PER_SECOND', index=53, number=53,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_GIBIBYTES_PER_SECOND', index=54, number=54,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_TEBIBITS_PER_SECOND', index=55, number=55,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_TEBIBYTES_PER_SECOND', index=56, number=56,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_PEBIBITS_PER_SECOND', index=57, number=57,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_PEBIBYTES_PER_SECOND', index=58, number=58,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_DATETIME_UTC', index=59, number=59,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_DATETIME_LOCAL', index=60, number=60,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_HERTZ', index=61, number=61,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_KILOHERTZ', index=62, number=62,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_MEGAHERTZ', index=63, number=63,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_GIGAHERTZ', index=64, number=64,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_DOLLAR', index=65, number=65,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_EURO', index=66, number=66,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_ROUBLE', index=67, number=67,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_CELSIUS', index=68, number=68,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_FAHRENHEIT', index=69, number=69,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_KELVIN', index=70, number=70,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_FLOP_PER_SECOND', index=71, number=71,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_KILOFLOP_PER_SECOND', index=72, number=72,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_MEGAFLOP_PER_SECOND', index=73, number=73,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_GIGAFLOP_PER_SECOND', index=74, number=74,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_PETAFLOP_PER_SECOND', index=75, number=75,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_EXAFLOP_PER_SECOND', index=76, number=76,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_METERS_PER_SECOND', index=77, number=77,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_KILOMETERS_PER_HOUR', index=78, number=78,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_MILES_PER_HOUR', index=79, number=79,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_MILLIMETER', index=80, number=80,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_CENTIMETER', index=81, number=81,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_METER', index=82, number=82,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_KILOMETER', index=83, number=83,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_MILE', index=84, number=84,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_PPM', index=85, number=85,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_EVENTS_PER_SECOND', index=86, number=86,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_PACKETS', index=87, number=87,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_DBM', index=88, number=88,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_VIRTUAL_CPU', index=89, number=89,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT_MESSAGES_PER_SECOND', index=90, number=90,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=77,
  serialized_end=2285,
)
_sym_db.RegisterEnumDescriptor(_UNITFORMAT)

UnitFormat = enum_type_wrapper.EnumTypeWrapper(_UNITFORMAT)
UNIT_FORMAT_UNSPECIFIED = 0
UNIT_NONE = 1
UNIT_COUNT = 2
UNIT_PERCENT = 3
UNIT_PERCENT_UNIT = 4
UNIT_NANOSECONDS = 5
UNIT_MICROSECONDS = 6
UNIT_MILLISECONDS = 7
UNIT_SECONDS = 8
UNIT_MINUTES = 9
UNIT_HOURS = 10
UNIT_DAYS = 11
UNIT_BITS_SI = 12
UNIT_BYTES_SI = 13
UNIT_KILOBYTES = 14
UNIT_MEGABYTES = 15
UNIT_GIGABYTES = 16
UNIT_TERABYTES = 17
UNIT_PETABYTES = 18
UNIT_EXABYTES = 19
UNIT_BITS_IEC = 20
UNIT_BYTES_IEC = 21
UNIT_KIBIBYTES = 22
UNIT_MEBIBYTES = 23
UNIT_GIBIBYTES = 24
UNIT_TEBIBYTES = 25
UNIT_PEBIBYTES = 26
UNIT_EXBIBYTES = 27
UNIT_REQUESTS_PER_SECOND = 28
UNIT_OPERATIONS_PER_SECOND = 29
UNIT_WRITES_PER_SECOND = 30
UNIT_READS_PER_SECOND = 31
UNIT_PACKETS_PER_SECOND = 32
UNIT_IO_OPERATIONS_PER_SECOND = 33
UNIT_COUNTS_PER_SECOND = 34
UNIT_BITS_SI_PER_SECOND = 35
UNIT_BYTES_SI_PER_SECOND = 36
UNIT_KILOBITS_PER_SECOND = 37
UNIT_KILOBYTES_PER_SECOND = 38
UNIT_MEGABITS_PER_SECOND = 39
UNIT_MEGABYTES_PER_SECOND = 40
UNIT_GIGABITS_PER_SECOND = 41
UNIT_GIGABYTES_PER_SECOND = 42
UNIT_TERABITS_PER_SECOND = 43
UNIT_TERABYTES_PER_SECOND = 44
UNIT_PETABITS_PER_SECOND = 45
UNIT_PETABYTES_PER_SECOND = 46
UNIT_BITS_IEC_PER_SECOND = 47
UNIT_BYTES_IEC_PER_SECOND = 48
UNIT_KIBIBITS_PER_SECOND = 49
UNIT_KIBIBYTES_PER_SECOND = 50
UNIT_MEBIBITS_PER_SECOND = 51
UNIT_MEBIBYTES_PER_SECOND = 52
UNIT_GIBIBITS_PER_SECOND = 53
UNIT_GIBIBYTES_PER_SECOND = 54
UNIT_TEBIBITS_PER_SECOND = 55
UNIT_TEBIBYTES_PER_SECOND = 56
UNIT_PEBIBITS_PER_SECOND = 57
UNIT_PEBIBYTES_PER_SECOND = 58
UNIT_DATETIME_UTC = 59
UNIT_DATETIME_LOCAL = 60
UNIT_HERTZ = 61
UNIT_KILOHERTZ = 62
UNIT_MEGAHERTZ = 63
UNIT_GIGAHERTZ = 64
UNIT_DOLLAR = 65
UNIT_EURO = 66
UNIT_ROUBLE = 67
UNIT_CELSIUS = 68
UNIT_FAHRENHEIT = 69
UNIT_KELVIN = 70
UNIT_FLOP_PER_SECOND = 71
UNIT_KILOFLOP_PER_SECOND = 72
UNIT_MEGAFLOP_PER_SECOND = 73
UNIT_GIGAFLOP_PER_SECOND = 74
UNIT_PETAFLOP_PER_SECOND = 75
UNIT_EXAFLOP_PER_SECOND = 76
UNIT_METERS_PER_SECOND = 77
UNIT_KILOMETERS_PER_HOUR = 78
UNIT_MILES_PER_HOUR = 79
UNIT_MILLIMETER = 80
UNIT_CENTIMETER = 81
UNIT_METER = 82
UNIT_KILOMETER = 83
UNIT_MILE = 84
UNIT_PPM = 85
UNIT_EVENTS_PER_SECOND = 86
UNIT_PACKETS = 87
UNIT_DBM = 88
UNIT_VIRTUAL_CPU = 89
UNIT_MESSAGES_PER_SECOND = 90


DESCRIPTOR.enum_types_by_name['UnitFormat'] = _UNITFORMAT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
