# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/logging/v1/sink_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.logging.v1 import sink_pb2 as yandex_dot_cloud_dot_logging_dot_v1_dot_sink__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/logging/v1/sink_service.proto',
  package='yandex.cloud.logging.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;logging',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*yandex/cloud/logging/v1/sink_service.proto\x12\x17yandex.cloud.logging.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1a\"yandex/cloud/logging/v1/sink.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"/\n\x0eGetSinkRequest\x12\x1d\n\x07sink_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\"\x81\x01\n\x10ListSinksRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12\x11\n\tpage_size\x18\x03 \x01(\x03\x12\x1d\n\npage_token\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x05 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"Z\n\x11ListSinksResponse\x12,\n\x05sinks\x18\x01 \x03(\x0b\x32\x1d.yandex.cloud.logging.v1.Sink\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xec\x03\n\x11\x43reateSinkRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x87\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x36.yandex.cloud.logging.v1.CreateSinkRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12<\n\x12service_account_id\x18\x05 \x01(\tB \xf2\xc7\x31\x1c[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x30\n\x03yds\x18\x06 \x01(\x0b\x32!.yandex.cloud.logging.v1.Sink.YdsH\x00\x12.\n\x02s3\x18\x07 \x01(\x0b\x32 .yandex.cloud.logging.v1.Sink.S3H\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0c\n\x04sink\x12\x04\xc0\xc1\x31\x01\"%\n\x12\x43reateSinkMetadata\x12\x0f\n\x07sink_id\x18\x01 \x01(\t\"\x9b\x04\n\x11UpdateSinkRequest\x12\x1d\n\x07sink_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x87\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x36.yandex.cloud.logging.v1.UpdateSinkRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12<\n\x12service_account_id\x18\x06 \x01(\tB \xf2\xc7\x31\x1c[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x30\n\x03yds\x18\x07 \x01(\x0b\x32!.yandex.cloud.logging.v1.Sink.YdsH\x00\x12.\n\x02s3\x18\x08 \x01(\x0b\x32 .yandex.cloud.logging.v1.Sink.S3H\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0c\n\x04sink\x12\x04\xc0\xc1\x31\x01\"%\n\x12UpdateSinkMetadata\x12\x0f\n\x07sink_id\x18\x01 \x01(\t\"2\n\x11\x44\x65leteSinkRequest\x12\x1d\n\x07sink_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\"%\n\x12\x44\x65leteSinkMetadata\x12\x0f\n\x07sink_id\x18\x01 \x01(\t\"\x94\x01\n\x19ListSinkOperationsRequest\x12\x1d\n\x07sink_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"l\n\x1aListSinkOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x91\x0c\n\x0bSinkService\x12r\n\x03Get\x12\'.yandex.cloud.logging.v1.GetSinkRequest\x1a\x1d.yandex.cloud.logging.v1.Sink\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/logging/v1/sinks/{sink_id}\x12x\n\x04List\x12).yandex.cloud.logging.v1.ListSinksRequest\x1a*.yandex.cloud.logging.v1.ListSinksResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/logging/v1/sinks\x12\x93\x01\n\x06\x43reate\x12*.yandex.cloud.logging.v1.CreateSinkRequest\x1a!.yandex.cloud.operation.Operation\":\x82\xd3\xe4\x93\x02\x16\"\x11/logging/v1/sinks:\x01*\xb2\xd2*\x1a\n\x12\x43reateSinkMetadata\x12\x04Sink\x12\x9d\x01\n\x06Update\x12*.yandex.cloud.logging.v1.UpdateSinkRequest\x1a!.yandex.cloud.operation.Operation\"D\x82\xd3\xe4\x93\x02 2\x1b/logging/v1/sinks/{sink_id}:\x01*\xb2\xd2*\x1a\n\x12UpdateSinkMetadata\x12\x04Sink\x12\xab\x01\n\x06\x44\x65lete\x12*.yandex.cloud.logging.v1.DeleteSinkRequest\x1a!.yandex.cloud.operation.Operation\"R\x82\xd3\xe4\x93\x02\x1d*\x1b/logging/v1/sinks/{sink_id}\xb2\xd2*+\n\x12\x44\x65leteSinkMetadata\x12\x15google.protobuf.Empty\x12\xa9\x01\n\x0eListOperations\x12\x32.yandex.cloud.logging.v1.ListSinkOperationsRequest\x1a\x33.yandex.cloud.logging.v1.ListSinkOperationsResponse\".\x82\xd3\xe4\x93\x02(\x12&/logging/v1/sinks/{sink_id}/operations\x12\xb1\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/logging/v1/sinks/{resource_id}:listAccessBindings\x12\xe0\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"y\x82\xd3\xe4\x93\x02\x36\"1/logging/v1/sinks/{resource_id}:setAccessBindings:\x01*\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x12\xec\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x7f\x82\xd3\xe4\x93\x02\x39\x32\x34/logging/v1/sinks/{resource_id}:updateAccessBindings:\x01*\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.EmptyBb\n\x1byandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;loggingb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_access_dot_access__pb2.DESCRIPTOR,yandex_dot_cloud_dot_logging_dot_v1_dot_sink__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETSINKREQUEST = _descriptor.Descriptor(
  name='GetSinkRequest',
  full_name='yandex.cloud.logging.v1.GetSinkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sink_id', full_name='yandex.cloud.logging.v1.GetSinkRequest.sink_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=64', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=310,
  serialized_end=357,
)


_LISTSINKSREQUEST = _descriptor.Descriptor(
  name='ListSinksRequest',
  full_name='yandex.cloud.logging.v1.ListSinksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.logging.v1.ListSinksRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=64', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.logging.v1.ListSinksRequest.page_size', index=1,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.logging.v1.ListSinksRequest.page_token', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.logging.v1.ListSinksRequest.filter', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=360,
  serialized_end=489,
)


_LISTSINKSRESPONSE = _descriptor.Descriptor(
  name='ListSinksResponse',
  full_name='yandex.cloud.logging.v1.ListSinksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sinks', full_name='yandex.cloud.logging.v1.ListSinksResponse.sinks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.logging.v1.ListSinksResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=491,
  serialized_end=581,
)


_CREATESINKREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.logging.v1.CreateSinkRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.logging.v1.CreateSinkRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.logging.v1.CreateSinkRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1017,
  serialized_end=1062,
)

_CREATESINKREQUEST = _descriptor.Descriptor(
  name='CreateSinkRequest',
  full_name='yandex.cloud.logging.v1.CreateSinkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.logging.v1.CreateSinkRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=64', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.logging.v1.CreateSinkRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.logging.v1.CreateSinkRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.logging.v1.CreateSinkRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.logging.v1.CreateSinkRequest.service_account_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\034[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yds', full_name='yandex.cloud.logging.v1.CreateSinkRequest.yds', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s3', full_name='yandex.cloud.logging.v1.CreateSinkRequest.s3', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATESINKREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='sink', full_name='yandex.cloud.logging.v1.CreateSinkRequest.sink',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=584,
  serialized_end=1076,
)


_CREATESINKMETADATA = _descriptor.Descriptor(
  name='CreateSinkMetadata',
  full_name='yandex.cloud.logging.v1.CreateSinkMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sink_id', full_name='yandex.cloud.logging.v1.CreateSinkMetadata.sink_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1078,
  serialized_end=1115,
)


_UPDATESINKREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.logging.v1.UpdateSinkRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.logging.v1.UpdateSinkRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.logging.v1.UpdateSinkRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1017,
  serialized_end=1062,
)

_UPDATESINKREQUEST = _descriptor.Descriptor(
  name='UpdateSinkRequest',
  full_name='yandex.cloud.logging.v1.UpdateSinkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sink_id', full_name='yandex.cloud.logging.v1.UpdateSinkRequest.sink_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=64', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.logging.v1.UpdateSinkRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.logging.v1.UpdateSinkRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.logging.v1.UpdateSinkRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.logging.v1.UpdateSinkRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.logging.v1.UpdateSinkRequest.service_account_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\034[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yds', full_name='yandex.cloud.logging.v1.UpdateSinkRequest.yds', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s3', full_name='yandex.cloud.logging.v1.UpdateSinkRequest.s3', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATESINKREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='sink', full_name='yandex.cloud.logging.v1.UpdateSinkRequest.sink',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=1118,
  serialized_end=1657,
)


_UPDATESINKMETADATA = _descriptor.Descriptor(
  name='UpdateSinkMetadata',
  full_name='yandex.cloud.logging.v1.UpdateSinkMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sink_id', full_name='yandex.cloud.logging.v1.UpdateSinkMetadata.sink_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1659,
  serialized_end=1696,
)


_DELETESINKREQUEST = _descriptor.Descriptor(
  name='DeleteSinkRequest',
  full_name='yandex.cloud.logging.v1.DeleteSinkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sink_id', full_name='yandex.cloud.logging.v1.DeleteSinkRequest.sink_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=64', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1698,
  serialized_end=1748,
)


_DELETESINKMETADATA = _descriptor.Descriptor(
  name='DeleteSinkMetadata',
  full_name='yandex.cloud.logging.v1.DeleteSinkMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sink_id', full_name='yandex.cloud.logging.v1.DeleteSinkMetadata.sink_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1750,
  serialized_end=1787,
)


_LISTSINKOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListSinkOperationsRequest',
  full_name='yandex.cloud.logging.v1.ListSinkOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sink_id', full_name='yandex.cloud.logging.v1.ListSinkOperationsRequest.sink_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=64', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.logging.v1.ListSinkOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.logging.v1.ListSinkOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.logging.v1.ListSinkOperationsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1790,
  serialized_end=1938,
)


_LISTSINKOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListSinkOperationsResponse',
  full_name='yandex.cloud.logging.v1.ListSinkOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.logging.v1.ListSinkOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.logging.v1.ListSinkOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1940,
  serialized_end=2048,
)

_LISTSINKSRESPONSE.fields_by_name['sinks'].message_type = yandex_dot_cloud_dot_logging_dot_v1_dot_sink__pb2._SINK
_CREATESINKREQUEST_LABELSENTRY.containing_type = _CREATESINKREQUEST
_CREATESINKREQUEST.fields_by_name['labels'].message_type = _CREATESINKREQUEST_LABELSENTRY
_CREATESINKREQUEST.fields_by_name['yds'].message_type = yandex_dot_cloud_dot_logging_dot_v1_dot_sink__pb2._SINK_YDS
_CREATESINKREQUEST.fields_by_name['s3'].message_type = yandex_dot_cloud_dot_logging_dot_v1_dot_sink__pb2._SINK_S3
_CREATESINKREQUEST.oneofs_by_name['sink'].fields.append(
  _CREATESINKREQUEST.fields_by_name['yds'])
_CREATESINKREQUEST.fields_by_name['yds'].containing_oneof = _CREATESINKREQUEST.oneofs_by_name['sink']
_CREATESINKREQUEST.oneofs_by_name['sink'].fields.append(
  _CREATESINKREQUEST.fields_by_name['s3'])
_CREATESINKREQUEST.fields_by_name['s3'].containing_oneof = _CREATESINKREQUEST.oneofs_by_name['sink']
_UPDATESINKREQUEST_LABELSENTRY.containing_type = _UPDATESINKREQUEST
_UPDATESINKREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATESINKREQUEST.fields_by_name['labels'].message_type = _UPDATESINKREQUEST_LABELSENTRY
_UPDATESINKREQUEST.fields_by_name['yds'].message_type = yandex_dot_cloud_dot_logging_dot_v1_dot_sink__pb2._SINK_YDS
_UPDATESINKREQUEST.fields_by_name['s3'].message_type = yandex_dot_cloud_dot_logging_dot_v1_dot_sink__pb2._SINK_S3
_UPDATESINKREQUEST.oneofs_by_name['sink'].fields.append(
  _UPDATESINKREQUEST.fields_by_name['yds'])
_UPDATESINKREQUEST.fields_by_name['yds'].containing_oneof = _UPDATESINKREQUEST.oneofs_by_name['sink']
_UPDATESINKREQUEST.oneofs_by_name['sink'].fields.append(
  _UPDATESINKREQUEST.fields_by_name['s3'])
_UPDATESINKREQUEST.fields_by_name['s3'].containing_oneof = _UPDATESINKREQUEST.oneofs_by_name['sink']
_LISTSINKOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['GetSinkRequest'] = _GETSINKREQUEST
DESCRIPTOR.message_types_by_name['ListSinksRequest'] = _LISTSINKSREQUEST
DESCRIPTOR.message_types_by_name['ListSinksResponse'] = _LISTSINKSRESPONSE
DESCRIPTOR.message_types_by_name['CreateSinkRequest'] = _CREATESINKREQUEST
DESCRIPTOR.message_types_by_name['CreateSinkMetadata'] = _CREATESINKMETADATA
DESCRIPTOR.message_types_by_name['UpdateSinkRequest'] = _UPDATESINKREQUEST
DESCRIPTOR.message_types_by_name['UpdateSinkMetadata'] = _UPDATESINKMETADATA
DESCRIPTOR.message_types_by_name['DeleteSinkRequest'] = _DELETESINKREQUEST
DESCRIPTOR.message_types_by_name['DeleteSinkMetadata'] = _DELETESINKMETADATA
DESCRIPTOR.message_types_by_name['ListSinkOperationsRequest'] = _LISTSINKOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListSinkOperationsResponse'] = _LISTSINKOPERATIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetSinkRequest = _reflection.GeneratedProtocolMessageType('GetSinkRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSINKREQUEST,
  '__module__' : 'yandex.cloud.logging.v1.sink_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.GetSinkRequest)
  })
_sym_db.RegisterMessage(GetSinkRequest)

ListSinksRequest = _reflection.GeneratedProtocolMessageType('ListSinksRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSINKSREQUEST,
  '__module__' : 'yandex.cloud.logging.v1.sink_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.ListSinksRequest)
  })
_sym_db.RegisterMessage(ListSinksRequest)

ListSinksResponse = _reflection.GeneratedProtocolMessageType('ListSinksResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSINKSRESPONSE,
  '__module__' : 'yandex.cloud.logging.v1.sink_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.ListSinksResponse)
  })
_sym_db.RegisterMessage(ListSinksResponse)

CreateSinkRequest = _reflection.GeneratedProtocolMessageType('CreateSinkRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATESINKREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.logging.v1.sink_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.CreateSinkRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATESINKREQUEST,
  '__module__' : 'yandex.cloud.logging.v1.sink_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.CreateSinkRequest)
  })
_sym_db.RegisterMessage(CreateSinkRequest)
_sym_db.RegisterMessage(CreateSinkRequest.LabelsEntry)

CreateSinkMetadata = _reflection.GeneratedProtocolMessageType('CreateSinkMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATESINKMETADATA,
  '__module__' : 'yandex.cloud.logging.v1.sink_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.CreateSinkMetadata)
  })
_sym_db.RegisterMessage(CreateSinkMetadata)

UpdateSinkRequest = _reflection.GeneratedProtocolMessageType('UpdateSinkRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATESINKREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.logging.v1.sink_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.UpdateSinkRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATESINKREQUEST,
  '__module__' : 'yandex.cloud.logging.v1.sink_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.UpdateSinkRequest)
  })
_sym_db.RegisterMessage(UpdateSinkRequest)
_sym_db.RegisterMessage(UpdateSinkRequest.LabelsEntry)

UpdateSinkMetadata = _reflection.GeneratedProtocolMessageType('UpdateSinkMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESINKMETADATA,
  '__module__' : 'yandex.cloud.logging.v1.sink_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.UpdateSinkMetadata)
  })
_sym_db.RegisterMessage(UpdateSinkMetadata)

DeleteSinkRequest = _reflection.GeneratedProtocolMessageType('DeleteSinkRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESINKREQUEST,
  '__module__' : 'yandex.cloud.logging.v1.sink_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.DeleteSinkRequest)
  })
_sym_db.RegisterMessage(DeleteSinkRequest)

DeleteSinkMetadata = _reflection.GeneratedProtocolMessageType('DeleteSinkMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETESINKMETADATA,
  '__module__' : 'yandex.cloud.logging.v1.sink_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.DeleteSinkMetadata)
  })
_sym_db.RegisterMessage(DeleteSinkMetadata)

ListSinkOperationsRequest = _reflection.GeneratedProtocolMessageType('ListSinkOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSINKOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.logging.v1.sink_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.ListSinkOperationsRequest)
  })
_sym_db.RegisterMessage(ListSinkOperationsRequest)

ListSinkOperationsResponse = _reflection.GeneratedProtocolMessageType('ListSinkOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSINKOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.logging.v1.sink_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.ListSinkOperationsResponse)
  })
_sym_db.RegisterMessage(ListSinkOperationsResponse)


DESCRIPTOR._options = None
_GETSINKREQUEST.fields_by_name['sink_id']._options = None
_LISTSINKSREQUEST.fields_by_name['folder_id']._options = None
_LISTSINKSREQUEST.fields_by_name['page_token']._options = None
_LISTSINKSREQUEST.fields_by_name['filter']._options = None
_CREATESINKREQUEST_LABELSENTRY._options = None
_CREATESINKREQUEST.oneofs_by_name['sink']._options = None
_CREATESINKREQUEST.fields_by_name['folder_id']._options = None
_CREATESINKREQUEST.fields_by_name['name']._options = None
_CREATESINKREQUEST.fields_by_name['description']._options = None
_CREATESINKREQUEST.fields_by_name['labels']._options = None
_CREATESINKREQUEST.fields_by_name['service_account_id']._options = None
_UPDATESINKREQUEST_LABELSENTRY._options = None
_UPDATESINKREQUEST.oneofs_by_name['sink']._options = None
_UPDATESINKREQUEST.fields_by_name['sink_id']._options = None
_UPDATESINKREQUEST.fields_by_name['name']._options = None
_UPDATESINKREQUEST.fields_by_name['description']._options = None
_UPDATESINKREQUEST.fields_by_name['labels']._options = None
_UPDATESINKREQUEST.fields_by_name['service_account_id']._options = None
_DELETESINKREQUEST.fields_by_name['sink_id']._options = None
_LISTSINKOPERATIONSREQUEST.fields_by_name['sink_id']._options = None
_LISTSINKOPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTSINKOPERATIONSREQUEST.fields_by_name['page_token']._options = None
_LISTSINKOPERATIONSREQUEST.fields_by_name['filter']._options = None

_SINKSERVICE = _descriptor.ServiceDescriptor(
  name='SinkService',
  full_name='yandex.cloud.logging.v1.SinkService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2051,
  serialized_end=3604,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.logging.v1.SinkService.Get',
    index=0,
    containing_service=None,
    input_type=_GETSINKREQUEST,
    output_type=yandex_dot_cloud_dot_logging_dot_v1_dot_sink__pb2._SINK,
    serialized_options=b'\202\323\344\223\002\035\022\033/logging/v1/sinks/{sink_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.logging.v1.SinkService.List',
    index=1,
    containing_service=None,
    input_type=_LISTSINKSREQUEST,
    output_type=_LISTSINKSRESPONSE,
    serialized_options=b'\202\323\344\223\002\023\022\021/logging/v1/sinks',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.logging.v1.SinkService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATESINKREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\026\"\021/logging/v1/sinks:\001*\262\322*\032\n\022CreateSinkMetadata\022\004Sink',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.logging.v1.SinkService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATESINKREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002 2\033/logging/v1/sinks/{sink_id}:\001*\262\322*\032\n\022UpdateSinkMetadata\022\004Sink',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.logging.v1.SinkService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETESINKREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\035*\033/logging/v1/sinks/{sink_id}\262\322*+\n\022DeleteSinkMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.logging.v1.SinkService.ListOperations',
    index=5,
    containing_service=None,
    input_type=_LISTSINKOPERATIONSREQUEST,
    output_type=_LISTSINKOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002(\022&/logging/v1/sinks/{sink_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListAccessBindings',
    full_name='yandex.cloud.logging.v1.SinkService.ListAccessBindings',
    index=6,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSRESPONSE,
    serialized_options=b'\202\323\344\223\0024\0222/logging/v1/sinks/{resource_id}:listAccessBindings',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetAccessBindings',
    full_name='yandex.cloud.logging.v1.SinkService.SetAccessBindings',
    index=7,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._SETACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0026\"1/logging/v1/sinks/{resource_id}:setAccessBindings:\001*\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAccessBindings',
    full_name='yandex.cloud.logging.v1.SinkService.UpdateAccessBindings',
    index=8,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._UPDATEACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002924/logging/v1/sinks/{resource_id}:updateAccessBindings:\001*\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SINKSERVICE)

DESCRIPTOR.services_by_name['SinkService'] = _SINKSERVICE

# @@protoc_insertion_point(module_scope)
