# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/storage/v1/bucket_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.storage.v1 import bucket_pb2 as yandex_dot_cloud_dot_storage_dot_v1_dot_bucket__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/storage/v1/bucket_service.proto',
  package='yandex.cloud.storage.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.storage.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/storage/v1;storage',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,yandex/cloud/storage/v1/bucket_service.proto\x12\x17yandex.cloud.storage.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a$yandex/cloud/storage/v1/bucket.proto\x1a\x1dyandex/cloud/validation.proto\"\xaf\x01\n\x10GetBucketRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12<\n\x04view\x18\x02 \x01(\x0e\x32..yandex.cloud.storage.v1.GetBucketRequest.View\"I\n\x04View\x12\x14\n\x10VIEW_UNSPECIFIED\x10\x00\x12\x0e\n\nVIEW_BASIC\x10\x01\x12\x0c\n\x08VIEW_ACL\x10\x02\x12\r\n\tVIEW_FULL\x10\x03\"5\n\x12ListBucketsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"G\n\x13ListBucketsResponse\x12\x30\n\x07\x62uckets\x18\x01 \x03(\x0b\x32\x1f.yandex.cloud.storage.v1.Bucket\"\xa1\x02\n\x13\x43reateBucketRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1f\n\tfolder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\x15\x64\x65\x66\x61ult_storage_class\x18\x04 \x01(\t\x12\x10\n\x08max_size\x18\x05 \x01(\x03\x12M\n\x16\x61nonymous_access_flags\x18\x06 \x01(\x0b\x32-.yandex.cloud.storage.v1.AnonymousAccessFlags\x12)\n\x03\x61\x63l\x18\x07 \x01(\x0b\x32\x1c.yandex.cloud.storage.v1.ACL\x12*\n\x04tags\x18\x08 \x03(\x0b\x32\x1c.yandex.cloud.storage.v1.Tag\"$\n\x14\x43reateBucketMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xc2\x05\n\x13UpdateBucketRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe8\xc7\x31\x01\x12M\n\x16\x61nonymous_access_flags\x18\x03 \x01(\x0b\x32-.yandex.cloud.storage.v1.AnonymousAccessFlags\x12\x1d\n\x15\x64\x65\x66\x61ult_storage_class\x18\x04 \x01(\t\x12\x10\n\x08max_size\x18\x05 \x01(\x03\x12/\n\x04\x63ors\x18\x06 \x03(\x0b\x32!.yandex.cloud.storage.v1.CorsRule\x12\x42\n\x10website_settings\x18\x07 \x01(\x0b\x32(.yandex.cloud.storage.v1.WebsiteSettings\x12\x37\n\nversioning\x18\x08 \x01(\x0e\x32#.yandex.cloud.storage.v1.Versioning\x12?\n\x0flifecycle_rules\x18\t \x03(\x0b\x32&.yandex.cloud.storage.v1.LifecycleRule\x12\'\n\x06policy\x18\n \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x03\x61\x63l\x18\x0b \x01(\x0b\x32\x1c.yandex.cloud.storage.v1.ACL\x12*\n\x04tags\x18\x0c \x03(\x0b\x32\x1c.yandex.cloud.storage.v1.Tag\x12\x38\n\x0bobject_lock\x18\r \x01(\x0b\x32#.yandex.cloud.storage.v1.ObjectLock\x12\x37\n\nencryption\x18\x0e \x01(\x0b\x32#.yandex.cloud.storage.v1.Encryption\"$\n\x14UpdateBucketMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\")\n\x13\x44\x65leteBucketRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"$\n\x14\x44\x65leteBucketMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\"+\n\x15GetBucketStatsRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"1\n\x1bGetBucketHTTPSConfigRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"n\n\x1cSelfManagedHTTPSConfigParams\x12&\n\x0f\x63\x65rtificate_pem\x18\x01 \x01(\tB\r\x8a\xc8\x31\t<=3145728\x12&\n\x0fprivate_key_pem\x18\x02 \x01(\tB\r\x8a\xc8\x31\t<=3145728\"=\n#CertificateManagerHTTPSConfigParams\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\"\xed\x01\n\x1bSetBucketHTTPSConfigRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12M\n\x0cself_managed\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.storage.v1.SelfManagedHTTPSConfigParamsH\x00\x12[\n\x13\x63\x65rtificate_manager\x18\x03 \x01(\x0b\x32<.yandex.cloud.storage.v1.CertificateManagerHTTPSConfigParamsH\x00\x42\x0e\n\x06params\x12\x04\xc0\xc1\x31\x01\",\n\x1cSetBucketHTTPSConfigMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\"4\n\x1e\x44\x65leteBucketHTTPSConfigRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"/\n\x1f\x44\x65leteBucketHTTPSConfigMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t2\xe1\x0b\n\rBucketService\x12~\n\x04List\x12+.yandex.cloud.storage.v1.ListBucketsRequest\x1a,.yandex.cloud.storage.v1.ListBucketsResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/storage/v1/buckets\x12u\n\x03Get\x12).yandex.cloud.storage.v1.GetBucketRequest\x1a\x1f.yandex.cloud.storage.v1.Bucket\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/storage/v1/buckets/{name}\x12\x9b\x01\n\x06\x43reate\x12,.yandex.cloud.storage.v1.CreateBucketRequest\x1a!.yandex.cloud.operation.Operation\"@\x82\xd3\xe4\x93\x02\x18\"\x13/storage/v1/buckets:\x01*\xb2\xd2*\x1e\n\x14\x43reateBucketMetadata\x12\x06\x42ucket\x12\xa2\x01\n\x06Update\x12,.yandex.cloud.storage.v1.UpdateBucketRequest\x1a!.yandex.cloud.operation.Operation\"G\x82\xd3\xe4\x93\x02\x1f\x32\x1a/storage/v1/buckets/{name}:\x01*\xb2\xd2*\x1e\n\x14UpdateBucketMetadata\x12\x06\x42ucket\x12\xae\x01\n\x06\x44\x65lete\x12,.yandex.cloud.storage.v1.DeleteBucketRequest\x1a!.yandex.cloud.operation.Operation\"S\x82\xd3\xe4\x93\x02\x1c*\x1a/storage/v1/buckets/{name}\xb2\xd2*-\n\x14\x44\x65leteBucketMetadata\x12\x15google.protobuf.Empty\x12\x8d\x01\n\x08GetStats\x12..yandex.cloud.storage.v1.GetBucketStatsRequest\x1a$.yandex.cloud.storage.v1.BucketStats\"+\x82\xd3\xe4\x93\x02%\x12#/storage/v1/buckets/{name}:getStats\x12\x9f\x01\n\x0eGetHTTPSConfig\x12\x34.yandex.cloud.storage.v1.GetBucketHTTPSConfigRequest\x1a$.yandex.cloud.storage.v1.HTTPSConfig\"1\x82\xd3\xe4\x93\x02+\x12)/storage/v1/buckets/{name}:getHttpsConfig\x12\xce\x01\n\x0eSetHTTPSConfig\x12\x34.yandex.cloud.storage.v1.SetBucketHTTPSConfigRequest\x1a!.yandex.cloud.operation.Operation\"c\x82\xd3\xe4\x93\x02.\")/storage/v1/buckets/{name}:setHttpsConfig:\x01*\xb2\xd2*+\n\x1cSetBucketHTTPSConfigMetadata\x12\x0bHTTPSConfig\x12\xe1\x01\n\x11\x44\x65leteHTTPSConfig\x12\x37.yandex.cloud.storage.v1.DeleteBucketHTTPSConfigRequest\x1a!.yandex.cloud.operation.Operation\"p\x82\xd3\xe4\x93\x02.\",/storage/v1/buckets/{name}:deleteHttpsConfig\xb2\xd2*8\n\x1f\x44\x65leteBucketHTTPSConfigMetadata\x12\x15google.protobuf.EmptyBb\n\x1byandex.cloud.api.storage.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/storage/v1;storageb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_storage_dot_v1_dot_bucket__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])



_GETBUCKETREQUEST_VIEW = _descriptor.EnumDescriptor(
  name='View',
  full_name='yandex.cloud.storage.v1.GetBucketRequest.View',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VIEW_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIEW_BASIC', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIEW_ACL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIEW_FULL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=413,
  serialized_end=486,
)
_sym_db.RegisterEnumDescriptor(_GETBUCKETREQUEST_VIEW)


_GETBUCKETREQUEST = _descriptor.Descriptor(
  name='GetBucketRequest',
  full_name='yandex.cloud.storage.v1.GetBucketRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.storage.v1.GetBucketRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='view', full_name='yandex.cloud.storage.v1.GetBucketRequest.view', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GETBUCKETREQUEST_VIEW,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=311,
  serialized_end=486,
)


_LISTBUCKETSREQUEST = _descriptor.Descriptor(
  name='ListBucketsRequest',
  full_name='yandex.cloud.storage.v1.ListBucketsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.storage.v1.ListBucketsRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=488,
  serialized_end=541,
)


_LISTBUCKETSRESPONSE = _descriptor.Descriptor(
  name='ListBucketsResponse',
  full_name='yandex.cloud.storage.v1.ListBucketsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='buckets', full_name='yandex.cloud.storage.v1.ListBucketsResponse.buckets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=543,
  serialized_end=614,
)


_CREATEBUCKETREQUEST = _descriptor.Descriptor(
  name='CreateBucketRequest',
  full_name='yandex.cloud.storage.v1.CreateBucketRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.storage.v1.CreateBucketRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.storage.v1.CreateBucketRequest.folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_storage_class', full_name='yandex.cloud.storage.v1.CreateBucketRequest.default_storage_class', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_size', full_name='yandex.cloud.storage.v1.CreateBucketRequest.max_size', index=3,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='anonymous_access_flags', full_name='yandex.cloud.storage.v1.CreateBucketRequest.anonymous_access_flags', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acl', full_name='yandex.cloud.storage.v1.CreateBucketRequest.acl', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='yandex.cloud.storage.v1.CreateBucketRequest.tags', index=6,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=617,
  serialized_end=906,
)


_CREATEBUCKETMETADATA = _descriptor.Descriptor(
  name='CreateBucketMetadata',
  full_name='yandex.cloud.storage.v1.CreateBucketMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.storage.v1.CreateBucketMetadata.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=908,
  serialized_end=944,
)


_UPDATEBUCKETREQUEST = _descriptor.Descriptor(
  name='UpdateBucketRequest',
  full_name='yandex.cloud.storage.v1.UpdateBucketRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.storage.v1.UpdateBucketRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.storage.v1.UpdateBucketRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='anonymous_access_flags', full_name='yandex.cloud.storage.v1.UpdateBucketRequest.anonymous_access_flags', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_storage_class', full_name='yandex.cloud.storage.v1.UpdateBucketRequest.default_storage_class', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_size', full_name='yandex.cloud.storage.v1.UpdateBucketRequest.max_size', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cors', full_name='yandex.cloud.storage.v1.UpdateBucketRequest.cors', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='website_settings', full_name='yandex.cloud.storage.v1.UpdateBucketRequest.website_settings', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='versioning', full_name='yandex.cloud.storage.v1.UpdateBucketRequest.versioning', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lifecycle_rules', full_name='yandex.cloud.storage.v1.UpdateBucketRequest.lifecycle_rules', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='policy', full_name='yandex.cloud.storage.v1.UpdateBucketRequest.policy', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acl', full_name='yandex.cloud.storage.v1.UpdateBucketRequest.acl', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='yandex.cloud.storage.v1.UpdateBucketRequest.tags', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_lock', full_name='yandex.cloud.storage.v1.UpdateBucketRequest.object_lock', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encryption', full_name='yandex.cloud.storage.v1.UpdateBucketRequest.encryption', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=947,
  serialized_end=1653,
)


_UPDATEBUCKETMETADATA = _descriptor.Descriptor(
  name='UpdateBucketMetadata',
  full_name='yandex.cloud.storage.v1.UpdateBucketMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.storage.v1.UpdateBucketMetadata.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1655,
  serialized_end=1691,
)


_DELETEBUCKETREQUEST = _descriptor.Descriptor(
  name='DeleteBucketRequest',
  full_name='yandex.cloud.storage.v1.DeleteBucketRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.storage.v1.DeleteBucketRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1693,
  serialized_end=1734,
)


_DELETEBUCKETMETADATA = _descriptor.Descriptor(
  name='DeleteBucketMetadata',
  full_name='yandex.cloud.storage.v1.DeleteBucketMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.storage.v1.DeleteBucketMetadata.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1736,
  serialized_end=1772,
)


_GETBUCKETSTATSREQUEST = _descriptor.Descriptor(
  name='GetBucketStatsRequest',
  full_name='yandex.cloud.storage.v1.GetBucketStatsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.storage.v1.GetBucketStatsRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1774,
  serialized_end=1817,
)


_GETBUCKETHTTPSCONFIGREQUEST = _descriptor.Descriptor(
  name='GetBucketHTTPSConfigRequest',
  full_name='yandex.cloud.storage.v1.GetBucketHTTPSConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.storage.v1.GetBucketHTTPSConfigRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1819,
  serialized_end=1868,
)


_SELFMANAGEDHTTPSCONFIGPARAMS = _descriptor.Descriptor(
  name='SelfManagedHTTPSConfigParams',
  full_name='yandex.cloud.storage.v1.SelfManagedHTTPSConfigParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificate_pem', full_name='yandex.cloud.storage.v1.SelfManagedHTTPSConfigParams.certificate_pem', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\t<=3145728', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='private_key_pem', full_name='yandex.cloud.storage.v1.SelfManagedHTTPSConfigParams.private_key_pem', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\t<=3145728', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1870,
  serialized_end=1980,
)


_CERTIFICATEMANAGERHTTPSCONFIGPARAMS = _descriptor.Descriptor(
  name='CertificateManagerHTTPSConfigParams',
  full_name='yandex.cloud.storage.v1.CertificateManagerHTTPSConfigParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificate_id', full_name='yandex.cloud.storage.v1.CertificateManagerHTTPSConfigParams.certificate_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1982,
  serialized_end=2043,
)


_SETBUCKETHTTPSCONFIGREQUEST = _descriptor.Descriptor(
  name='SetBucketHTTPSConfigRequest',
  full_name='yandex.cloud.storage.v1.SetBucketHTTPSConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.storage.v1.SetBucketHTTPSConfigRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='self_managed', full_name='yandex.cloud.storage.v1.SetBucketHTTPSConfigRequest.self_managed', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='certificate_manager', full_name='yandex.cloud.storage.v1.SetBucketHTTPSConfigRequest.certificate_manager', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='params', full_name='yandex.cloud.storage.v1.SetBucketHTTPSConfigRequest.params',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=2046,
  serialized_end=2283,
)


_SETBUCKETHTTPSCONFIGMETADATA = _descriptor.Descriptor(
  name='SetBucketHTTPSConfigMetadata',
  full_name='yandex.cloud.storage.v1.SetBucketHTTPSConfigMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.storage.v1.SetBucketHTTPSConfigMetadata.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2285,
  serialized_end=2329,
)


_DELETEBUCKETHTTPSCONFIGREQUEST = _descriptor.Descriptor(
  name='DeleteBucketHTTPSConfigRequest',
  full_name='yandex.cloud.storage.v1.DeleteBucketHTTPSConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.storage.v1.DeleteBucketHTTPSConfigRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2331,
  serialized_end=2383,
)


_DELETEBUCKETHTTPSCONFIGMETADATA = _descriptor.Descriptor(
  name='DeleteBucketHTTPSConfigMetadata',
  full_name='yandex.cloud.storage.v1.DeleteBucketHTTPSConfigMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.storage.v1.DeleteBucketHTTPSConfigMetadata.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2385,
  serialized_end=2432,
)

_GETBUCKETREQUEST.fields_by_name['view'].enum_type = _GETBUCKETREQUEST_VIEW
_GETBUCKETREQUEST_VIEW.containing_type = _GETBUCKETREQUEST
_LISTBUCKETSRESPONSE.fields_by_name['buckets'].message_type = yandex_dot_cloud_dot_storage_dot_v1_dot_bucket__pb2._BUCKET
_CREATEBUCKETREQUEST.fields_by_name['anonymous_access_flags'].message_type = yandex_dot_cloud_dot_storage_dot_v1_dot_bucket__pb2._ANONYMOUSACCESSFLAGS
_CREATEBUCKETREQUEST.fields_by_name['acl'].message_type = yandex_dot_cloud_dot_storage_dot_v1_dot_bucket__pb2._ACL
_CREATEBUCKETREQUEST.fields_by_name['tags'].message_type = yandex_dot_cloud_dot_storage_dot_v1_dot_bucket__pb2._TAG
_UPDATEBUCKETREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEBUCKETREQUEST.fields_by_name['anonymous_access_flags'].message_type = yandex_dot_cloud_dot_storage_dot_v1_dot_bucket__pb2._ANONYMOUSACCESSFLAGS
_UPDATEBUCKETREQUEST.fields_by_name['cors'].message_type = yandex_dot_cloud_dot_storage_dot_v1_dot_bucket__pb2._CORSRULE
_UPDATEBUCKETREQUEST.fields_by_name['website_settings'].message_type = yandex_dot_cloud_dot_storage_dot_v1_dot_bucket__pb2._WEBSITESETTINGS
_UPDATEBUCKETREQUEST.fields_by_name['versioning'].enum_type = yandex_dot_cloud_dot_storage_dot_v1_dot_bucket__pb2._VERSIONING
_UPDATEBUCKETREQUEST.fields_by_name['lifecycle_rules'].message_type = yandex_dot_cloud_dot_storage_dot_v1_dot_bucket__pb2._LIFECYCLERULE
_UPDATEBUCKETREQUEST.fields_by_name['policy'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_UPDATEBUCKETREQUEST.fields_by_name['acl'].message_type = yandex_dot_cloud_dot_storage_dot_v1_dot_bucket__pb2._ACL
_UPDATEBUCKETREQUEST.fields_by_name['tags'].message_type = yandex_dot_cloud_dot_storage_dot_v1_dot_bucket__pb2._TAG
_UPDATEBUCKETREQUEST.fields_by_name['object_lock'].message_type = yandex_dot_cloud_dot_storage_dot_v1_dot_bucket__pb2._OBJECTLOCK
_UPDATEBUCKETREQUEST.fields_by_name['encryption'].message_type = yandex_dot_cloud_dot_storage_dot_v1_dot_bucket__pb2._ENCRYPTION
_SETBUCKETHTTPSCONFIGREQUEST.fields_by_name['self_managed'].message_type = _SELFMANAGEDHTTPSCONFIGPARAMS
_SETBUCKETHTTPSCONFIGREQUEST.fields_by_name['certificate_manager'].message_type = _CERTIFICATEMANAGERHTTPSCONFIGPARAMS
_SETBUCKETHTTPSCONFIGREQUEST.oneofs_by_name['params'].fields.append(
  _SETBUCKETHTTPSCONFIGREQUEST.fields_by_name['self_managed'])
_SETBUCKETHTTPSCONFIGREQUEST.fields_by_name['self_managed'].containing_oneof = _SETBUCKETHTTPSCONFIGREQUEST.oneofs_by_name['params']
_SETBUCKETHTTPSCONFIGREQUEST.oneofs_by_name['params'].fields.append(
  _SETBUCKETHTTPSCONFIGREQUEST.fields_by_name['certificate_manager'])
_SETBUCKETHTTPSCONFIGREQUEST.fields_by_name['certificate_manager'].containing_oneof = _SETBUCKETHTTPSCONFIGREQUEST.oneofs_by_name['params']
DESCRIPTOR.message_types_by_name['GetBucketRequest'] = _GETBUCKETREQUEST
DESCRIPTOR.message_types_by_name['ListBucketsRequest'] = _LISTBUCKETSREQUEST
DESCRIPTOR.message_types_by_name['ListBucketsResponse'] = _LISTBUCKETSRESPONSE
DESCRIPTOR.message_types_by_name['CreateBucketRequest'] = _CREATEBUCKETREQUEST
DESCRIPTOR.message_types_by_name['CreateBucketMetadata'] = _CREATEBUCKETMETADATA
DESCRIPTOR.message_types_by_name['UpdateBucketRequest'] = _UPDATEBUCKETREQUEST
DESCRIPTOR.message_types_by_name['UpdateBucketMetadata'] = _UPDATEBUCKETMETADATA
DESCRIPTOR.message_types_by_name['DeleteBucketRequest'] = _DELETEBUCKETREQUEST
DESCRIPTOR.message_types_by_name['DeleteBucketMetadata'] = _DELETEBUCKETMETADATA
DESCRIPTOR.message_types_by_name['GetBucketStatsRequest'] = _GETBUCKETSTATSREQUEST
DESCRIPTOR.message_types_by_name['GetBucketHTTPSConfigRequest'] = _GETBUCKETHTTPSCONFIGREQUEST
DESCRIPTOR.message_types_by_name['SelfManagedHTTPSConfigParams'] = _SELFMANAGEDHTTPSCONFIGPARAMS
DESCRIPTOR.message_types_by_name['CertificateManagerHTTPSConfigParams'] = _CERTIFICATEMANAGERHTTPSCONFIGPARAMS
DESCRIPTOR.message_types_by_name['SetBucketHTTPSConfigRequest'] = _SETBUCKETHTTPSCONFIGREQUEST
DESCRIPTOR.message_types_by_name['SetBucketHTTPSConfigMetadata'] = _SETBUCKETHTTPSCONFIGMETADATA
DESCRIPTOR.message_types_by_name['DeleteBucketHTTPSConfigRequest'] = _DELETEBUCKETHTTPSCONFIGREQUEST
DESCRIPTOR.message_types_by_name['DeleteBucketHTTPSConfigMetadata'] = _DELETEBUCKETHTTPSCONFIGMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetBucketRequest = _reflection.GeneratedProtocolMessageType('GetBucketRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBUCKETREQUEST,
  '__module__' : 'yandex.cloud.storage.v1.bucket_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.GetBucketRequest)
  })
_sym_db.RegisterMessage(GetBucketRequest)

ListBucketsRequest = _reflection.GeneratedProtocolMessageType('ListBucketsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTBUCKETSREQUEST,
  '__module__' : 'yandex.cloud.storage.v1.bucket_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.ListBucketsRequest)
  })
_sym_db.RegisterMessage(ListBucketsRequest)

ListBucketsResponse = _reflection.GeneratedProtocolMessageType('ListBucketsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTBUCKETSRESPONSE,
  '__module__' : 'yandex.cloud.storage.v1.bucket_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.ListBucketsResponse)
  })
_sym_db.RegisterMessage(ListBucketsResponse)

CreateBucketRequest = _reflection.GeneratedProtocolMessageType('CreateBucketRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEBUCKETREQUEST,
  '__module__' : 'yandex.cloud.storage.v1.bucket_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.CreateBucketRequest)
  })
_sym_db.RegisterMessage(CreateBucketRequest)

CreateBucketMetadata = _reflection.GeneratedProtocolMessageType('CreateBucketMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEBUCKETMETADATA,
  '__module__' : 'yandex.cloud.storage.v1.bucket_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.CreateBucketMetadata)
  })
_sym_db.RegisterMessage(CreateBucketMetadata)

UpdateBucketRequest = _reflection.GeneratedProtocolMessageType('UpdateBucketRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEBUCKETREQUEST,
  '__module__' : 'yandex.cloud.storage.v1.bucket_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.UpdateBucketRequest)
  })
_sym_db.RegisterMessage(UpdateBucketRequest)

UpdateBucketMetadata = _reflection.GeneratedProtocolMessageType('UpdateBucketMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEBUCKETMETADATA,
  '__module__' : 'yandex.cloud.storage.v1.bucket_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.UpdateBucketMetadata)
  })
_sym_db.RegisterMessage(UpdateBucketMetadata)

DeleteBucketRequest = _reflection.GeneratedProtocolMessageType('DeleteBucketRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBUCKETREQUEST,
  '__module__' : 'yandex.cloud.storage.v1.bucket_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.DeleteBucketRequest)
  })
_sym_db.RegisterMessage(DeleteBucketRequest)

DeleteBucketMetadata = _reflection.GeneratedProtocolMessageType('DeleteBucketMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBUCKETMETADATA,
  '__module__' : 'yandex.cloud.storage.v1.bucket_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.DeleteBucketMetadata)
  })
_sym_db.RegisterMessage(DeleteBucketMetadata)

GetBucketStatsRequest = _reflection.GeneratedProtocolMessageType('GetBucketStatsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBUCKETSTATSREQUEST,
  '__module__' : 'yandex.cloud.storage.v1.bucket_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.GetBucketStatsRequest)
  })
_sym_db.RegisterMessage(GetBucketStatsRequest)

GetBucketHTTPSConfigRequest = _reflection.GeneratedProtocolMessageType('GetBucketHTTPSConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBUCKETHTTPSCONFIGREQUEST,
  '__module__' : 'yandex.cloud.storage.v1.bucket_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.GetBucketHTTPSConfigRequest)
  })
_sym_db.RegisterMessage(GetBucketHTTPSConfigRequest)

SelfManagedHTTPSConfigParams = _reflection.GeneratedProtocolMessageType('SelfManagedHTTPSConfigParams', (_message.Message,), {
  'DESCRIPTOR' : _SELFMANAGEDHTTPSCONFIGPARAMS,
  '__module__' : 'yandex.cloud.storage.v1.bucket_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.SelfManagedHTTPSConfigParams)
  })
_sym_db.RegisterMessage(SelfManagedHTTPSConfigParams)

CertificateManagerHTTPSConfigParams = _reflection.GeneratedProtocolMessageType('CertificateManagerHTTPSConfigParams', (_message.Message,), {
  'DESCRIPTOR' : _CERTIFICATEMANAGERHTTPSCONFIGPARAMS,
  '__module__' : 'yandex.cloud.storage.v1.bucket_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.CertificateManagerHTTPSConfigParams)
  })
_sym_db.RegisterMessage(CertificateManagerHTTPSConfigParams)

SetBucketHTTPSConfigRequest = _reflection.GeneratedProtocolMessageType('SetBucketHTTPSConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETBUCKETHTTPSCONFIGREQUEST,
  '__module__' : 'yandex.cloud.storage.v1.bucket_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.SetBucketHTTPSConfigRequest)
  })
_sym_db.RegisterMessage(SetBucketHTTPSConfigRequest)

SetBucketHTTPSConfigMetadata = _reflection.GeneratedProtocolMessageType('SetBucketHTTPSConfigMetadata', (_message.Message,), {
  'DESCRIPTOR' : _SETBUCKETHTTPSCONFIGMETADATA,
  '__module__' : 'yandex.cloud.storage.v1.bucket_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.SetBucketHTTPSConfigMetadata)
  })
_sym_db.RegisterMessage(SetBucketHTTPSConfigMetadata)

DeleteBucketHTTPSConfigRequest = _reflection.GeneratedProtocolMessageType('DeleteBucketHTTPSConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBUCKETHTTPSCONFIGREQUEST,
  '__module__' : 'yandex.cloud.storage.v1.bucket_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.DeleteBucketHTTPSConfigRequest)
  })
_sym_db.RegisterMessage(DeleteBucketHTTPSConfigRequest)

DeleteBucketHTTPSConfigMetadata = _reflection.GeneratedProtocolMessageType('DeleteBucketHTTPSConfigMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBUCKETHTTPSCONFIGMETADATA,
  '__module__' : 'yandex.cloud.storage.v1.bucket_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.DeleteBucketHTTPSConfigMetadata)
  })
_sym_db.RegisterMessage(DeleteBucketHTTPSConfigMetadata)


DESCRIPTOR._options = None
_GETBUCKETREQUEST.fields_by_name['name']._options = None
_LISTBUCKETSREQUEST.fields_by_name['folder_id']._options = None
_CREATEBUCKETREQUEST.fields_by_name['name']._options = None
_CREATEBUCKETREQUEST.fields_by_name['folder_id']._options = None
_UPDATEBUCKETREQUEST.fields_by_name['name']._options = None
_UPDATEBUCKETREQUEST.fields_by_name['update_mask']._options = None
_DELETEBUCKETREQUEST.fields_by_name['name']._options = None
_GETBUCKETSTATSREQUEST.fields_by_name['name']._options = None
_GETBUCKETHTTPSCONFIGREQUEST.fields_by_name['name']._options = None
_SELFMANAGEDHTTPSCONFIGPARAMS.fields_by_name['certificate_pem']._options = None
_SELFMANAGEDHTTPSCONFIGPARAMS.fields_by_name['private_key_pem']._options = None
_SETBUCKETHTTPSCONFIGREQUEST.oneofs_by_name['params']._options = None
_SETBUCKETHTTPSCONFIGREQUEST.fields_by_name['name']._options = None
_DELETEBUCKETHTTPSCONFIGREQUEST.fields_by_name['name']._options = None

_BUCKETSERVICE = _descriptor.ServiceDescriptor(
  name='BucketService',
  full_name='yandex.cloud.storage.v1.BucketService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2435,
  serialized_end=3940,
  methods=[
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.storage.v1.BucketService.List',
    index=0,
    containing_service=None,
    input_type=_LISTBUCKETSREQUEST,
    output_type=_LISTBUCKETSRESPONSE,
    serialized_options=b'\202\323\344\223\002\025\022\023/storage/v1/buckets',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.storage.v1.BucketService.Get',
    index=1,
    containing_service=None,
    input_type=_GETBUCKETREQUEST,
    output_type=yandex_dot_cloud_dot_storage_dot_v1_dot_bucket__pb2._BUCKET,
    serialized_options=b'\202\323\344\223\002\034\022\032/storage/v1/buckets/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.storage.v1.BucketService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEBUCKETREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\030\"\023/storage/v1/buckets:\001*\262\322*\036\n\024CreateBucketMetadata\022\006Bucket',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.storage.v1.BucketService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATEBUCKETREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\0372\032/storage/v1/buckets/{name}:\001*\262\322*\036\n\024UpdateBucketMetadata\022\006Bucket',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.storage.v1.BucketService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETEBUCKETREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\034*\032/storage/v1/buckets/{name}\262\322*-\n\024DeleteBucketMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetStats',
    full_name='yandex.cloud.storage.v1.BucketService.GetStats',
    index=5,
    containing_service=None,
    input_type=_GETBUCKETSTATSREQUEST,
    output_type=yandex_dot_cloud_dot_storage_dot_v1_dot_bucket__pb2._BUCKETSTATS,
    serialized_options=b'\202\323\344\223\002%\022#/storage/v1/buckets/{name}:getStats',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetHTTPSConfig',
    full_name='yandex.cloud.storage.v1.BucketService.GetHTTPSConfig',
    index=6,
    containing_service=None,
    input_type=_GETBUCKETHTTPSCONFIGREQUEST,
    output_type=yandex_dot_cloud_dot_storage_dot_v1_dot_bucket__pb2._HTTPSCONFIG,
    serialized_options=b'\202\323\344\223\002+\022)/storage/v1/buckets/{name}:getHttpsConfig',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetHTTPSConfig',
    full_name='yandex.cloud.storage.v1.BucketService.SetHTTPSConfig',
    index=7,
    containing_service=None,
    input_type=_SETBUCKETHTTPSCONFIGREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002.\")/storage/v1/buckets/{name}:setHttpsConfig:\001*\262\322*+\n\034SetBucketHTTPSConfigMetadata\022\013HTTPSConfig',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteHTTPSConfig',
    full_name='yandex.cloud.storage.v1.BucketService.DeleteHTTPSConfig',
    index=8,
    containing_service=None,
    input_type=_DELETEBUCKETHTTPSCONFIGREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002.\",/storage/v1/buckets/{name}:deleteHttpsConfig\262\322*8\n\037DeleteBucketHTTPSConfigMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_BUCKETSERVICE)

DESCRIPTOR.services_by_name['BucketService'] = _BUCKETSERVICE

# @@protoc_insertion_point(module_scope)
