# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/monitoring/v3/parametrization.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.monitoring.v3 import unit_format_pb2 as yandex_dot_cloud_dot_monitoring_dot_v3_dot_unit__format__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/monitoring/v3/parametrization.proto',
  package='yandex.cloud.monitoring.v3',
  syntax='proto3',
  serialized_options=b'\n\036yandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoring',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n0yandex/cloud/monitoring/v3/parametrization.proto\x12\x1ayandex.cloud.monitoring.v3\x1a,yandex/cloud/monitoring/v3/unit_format.proto\"\x8f\x01\n\x14LabelValuesParameter\x12\x13\n\tfolder_id\x18\x02 \x01(\tH\x00\x12\x11\n\tselectors\x18\x13 \x01(\t\x12\x11\n\tlabel_key\x18\x14 \x01(\t\x12\x17\n\x0fmultiselectable\x18\x15 \x01(\x08\x12\x16\n\x0e\x64\x65\x66\x61ult_values\x18\x16 \x03(\tB\x0b\n\tcontainer\"R\n\x0f\x43ustomParameter\x12\x0e\n\x06values\x18\x01 \x03(\t\x12\x17\n\x0fmultiselectable\x18\x02 \x01(\x08\x12\x16\n\x0e\x64\x65\x66\x61ult_values\x18\x03 \x03(\t\"&\n\rTextParameter\x12\x15\n\rdefault_value\x18\x01 \x01(\t\"e\n\x0f\x44oubleParameter\x12\x15\n\rdefault_value\x18\x01 \x01(\x01\x12;\n\x0bunit_format\x18\x02 \x01(\x0e\x32&.yandex.cloud.monitoring.v3.UnitFormat\"f\n\x10IntegerParameter\x12\x15\n\rdefault_value\x18\x01 \x01(\x03\x12;\n\x0bunit_format\x18\x02 \x01(\x0e\x32&.yandex.cloud.monitoring.v3.UnitFormat\"-\n\x13TextValuesParameter\x12\x16\n\x0e\x64\x65\x66\x61ult_values\x18\x01 \x03(\t\"\xf5\x03\n\tParameter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12H\n\x0clabel_values\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.monitoring.v3.LabelValuesParameterH\x00\x12=\n\x06\x63ustom\x18\x04 \x01(\x0b\x32+.yandex.cloud.monitoring.v3.CustomParameterH\x00\x12\x39\n\x04text\x18\x05 \x01(\x0b\x32).yandex.cloud.monitoring.v3.TextParameterH\x00\x12I\n\x11integer_parameter\x18\x07 \x01(\x0b\x32,.yandex.cloud.monitoring.v3.IntegerParameterH\x00\x12G\n\x10\x64ouble_parameter\x18\x08 \x01(\x0b\x32+.yandex.cloud.monitoring.v3.DoubleParameterH\x00\x12\x46\n\x0btext_values\x18\t \x01(\x0b\x32/.yandex.cloud.monitoring.v3.TextValuesParameterH\x00\x12\x0e\n\x06hidden\x18\x06 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\n \x01(\tB\x06\n\x04\x64\x61ta\"_\n\x0fParametrization\x12\x39\n\nparameters\x18\x01 \x03(\x0b\x32%.yandex.cloud.monitoring.v3.Parameter\x12\x11\n\tselectors\x18\x02 \x01(\tBk\n\x1eyandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoringb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_monitoring_dot_v3_dot_unit__format__pb2.DESCRIPTOR,])




_LABELVALUESPARAMETER = _descriptor.Descriptor(
  name='LabelValuesParameter',
  full_name='yandex.cloud.monitoring.v3.LabelValuesParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.monitoring.v3.LabelValuesParameter.folder_id', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selectors', full_name='yandex.cloud.monitoring.v3.LabelValuesParameter.selectors', index=1,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label_key', full_name='yandex.cloud.monitoring.v3.LabelValuesParameter.label_key', index=2,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='multiselectable', full_name='yandex.cloud.monitoring.v3.LabelValuesParameter.multiselectable', index=3,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_values', full_name='yandex.cloud.monitoring.v3.LabelValuesParameter.default_values', index=4,
      number=22, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='container', full_name='yandex.cloud.monitoring.v3.LabelValuesParameter.container',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=127,
  serialized_end=270,
)


_CUSTOMPARAMETER = _descriptor.Descriptor(
  name='CustomParameter',
  full_name='yandex.cloud.monitoring.v3.CustomParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='yandex.cloud.monitoring.v3.CustomParameter.values', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='multiselectable', full_name='yandex.cloud.monitoring.v3.CustomParameter.multiselectable', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_values', full_name='yandex.cloud.monitoring.v3.CustomParameter.default_values', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=272,
  serialized_end=354,
)


_TEXTPARAMETER = _descriptor.Descriptor(
  name='TextParameter',
  full_name='yandex.cloud.monitoring.v3.TextParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_value', full_name='yandex.cloud.monitoring.v3.TextParameter.default_value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=356,
  serialized_end=394,
)


_DOUBLEPARAMETER = _descriptor.Descriptor(
  name='DoubleParameter',
  full_name='yandex.cloud.monitoring.v3.DoubleParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_value', full_name='yandex.cloud.monitoring.v3.DoubleParameter.default_value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit_format', full_name='yandex.cloud.monitoring.v3.DoubleParameter.unit_format', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=396,
  serialized_end=497,
)


_INTEGERPARAMETER = _descriptor.Descriptor(
  name='IntegerParameter',
  full_name='yandex.cloud.monitoring.v3.IntegerParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_value', full_name='yandex.cloud.monitoring.v3.IntegerParameter.default_value', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit_format', full_name='yandex.cloud.monitoring.v3.IntegerParameter.unit_format', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=499,
  serialized_end=601,
)


_TEXTVALUESPARAMETER = _descriptor.Descriptor(
  name='TextValuesParameter',
  full_name='yandex.cloud.monitoring.v3.TextValuesParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_values', full_name='yandex.cloud.monitoring.v3.TextValuesParameter.default_values', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=603,
  serialized_end=648,
)


_PARAMETER = _descriptor.Descriptor(
  name='Parameter',
  full_name='yandex.cloud.monitoring.v3.Parameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.monitoring.v3.Parameter.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='yandex.cloud.monitoring.v3.Parameter.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label_values', full_name='yandex.cloud.monitoring.v3.Parameter.label_values', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom', full_name='yandex.cloud.monitoring.v3.Parameter.custom', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='yandex.cloud.monitoring.v3.Parameter.text', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='integer_parameter', full_name='yandex.cloud.monitoring.v3.Parameter.integer_parameter', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='double_parameter', full_name='yandex.cloud.monitoring.v3.Parameter.double_parameter', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text_values', full_name='yandex.cloud.monitoring.v3.Parameter.text_values', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hidden', full_name='yandex.cloud.monitoring.v3.Parameter.hidden', index=8,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.monitoring.v3.Parameter.description', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='yandex.cloud.monitoring.v3.Parameter.data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=651,
  serialized_end=1152,
)


_PARAMETRIZATION = _descriptor.Descriptor(
  name='Parametrization',
  full_name='yandex.cloud.monitoring.v3.Parametrization',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parameters', full_name='yandex.cloud.monitoring.v3.Parametrization.parameters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selectors', full_name='yandex.cloud.monitoring.v3.Parametrization.selectors', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1154,
  serialized_end=1249,
)

_LABELVALUESPARAMETER.oneofs_by_name['container'].fields.append(
  _LABELVALUESPARAMETER.fields_by_name['folder_id'])
_LABELVALUESPARAMETER.fields_by_name['folder_id'].containing_oneof = _LABELVALUESPARAMETER.oneofs_by_name['container']
_DOUBLEPARAMETER.fields_by_name['unit_format'].enum_type = yandex_dot_cloud_dot_monitoring_dot_v3_dot_unit__format__pb2._UNITFORMAT
_INTEGERPARAMETER.fields_by_name['unit_format'].enum_type = yandex_dot_cloud_dot_monitoring_dot_v3_dot_unit__format__pb2._UNITFORMAT
_PARAMETER.fields_by_name['label_values'].message_type = _LABELVALUESPARAMETER
_PARAMETER.fields_by_name['custom'].message_type = _CUSTOMPARAMETER
_PARAMETER.fields_by_name['text'].message_type = _TEXTPARAMETER
_PARAMETER.fields_by_name['integer_parameter'].message_type = _INTEGERPARAMETER
_PARAMETER.fields_by_name['double_parameter'].message_type = _DOUBLEPARAMETER
_PARAMETER.fields_by_name['text_values'].message_type = _TEXTVALUESPARAMETER
_PARAMETER.oneofs_by_name['data'].fields.append(
  _PARAMETER.fields_by_name['label_values'])
_PARAMETER.fields_by_name['label_values'].containing_oneof = _PARAMETER.oneofs_by_name['data']
_PARAMETER.oneofs_by_name['data'].fields.append(
  _PARAMETER.fields_by_name['custom'])
_PARAMETER.fields_by_name['custom'].containing_oneof = _PARAMETER.oneofs_by_name['data']
_PARAMETER.oneofs_by_name['data'].fields.append(
  _PARAMETER.fields_by_name['text'])
_PARAMETER.fields_by_name['text'].containing_oneof = _PARAMETER.oneofs_by_name['data']
_PARAMETER.oneofs_by_name['data'].fields.append(
  _PARAMETER.fields_by_name['integer_parameter'])
_PARAMETER.fields_by_name['integer_parameter'].containing_oneof = _PARAMETER.oneofs_by_name['data']
_PARAMETER.oneofs_by_name['data'].fields.append(
  _PARAMETER.fields_by_name['double_parameter'])
_PARAMETER.fields_by_name['double_parameter'].containing_oneof = _PARAMETER.oneofs_by_name['data']
_PARAMETER.oneofs_by_name['data'].fields.append(
  _PARAMETER.fields_by_name['text_values'])
_PARAMETER.fields_by_name['text_values'].containing_oneof = _PARAMETER.oneofs_by_name['data']
_PARAMETRIZATION.fields_by_name['parameters'].message_type = _PARAMETER
DESCRIPTOR.message_types_by_name['LabelValuesParameter'] = _LABELVALUESPARAMETER
DESCRIPTOR.message_types_by_name['CustomParameter'] = _CUSTOMPARAMETER
DESCRIPTOR.message_types_by_name['TextParameter'] = _TEXTPARAMETER
DESCRIPTOR.message_types_by_name['DoubleParameter'] = _DOUBLEPARAMETER
DESCRIPTOR.message_types_by_name['IntegerParameter'] = _INTEGERPARAMETER
DESCRIPTOR.message_types_by_name['TextValuesParameter'] = _TEXTVALUESPARAMETER
DESCRIPTOR.message_types_by_name['Parameter'] = _PARAMETER
DESCRIPTOR.message_types_by_name['Parametrization'] = _PARAMETRIZATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LabelValuesParameter = _reflection.GeneratedProtocolMessageType('LabelValuesParameter', (_message.Message,), {
  'DESCRIPTOR' : _LABELVALUESPARAMETER,
  '__module__' : 'yandex.cloud.monitoring.v3.parametrization_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.LabelValuesParameter)
  })
_sym_db.RegisterMessage(LabelValuesParameter)

CustomParameter = _reflection.GeneratedProtocolMessageType('CustomParameter', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMPARAMETER,
  '__module__' : 'yandex.cloud.monitoring.v3.parametrization_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.CustomParameter)
  })
_sym_db.RegisterMessage(CustomParameter)

TextParameter = _reflection.GeneratedProtocolMessageType('TextParameter', (_message.Message,), {
  'DESCRIPTOR' : _TEXTPARAMETER,
  '__module__' : 'yandex.cloud.monitoring.v3.parametrization_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.TextParameter)
  })
_sym_db.RegisterMessage(TextParameter)

DoubleParameter = _reflection.GeneratedProtocolMessageType('DoubleParameter', (_message.Message,), {
  'DESCRIPTOR' : _DOUBLEPARAMETER,
  '__module__' : 'yandex.cloud.monitoring.v3.parametrization_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.DoubleParameter)
  })
_sym_db.RegisterMessage(DoubleParameter)

IntegerParameter = _reflection.GeneratedProtocolMessageType('IntegerParameter', (_message.Message,), {
  'DESCRIPTOR' : _INTEGERPARAMETER,
  '__module__' : 'yandex.cloud.monitoring.v3.parametrization_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.IntegerParameter)
  })
_sym_db.RegisterMessage(IntegerParameter)

TextValuesParameter = _reflection.GeneratedProtocolMessageType('TextValuesParameter', (_message.Message,), {
  'DESCRIPTOR' : _TEXTVALUESPARAMETER,
  '__module__' : 'yandex.cloud.monitoring.v3.parametrization_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.TextValuesParameter)
  })
_sym_db.RegisterMessage(TextValuesParameter)

Parameter = _reflection.GeneratedProtocolMessageType('Parameter', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETER,
  '__module__' : 'yandex.cloud.monitoring.v3.parametrization_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.Parameter)
  })
_sym_db.RegisterMessage(Parameter)

Parametrization = _reflection.GeneratedProtocolMessageType('Parametrization', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETRIZATION,
  '__module__' : 'yandex.cloud.monitoring.v3.parametrization_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.Parametrization)
  })
_sym_db.RegisterMessage(Parametrization)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
