# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/resourcemanager/v1/cloud_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.resourcemanager.v1 import cloud_pb2 as yandex_dot_cloud_dot_resourcemanager_dot_v1_dot_cloud__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/resourcemanager/v1/cloud_service.proto',
  package='yandex.cloud.resourcemanager.v1',
  syntax='proto3',
  serialized_options=b'\n#yandex.cloud.api.resourcemanager.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/resourcemanager/v1;resourcemanager',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n3yandex/cloud/resourcemanager/v1/cloud_service.proto\x12\x1fyandex.cloud.resourcemanager.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a+yandex/cloud/resourcemanager/v1/cloud.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"1\n\x0fGetCloudRequest\x12\x1e\n\x08\x63loud_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x91\x01\n\x11ListCloudsRequest\x12\x1d\n\tpage_size\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1e\n\npage_token\x18\x02 \x01(\tB\n\x8a\xc8\x31\x06<=2000\x12\x1a\n\x06\x66ilter\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12!\n\x0forganization_id\x18\x04 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"e\n\x12ListCloudsResponse\x12\x36\n\x06\x63louds\x18\x01 \x03(\x0b\x32&.yandex.cloud.resourcemanager.v1.Cloud\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xd2\x02\n\x12\x43reateCloudRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x33\n\x04name\x18\x02 \x01(\tB%\xe8\xc7\x31\x01\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x90\x01\n\x06labels\x18\x04 \x03(\x0b\x32?.yandex.cloud.resourcemanager.v1.CreateCloudRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\'\n\x13\x43reateCloudMetadata\x12\x10\n\x08\x63loud_id\x18\x01 \x01(\t\"{\n\x1aListCloudOperationsRequest\x12\x1e\n\x08\x63loud_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"m\n\x1bListCloudOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xfa\x02\n\x12UpdateCloudRequest\x12\x1e\n\x08\x63loud_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x31\n\x04name\x18\x03 \x01(\tB#\xf2\xc7\x31\x1f[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x90\x01\n\x06labels\x18\x05 \x03(\x0b\x32?.yandex.cloud.resourcemanager.v1.UpdateCloudRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\'\n\x13UpdateCloudMetadata\x12\x10\n\x08\x63loud_id\x18\x01 \x01(\t\"f\n\x12\x44\x65leteCloudRequest\x12\x1e\n\x08\x63loud_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x30\n\x0c\x64\x65lete_after\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"Y\n\x13\x44\x65leteCloudMetadata\x12\x10\n\x08\x63loud_id\x18\x01 \x01(\t\x12\x30\n\x0c\x64\x65lete_after\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp2\xe8\r\n\x0c\x43loudService\x12\x8f\x01\n\x03Get\x12\x30.yandex.cloud.resourcemanager.v1.GetCloudRequest\x1a&.yandex.cloud.resourcemanager.v1.Cloud\".\x82\xd3\xe4\x93\x02(\x12&/resource-manager/v1/clouds/{cloud_id}\x12\x94\x01\n\x04List\x12\x32.yandex.cloud.resourcemanager.v1.ListCloudsRequest\x1a\x33.yandex.cloud.resourcemanager.v1.ListCloudsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/resource-manager/v1/clouds\x12\xa8\x01\n\x06\x43reate\x12\x33.yandex.cloud.resourcemanager.v1.CreateCloudRequest\x1a!.yandex.cloud.operation.Operation\"F\x82\xd3\xe4\x93\x02 \"\x1b/resource-manager/v1/clouds:\x01*\xb2\xd2*\x1c\n\x13\x43reateCloudMetadata\x12\x05\x43loud\x12\xb3\x01\n\x06Update\x12\x33.yandex.cloud.resourcemanager.v1.UpdateCloudRequest\x1a!.yandex.cloud.operation.Operation\"Q\x82\xd3\xe4\x93\x02+2&/resource-manager/v1/clouds/{cloud_id}:\x01*\xb2\xd2*\x1c\n\x13UpdateCloudMetadata\x12\x05\x43loud\x12\xc0\x01\n\x06\x44\x65lete\x12\x33.yandex.cloud.resourcemanager.v1.DeleteCloudRequest\x1a!.yandex.cloud.operation.Operation\"^\x82\xd3\xe4\x93\x02(*&/resource-manager/v1/clouds/{cloud_id}\xb2\xd2*,\n\x13\x44\x65leteCloudMetadata\x12\x15google.protobuf.Empty\x12\xc6\x01\n\x0eListOperations\x12;.yandex.cloud.resourcemanager.v1.ListCloudOperationsRequest\x1a<.yandex.cloud.resourcemanager.v1.ListCloudOperationsResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/resource-manager/v1/clouds/{cloud_id}/operations\x12\xbb\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"D\x82\xd3\xe4\x93\x02>\x12</resource-manager/v1/clouds/{resource_id}:listAccessBindings\x12\xfa\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x92\x01\x82\xd3\xe4\x93\x02@\";/resource-manager/v1/clouds/{resource_id}:setAccessBindings:\x01*\xb2\xd2*H\n access.SetAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x12\x86\x02\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x98\x01\x82\xd3\xe4\x93\x02\x43\">/resource-manager/v1/clouds/{resource_id}:updateAccessBindings:\x01*\xb2\xd2*K\n#access.UpdateAccessBindingsMetadata\x12$access.AccessBindingsOperationResultBz\n#yandex.cloud.api.resourcemanager.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/resourcemanager/v1;resourcemanagerb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yandex_dot_cloud_dot_resourcemanager_dot_v1_dot_cloud__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_access_dot_access__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETCLOUDREQUEST = _descriptor.Descriptor(
  name='GetCloudRequest',
  full_name='yandex.cloud.resourcemanager.v1.GetCloudRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cloud_id', full_name='yandex.cloud.resourcemanager.v1.GetCloudRequest.cloud_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=369,
  serialized_end=418,
)


_LISTCLOUDSREQUEST = _descriptor.Descriptor(
  name='ListCloudsRequest',
  full_name='yandex.cloud.resourcemanager.v1.ListCloudsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.resourcemanager.v1.ListCloudsRequest.page_size', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.resourcemanager.v1.ListCloudsRequest.page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=2000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.resourcemanager.v1.ListCloudsRequest.filter', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='organization_id', full_name='yandex.cloud.resourcemanager.v1.ListCloudsRequest.organization_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=421,
  serialized_end=566,
)


_LISTCLOUDSRESPONSE = _descriptor.Descriptor(
  name='ListCloudsResponse',
  full_name='yandex.cloud.resourcemanager.v1.ListCloudsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clouds', full_name='yandex.cloud.resourcemanager.v1.ListCloudsResponse.clouds', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.resourcemanager.v1.ListCloudsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=568,
  serialized_end=669,
)


_CREATECLOUDREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.resourcemanager.v1.CreateCloudRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.resourcemanager.v1.CreateCloudRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.resourcemanager.v1.CreateCloudRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=965,
  serialized_end=1010,
)

_CREATECLOUDREQUEST = _descriptor.Descriptor(
  name='CreateCloudRequest',
  full_name='yandex.cloud.resourcemanager.v1.CreateCloudRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='organization_id', full_name='yandex.cloud.resourcemanager.v1.CreateCloudRequest.organization_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.resourcemanager.v1.CreateCloudRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.resourcemanager.v1.CreateCloudRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.resourcemanager.v1.CreateCloudRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATECLOUDREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=672,
  serialized_end=1010,
)


_CREATECLOUDMETADATA = _descriptor.Descriptor(
  name='CreateCloudMetadata',
  full_name='yandex.cloud.resourcemanager.v1.CreateCloudMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cloud_id', full_name='yandex.cloud.resourcemanager.v1.CreateCloudMetadata.cloud_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1012,
  serialized_end=1051,
)


_LISTCLOUDOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListCloudOperationsRequest',
  full_name='yandex.cloud.resourcemanager.v1.ListCloudOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cloud_id', full_name='yandex.cloud.resourcemanager.v1.ListCloudOperationsRequest.cloud_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.resourcemanager.v1.ListCloudOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.resourcemanager.v1.ListCloudOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=2000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1053,
  serialized_end=1176,
)


_LISTCLOUDOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListCloudOperationsResponse',
  full_name='yandex.cloud.resourcemanager.v1.ListCloudOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.resourcemanager.v1.ListCloudOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.resourcemanager.v1.ListCloudOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1178,
  serialized_end=1287,
)


_UPDATECLOUDREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.resourcemanager.v1.UpdateCloudRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.resourcemanager.v1.UpdateCloudRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.resourcemanager.v1.UpdateCloudRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=965,
  serialized_end=1010,
)

_UPDATECLOUDREQUEST = _descriptor.Descriptor(
  name='UpdateCloudRequest',
  full_name='yandex.cloud.resourcemanager.v1.UpdateCloudRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cloud_id', full_name='yandex.cloud.resourcemanager.v1.UpdateCloudRequest.cloud_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.resourcemanager.v1.UpdateCloudRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.resourcemanager.v1.UpdateCloudRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\037[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.resourcemanager.v1.UpdateCloudRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.resourcemanager.v1.UpdateCloudRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATECLOUDREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1290,
  serialized_end=1668,
)


_UPDATECLOUDMETADATA = _descriptor.Descriptor(
  name='UpdateCloudMetadata',
  full_name='yandex.cloud.resourcemanager.v1.UpdateCloudMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cloud_id', full_name='yandex.cloud.resourcemanager.v1.UpdateCloudMetadata.cloud_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1670,
  serialized_end=1709,
)


_DELETECLOUDREQUEST = _descriptor.Descriptor(
  name='DeleteCloudRequest',
  full_name='yandex.cloud.resourcemanager.v1.DeleteCloudRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cloud_id', full_name='yandex.cloud.resourcemanager.v1.DeleteCloudRequest.cloud_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delete_after', full_name='yandex.cloud.resourcemanager.v1.DeleteCloudRequest.delete_after', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1711,
  serialized_end=1813,
)


_DELETECLOUDMETADATA = _descriptor.Descriptor(
  name='DeleteCloudMetadata',
  full_name='yandex.cloud.resourcemanager.v1.DeleteCloudMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cloud_id', full_name='yandex.cloud.resourcemanager.v1.DeleteCloudMetadata.cloud_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delete_after', full_name='yandex.cloud.resourcemanager.v1.DeleteCloudMetadata.delete_after', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1815,
  serialized_end=1904,
)

_LISTCLOUDSRESPONSE.fields_by_name['clouds'].message_type = yandex_dot_cloud_dot_resourcemanager_dot_v1_dot_cloud__pb2._CLOUD
_CREATECLOUDREQUEST_LABELSENTRY.containing_type = _CREATECLOUDREQUEST
_CREATECLOUDREQUEST.fields_by_name['labels'].message_type = _CREATECLOUDREQUEST_LABELSENTRY
_LISTCLOUDOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
_UPDATECLOUDREQUEST_LABELSENTRY.containing_type = _UPDATECLOUDREQUEST
_UPDATECLOUDREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATECLOUDREQUEST.fields_by_name['labels'].message_type = _UPDATECLOUDREQUEST_LABELSENTRY
_DELETECLOUDREQUEST.fields_by_name['delete_after'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DELETECLOUDMETADATA.fields_by_name['delete_after'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['GetCloudRequest'] = _GETCLOUDREQUEST
DESCRIPTOR.message_types_by_name['ListCloudsRequest'] = _LISTCLOUDSREQUEST
DESCRIPTOR.message_types_by_name['ListCloudsResponse'] = _LISTCLOUDSRESPONSE
DESCRIPTOR.message_types_by_name['CreateCloudRequest'] = _CREATECLOUDREQUEST
DESCRIPTOR.message_types_by_name['CreateCloudMetadata'] = _CREATECLOUDMETADATA
DESCRIPTOR.message_types_by_name['ListCloudOperationsRequest'] = _LISTCLOUDOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListCloudOperationsResponse'] = _LISTCLOUDOPERATIONSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateCloudRequest'] = _UPDATECLOUDREQUEST
DESCRIPTOR.message_types_by_name['UpdateCloudMetadata'] = _UPDATECLOUDMETADATA
DESCRIPTOR.message_types_by_name['DeleteCloudRequest'] = _DELETECLOUDREQUEST
DESCRIPTOR.message_types_by_name['DeleteCloudMetadata'] = _DELETECLOUDMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetCloudRequest = _reflection.GeneratedProtocolMessageType('GetCloudRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCLOUDREQUEST,
  '__module__' : 'yandex.cloud.resourcemanager.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.resourcemanager.v1.GetCloudRequest)
  })
_sym_db.RegisterMessage(GetCloudRequest)

ListCloudsRequest = _reflection.GeneratedProtocolMessageType('ListCloudsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLOUDSREQUEST,
  '__module__' : 'yandex.cloud.resourcemanager.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.resourcemanager.v1.ListCloudsRequest)
  })
_sym_db.RegisterMessage(ListCloudsRequest)

ListCloudsResponse = _reflection.GeneratedProtocolMessageType('ListCloudsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLOUDSRESPONSE,
  '__module__' : 'yandex.cloud.resourcemanager.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.resourcemanager.v1.ListCloudsResponse)
  })
_sym_db.RegisterMessage(ListCloudsResponse)

CreateCloudRequest = _reflection.GeneratedProtocolMessageType('CreateCloudRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATECLOUDREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.resourcemanager.v1.cloud_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.resourcemanager.v1.CreateCloudRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATECLOUDREQUEST,
  '__module__' : 'yandex.cloud.resourcemanager.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.resourcemanager.v1.CreateCloudRequest)
  })
_sym_db.RegisterMessage(CreateCloudRequest)
_sym_db.RegisterMessage(CreateCloudRequest.LabelsEntry)

CreateCloudMetadata = _reflection.GeneratedProtocolMessageType('CreateCloudMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATECLOUDMETADATA,
  '__module__' : 'yandex.cloud.resourcemanager.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.resourcemanager.v1.CreateCloudMetadata)
  })
_sym_db.RegisterMessage(CreateCloudMetadata)

ListCloudOperationsRequest = _reflection.GeneratedProtocolMessageType('ListCloudOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLOUDOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.resourcemanager.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.resourcemanager.v1.ListCloudOperationsRequest)
  })
_sym_db.RegisterMessage(ListCloudOperationsRequest)

ListCloudOperationsResponse = _reflection.GeneratedProtocolMessageType('ListCloudOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLOUDOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.resourcemanager.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.resourcemanager.v1.ListCloudOperationsResponse)
  })
_sym_db.RegisterMessage(ListCloudOperationsResponse)

UpdateCloudRequest = _reflection.GeneratedProtocolMessageType('UpdateCloudRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATECLOUDREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.resourcemanager.v1.cloud_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.resourcemanager.v1.UpdateCloudRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATECLOUDREQUEST,
  '__module__' : 'yandex.cloud.resourcemanager.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.resourcemanager.v1.UpdateCloudRequest)
  })
_sym_db.RegisterMessage(UpdateCloudRequest)
_sym_db.RegisterMessage(UpdateCloudRequest.LabelsEntry)

UpdateCloudMetadata = _reflection.GeneratedProtocolMessageType('UpdateCloudMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECLOUDMETADATA,
  '__module__' : 'yandex.cloud.resourcemanager.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.resourcemanager.v1.UpdateCloudMetadata)
  })
_sym_db.RegisterMessage(UpdateCloudMetadata)

DeleteCloudRequest = _reflection.GeneratedProtocolMessageType('DeleteCloudRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECLOUDREQUEST,
  '__module__' : 'yandex.cloud.resourcemanager.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.resourcemanager.v1.DeleteCloudRequest)
  })
_sym_db.RegisterMessage(DeleteCloudRequest)

DeleteCloudMetadata = _reflection.GeneratedProtocolMessageType('DeleteCloudMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETECLOUDMETADATA,
  '__module__' : 'yandex.cloud.resourcemanager.v1.cloud_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.resourcemanager.v1.DeleteCloudMetadata)
  })
_sym_db.RegisterMessage(DeleteCloudMetadata)


DESCRIPTOR._options = None
_GETCLOUDREQUEST.fields_by_name['cloud_id']._options = None
_LISTCLOUDSREQUEST.fields_by_name['page_size']._options = None
_LISTCLOUDSREQUEST.fields_by_name['page_token']._options = None
_LISTCLOUDSREQUEST.fields_by_name['filter']._options = None
_LISTCLOUDSREQUEST.fields_by_name['organization_id']._options = None
_CREATECLOUDREQUEST_LABELSENTRY._options = None
_CREATECLOUDREQUEST.fields_by_name['organization_id']._options = None
_CREATECLOUDREQUEST.fields_by_name['name']._options = None
_CREATECLOUDREQUEST.fields_by_name['description']._options = None
_CREATECLOUDREQUEST.fields_by_name['labels']._options = None
_LISTCLOUDOPERATIONSREQUEST.fields_by_name['cloud_id']._options = None
_LISTCLOUDOPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTCLOUDOPERATIONSREQUEST.fields_by_name['page_token']._options = None
_UPDATECLOUDREQUEST_LABELSENTRY._options = None
_UPDATECLOUDREQUEST.fields_by_name['cloud_id']._options = None
_UPDATECLOUDREQUEST.fields_by_name['name']._options = None
_UPDATECLOUDREQUEST.fields_by_name['description']._options = None
_UPDATECLOUDREQUEST.fields_by_name['labels']._options = None
_DELETECLOUDREQUEST.fields_by_name['cloud_id']._options = None

_CLOUDSERVICE = _descriptor.ServiceDescriptor(
  name='CloudService',
  full_name='yandex.cloud.resourcemanager.v1.CloudService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1907,
  serialized_end=3675,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.resourcemanager.v1.CloudService.Get',
    index=0,
    containing_service=None,
    input_type=_GETCLOUDREQUEST,
    output_type=yandex_dot_cloud_dot_resourcemanager_dot_v1_dot_cloud__pb2._CLOUD,
    serialized_options=b'\202\323\344\223\002(\022&/resource-manager/v1/clouds/{cloud_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.resourcemanager.v1.CloudService.List',
    index=1,
    containing_service=None,
    input_type=_LISTCLOUDSREQUEST,
    output_type=_LISTCLOUDSRESPONSE,
    serialized_options=b'\202\323\344\223\002\035\022\033/resource-manager/v1/clouds',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.resourcemanager.v1.CloudService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATECLOUDREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002 \"\033/resource-manager/v1/clouds:\001*\262\322*\034\n\023CreateCloudMetadata\022\005Cloud',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.resourcemanager.v1.CloudService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATECLOUDREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002+2&/resource-manager/v1/clouds/{cloud_id}:\001*\262\322*\034\n\023UpdateCloudMetadata\022\005Cloud',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.resourcemanager.v1.CloudService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETECLOUDREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002(*&/resource-manager/v1/clouds/{cloud_id}\262\322*,\n\023DeleteCloudMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.resourcemanager.v1.CloudService.ListOperations',
    index=5,
    containing_service=None,
    input_type=_LISTCLOUDOPERATIONSREQUEST,
    output_type=_LISTCLOUDOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\0023\0221/resource-manager/v1/clouds/{cloud_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListAccessBindings',
    full_name='yandex.cloud.resourcemanager.v1.CloudService.ListAccessBindings',
    index=6,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSRESPONSE,
    serialized_options=b'\202\323\344\223\002>\022</resource-manager/v1/clouds/{resource_id}:listAccessBindings',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetAccessBindings',
    full_name='yandex.cloud.resourcemanager.v1.CloudService.SetAccessBindings',
    index=7,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._SETACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002@\";/resource-manager/v1/clouds/{resource_id}:setAccessBindings:\001*\262\322*H\n access.SetAccessBindingsMetadata\022$access.AccessBindingsOperationResult',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAccessBindings',
    full_name='yandex.cloud.resourcemanager.v1.CloudService.UpdateAccessBindings',
    index=8,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._UPDATEACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002C\">/resource-manager/v1/clouds/{resource_id}:updateAccessBindings:\001*\262\322*K\n#access.UpdateAccessBindingsMetadata\022$access.AccessBindingsOperationResult',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CLOUDSERVICE)

DESCRIPTOR.services_by_name['CloudService'] = _CLOUDSERVICE

# @@protoc_insertion_point(module_scope)
