# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/monitoring/v3/chart_widget.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud.monitoring.v3 import downsampling_pb2 as yandex_dot_cloud_dot_monitoring_dot_v3_dot_downsampling__pb2
from yandex.cloud.monitoring.v3 import unit_format_pb2 as yandex_dot_cloud_dot_monitoring_dot_v3_dot_unit__format__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/monitoring/v3/chart_widget.proto',
  package='yandex.cloud.monitoring.v3',
  syntax='proto3',
  serialized_options=b'\n\036yandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoring',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-yandex/cloud/monitoring/v3/chart_widget.proto\x12\x1ayandex.cloud.monitoring.v3\x1a\x1egoogle/protobuf/wrappers.proto\x1a-yandex/cloud/monitoring/v3/downsampling.proto\x1a,yandex/cloud/monitoring/v3/unit_format.proto\"\xd3 \n\x0b\x43hartWidget\x12\n\n\x02id\x18\x01 \x01(\t\x12@\n\x07queries\x18\x02 \x01(\x0b\x32/.yandex.cloud.monitoring.v3.ChartWidget.Queries\x12]\n\x16visualization_settings\x18\x03 \x01(\x0b\x32=.yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings\x12Q\n\x10series_overrides\x18\x04 \x03(\x0b\x32\x37.yandex.cloud.monitoring.v3.ChartWidget.SeriesOverrides\x12X\n\x14name_hiding_settings\x18\x05 \x01(\x0b\x32:.yandex.cloud.monitoring.v3.ChartWidget.NameHidingSettings\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\r\n\x05title\x18\x07 \x01(\t\x12\x16\n\x0e\x64isplay_legend\x18\x08 \x01(\x08\x12\x46\n\x06\x66reeze\x18\t \x01(\x0e\x32\x36.yandex.cloud.monitoring.v3.ChartWidget.FreezeDuration\x1a\xce\x01\n\x07Queries\x12G\n\x07targets\x18\x01 \x03(\x0b\x32\x36.yandex.cloud.monitoring.v3.ChartWidget.Queries.Target\x12>\n\x0c\x64ownsampling\x18\x02 \x01(\x0b\x32(.yandex.cloud.monitoring.v3.Downsampling\x1a:\n\x06Target\x12\r\n\x05query\x18\x01 \x01(\t\x12\x11\n\ttext_mode\x18\x02 \x01(\x08\x12\x0e\n\x06hidden\x18\x03 \x01(\x08\x1a\xbe\x13\n\x15VisualizationSettings\x12]\n\x04type\x18\x01 \x01(\x0e\x32O.yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.VisualizationType\x12\x11\n\tnormalize\x18\x02 \x01(\x08\x12^\n\x0binterpolate\x18\x03 \x01(\x0e\x32I.yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.Interpolate\x12\x64\n\x0b\x61ggregation\x18\x04 \x01(\x0e\x32O.yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.SeriesAggregation\x12p\n\x15\x63olor_scheme_settings\x18\x05 \x01(\x0b\x32Q.yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.ColorSchemeSettings\x12g\n\x10heatmap_settings\x18\x06 \x01(\x0b\x32M.yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.HeatmapSettings\x12\x63\n\x0eyaxis_settings\x18\x07 \x01(\x0b\x32K.yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.YaxisSettings\x12\r\n\x05title\x18\x08 \x01(\t\x12\x13\n\x0bshow_labels\x18\t \x01(\x08\x1a\xac\x04\n\x13\x43olorSchemeSettings\x12{\n\tautomatic\x18\x01 \x01(\x0b\x32\x66.yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.ColorSchemeSettings.AutomaticColorSchemeH\x00\x12y\n\x08standard\x18\x02 \x01(\x0b\x32\x65.yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.ColorSchemeSettings.StandardColorSchemeH\x00\x12y\n\x08gradient\x18\x03 \x01(\x0b\x32\x65.yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.ColorSchemeSettings.GradientColorSchemeH\x00\x1a\x16\n\x14\x41utomaticColorScheme\x1a\x15\n\x13StandardColorScheme\x1ai\n\x13GradientColorScheme\x12\x13\n\x0bgreen_value\x18\x02 \x01(\t\x12\x14\n\x0cyellow_value\x18\x03 \x01(\t\x12\x11\n\tred_value\x18\x04 \x01(\t\x12\x14\n\x0cviolet_value\x18\x05 \x01(\tB\x08\n\x06scheme\x1a\x65\n\x0fHeatmapSettings\x12\x13\n\x0bgreen_value\x18\x02 \x01(\t\x12\x14\n\x0cyellow_value\x18\x03 \x01(\t\x12\x11\n\tred_value\x18\x04 \x01(\t\x12\x14\n\x0cviolet_value\x18\x05 \x01(\t\x1a\xf4\x01\n\x05Yaxis\x12U\n\x04type\x18\x01 \x01(\x0e\x32G.yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.YaxisType\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0b\n\x03min\x18\x03 \x01(\t\x12\x0b\n\x03max\x18\x04 \x01(\t\x12;\n\x0bunit_format\x18\x05 \x01(\x0e\x32&.yandex.cloud.monitoring.v3.UnitFormat\x12.\n\tprecision\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x1a\xb6\x01\n\rYaxisSettings\x12Q\n\x04left\x18\x01 \x01(\x0b\x32\x43.yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.Yaxis\x12R\n\x05right\x18\x02 \x01(\x0b\x32\x43.yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.Yaxis\"\xae\x02\n\x11VisualizationType\x12\"\n\x1eVISUALIZATION_TYPE_UNSPECIFIED\x10\x00\x12\x1b\n\x17VISUALIZATION_TYPE_LINE\x10\x01\x12\x1c\n\x18VISUALIZATION_TYPE_STACK\x10\x02\x12\x1d\n\x19VISUALIZATION_TYPE_COLUMN\x10\x03\x12\x1d\n\x19VISUALIZATION_TYPE_POINTS\x10\x04\x12\x1a\n\x16VISUALIZATION_TYPE_PIE\x10\x05\x12\x1b\n\x17VISUALIZATION_TYPE_BARS\x10\x06\x12#\n\x1fVISUALIZATION_TYPE_DISTRIBUTION\x10\x07\x12\x1e\n\x1aVISUALIZATION_TYPE_HEATMAP\x10\x08\"o\n\x0bInterpolate\x12\x1b\n\x17INTERPOLATE_UNSPECIFIED\x10\x00\x12\x16\n\x12INTERPOLATE_LINEAR\x10\x01\x12\x14\n\x10INTERPOLATE_LEFT\x10\x02\x12\x15\n\x11INTERPOLATE_RIGHT\x10\x03\"Z\n\tYaxisType\x12\x1a\n\x16YAXIS_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11YAXIS_TYPE_LINEAR\x10\x01\x12\x1a\n\x16YAXIS_TYPE_LOGARITHMIC\x10\x02\"\xc4\x01\n\x11SeriesAggregation\x12\"\n\x1eSERIES_AGGREGATION_UNSPECIFIED\x10\x00\x12\x1a\n\x16SERIES_AGGREGATION_AVG\x10\x01\x12\x1a\n\x16SERIES_AGGREGATION_MIN\x10\x02\x12\x1a\n\x16SERIES_AGGREGATION_MAX\x10\x03\x12\x1b\n\x17SERIES_AGGREGATION_LAST\x10\x04\x12\x1a\n\x16SERIES_AGGREGATION_SUM\x10\x05\x1a\x80\x06\n\x0fSeriesOverrides\x12\x0e\n\x04name\x18\x01 \x01(\tH\x00\x12\x16\n\x0ctarget_index\x18\x02 \x01(\tH\x00\x12`\n\x08settings\x18\x03 \x01(\x0b\x32N.yandex.cloud.monitoring.v3.ChartWidget.SeriesOverrides.SeriesOverrideSettings\x1a\x9a\x02\n\x16SeriesOverrideSettings\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x63olor\x18\x02 \x01(\t\x12]\n\x04type\x18\x03 \x01(\x0e\x32O.yandex.cloud.monitoring.v3.ChartWidget.SeriesOverrides.SeriesVisualizationType\x12\x12\n\nstack_name\x18\x04 \x01(\t\x12\x11\n\tgrow_down\x18\x05 \x01(\x08\x12]\n\x0eyaxis_position\x18\x06 \x01(\x0e\x32\x45.yandex.cloud.monitoring.v3.ChartWidget.SeriesOverrides.YaxisPosition\"b\n\rYaxisPosition\x12\x1e\n\x1aYAXIS_POSITION_UNSPECIFIED\x10\x00\x12\x17\n\x13YAXIS_POSITION_LEFT\x10\x01\x12\x18\n\x14YAXIS_POSITION_RIGHT\x10\x02\"\xd9\x01\n\x17SeriesVisualizationType\x12)\n%SERIES_VISUALIZATION_TYPE_UNSPECIFIED\x10\x00\x12\"\n\x1eSERIES_VISUALIZATION_TYPE_LINE\x10\x01\x12#\n\x1fSERIES_VISUALIZATION_TYPE_STACK\x10\x02\x12$\n SERIES_VISUALIZATION_TYPE_COLUMN\x10\x03\x12$\n SERIES_VISUALIZATION_TYPE_POINTS\x10\x04\x42\x06\n\x04type\x1a\x35\n\x12NameHidingSettings\x12\x10\n\x08positive\x18\x01 \x01(\x08\x12\r\n\x05names\x18\x02 \x03(\t\"\x99\x01\n\x0e\x46reezeDuration\x12\x1f\n\x1b\x46REEZE_DURATION_UNSPECIFIED\x10\x00\x12\x18\n\x14\x46REEZE_DURATION_HOUR\x10\x01\x12\x17\n\x13\x46REEZE_DURATION_DAY\x10\x02\x12\x18\n\x14\x46REEZE_DURATION_WEEK\x10\x03\x12\x19\n\x15\x46REEZE_DURATION_MONTH\x10\x04\x42k\n\x1eyandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoringb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,yandex_dot_cloud_dot_monitoring_dot_v3_dot_downsampling__pb2.DESCRIPTOR,yandex_dot_cloud_dot_monitoring_dot_v3_dot_unit__format__pb2.DESCRIPTOR,])



_CHARTWIDGET_VISUALIZATIONSETTINGS_VISUALIZATIONTYPE = _descriptor.EnumDescriptor(
  name='VisualizationType',
  full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.VisualizationType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VISUALIZATION_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VISUALIZATION_TYPE_LINE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VISUALIZATION_TYPE_STACK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VISUALIZATION_TYPE_COLUMN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VISUALIZATION_TYPE_POINTS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VISUALIZATION_TYPE_PIE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VISUALIZATION_TYPE_BARS', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VISUALIZATION_TYPE_DISTRIBUTION', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VISUALIZATION_TYPE_HEATMAP', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2694,
  serialized_end=2996,
)
_sym_db.RegisterEnumDescriptor(_CHARTWIDGET_VISUALIZATIONSETTINGS_VISUALIZATIONTYPE)

_CHARTWIDGET_VISUALIZATIONSETTINGS_INTERPOLATE = _descriptor.EnumDescriptor(
  name='Interpolate',
  full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.Interpolate',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INTERPOLATE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTERPOLATE_LINEAR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTERPOLATE_LEFT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTERPOLATE_RIGHT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2998,
  serialized_end=3109,
)
_sym_db.RegisterEnumDescriptor(_CHARTWIDGET_VISUALIZATIONSETTINGS_INTERPOLATE)

_CHARTWIDGET_VISUALIZATIONSETTINGS_YAXISTYPE = _descriptor.EnumDescriptor(
  name='YaxisType',
  full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.YaxisType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='YAXIS_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YAXIS_TYPE_LINEAR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YAXIS_TYPE_LOGARITHMIC', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3111,
  serialized_end=3201,
)
_sym_db.RegisterEnumDescriptor(_CHARTWIDGET_VISUALIZATIONSETTINGS_YAXISTYPE)

_CHARTWIDGET_VISUALIZATIONSETTINGS_SERIESAGGREGATION = _descriptor.EnumDescriptor(
  name='SeriesAggregation',
  full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.SeriesAggregation',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SERIES_AGGREGATION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SERIES_AGGREGATION_AVG', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SERIES_AGGREGATION_MIN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SERIES_AGGREGATION_MAX', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SERIES_AGGREGATION_LAST', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SERIES_AGGREGATION_SUM', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3204,
  serialized_end=3400,
)
_sym_db.RegisterEnumDescriptor(_CHARTWIDGET_VISUALIZATIONSETTINGS_SERIESAGGREGATION)

_CHARTWIDGET_SERIESOVERRIDES_YAXISPOSITION = _descriptor.EnumDescriptor(
  name='YaxisPosition',
  full_name='yandex.cloud.monitoring.v3.ChartWidget.SeriesOverrides.YaxisPosition',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='YAXIS_POSITION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YAXIS_POSITION_LEFT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YAXIS_POSITION_RIGHT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3845,
  serialized_end=3943,
)
_sym_db.RegisterEnumDescriptor(_CHARTWIDGET_SERIESOVERRIDES_YAXISPOSITION)

_CHARTWIDGET_SERIESOVERRIDES_SERIESVISUALIZATIONTYPE = _descriptor.EnumDescriptor(
  name='SeriesVisualizationType',
  full_name='yandex.cloud.monitoring.v3.ChartWidget.SeriesOverrides.SeriesVisualizationType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SERIES_VISUALIZATION_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SERIES_VISUALIZATION_TYPE_LINE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SERIES_VISUALIZATION_TYPE_STACK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SERIES_VISUALIZATION_TYPE_COLUMN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SERIES_VISUALIZATION_TYPE_POINTS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3946,
  serialized_end=4163,
)
_sym_db.RegisterEnumDescriptor(_CHARTWIDGET_SERIESOVERRIDES_SERIESVISUALIZATIONTYPE)

_CHARTWIDGET_FREEZEDURATION = _descriptor.EnumDescriptor(
  name='FreezeDuration',
  full_name='yandex.cloud.monitoring.v3.ChartWidget.FreezeDuration',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FREEZE_DURATION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FREEZE_DURATION_HOUR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FREEZE_DURATION_DAY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FREEZE_DURATION_WEEK', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FREEZE_DURATION_MONTH', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4229,
  serialized_end=4382,
)
_sym_db.RegisterEnumDescriptor(_CHARTWIDGET_FREEZEDURATION)


_CHARTWIDGET_QUERIES_TARGET = _descriptor.Descriptor(
  name='Target',
  full_name='yandex.cloud.monitoring.v3.ChartWidget.Queries.Target',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='yandex.cloud.monitoring.v3.ChartWidget.Queries.Target.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text_mode', full_name='yandex.cloud.monitoring.v3.ChartWidget.Queries.Target.text_mode', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hidden', full_name='yandex.cloud.monitoring.v3.ChartWidget.Queries.Target.hidden', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=845,
  serialized_end=903,
)

_CHARTWIDGET_QUERIES = _descriptor.Descriptor(
  name='Queries',
  full_name='yandex.cloud.monitoring.v3.ChartWidget.Queries',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='targets', full_name='yandex.cloud.monitoring.v3.ChartWidget.Queries.targets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='downsampling', full_name='yandex.cloud.monitoring.v3.ChartWidget.Queries.downsampling', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CHARTWIDGET_QUERIES_TARGET, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=697,
  serialized_end=903,
)

_CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_AUTOMATICCOLORSCHEME = _descriptor.Descriptor(
  name='AutomaticColorScheme',
  full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.ColorSchemeSettings.AutomaticColorScheme',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1994,
  serialized_end=2016,
)

_CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_STANDARDCOLORSCHEME = _descriptor.Descriptor(
  name='StandardColorScheme',
  full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.ColorSchemeSettings.StandardColorScheme',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2018,
  serialized_end=2039,
)

_CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_GRADIENTCOLORSCHEME = _descriptor.Descriptor(
  name='GradientColorScheme',
  full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.ColorSchemeSettings.GradientColorScheme',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='green_value', full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.ColorSchemeSettings.GradientColorScheme.green_value', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yellow_value', full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.ColorSchemeSettings.GradientColorScheme.yellow_value', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='red_value', full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.ColorSchemeSettings.GradientColorScheme.red_value', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='violet_value', full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.ColorSchemeSettings.GradientColorScheme.violet_value', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2041,
  serialized_end=2146,
)

_CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS = _descriptor.Descriptor(
  name='ColorSchemeSettings',
  full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.ColorSchemeSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='automatic', full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.ColorSchemeSettings.automatic', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='standard', full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.ColorSchemeSettings.standard', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gradient', full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.ColorSchemeSettings.gradient', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_AUTOMATICCOLORSCHEME, _CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_STANDARDCOLORSCHEME, _CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_GRADIENTCOLORSCHEME, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='scheme', full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.ColorSchemeSettings.scheme',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1600,
  serialized_end=2156,
)

_CHARTWIDGET_VISUALIZATIONSETTINGS_HEATMAPSETTINGS = _descriptor.Descriptor(
  name='HeatmapSettings',
  full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.HeatmapSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='green_value', full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.HeatmapSettings.green_value', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yellow_value', full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.HeatmapSettings.yellow_value', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='red_value', full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.HeatmapSettings.red_value', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='violet_value', full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.HeatmapSettings.violet_value', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2158,
  serialized_end=2259,
)

_CHARTWIDGET_VISUALIZATIONSETTINGS_YAXIS = _descriptor.Descriptor(
  name='Yaxis',
  full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.Yaxis',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.Yaxis.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.Yaxis.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min', full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.Yaxis.min', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max', full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.Yaxis.max', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit_format', full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.Yaxis.unit_format', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='precision', full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.Yaxis.precision', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2262,
  serialized_end=2506,
)

_CHARTWIDGET_VISUALIZATIONSETTINGS_YAXISSETTINGS = _descriptor.Descriptor(
  name='YaxisSettings',
  full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.YaxisSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='left', full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.YaxisSettings.left', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right', full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.YaxisSettings.right', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2509,
  serialized_end=2691,
)

_CHARTWIDGET_VISUALIZATIONSETTINGS = _descriptor.Descriptor(
  name='VisualizationSettings',
  full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='normalize', full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.normalize', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interpolate', full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.interpolate', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aggregation', full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.aggregation', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='color_scheme_settings', full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.color_scheme_settings', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heatmap_settings', full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.heatmap_settings', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaxis_settings', full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.yaxis_settings', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.title', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='show_labels', full_name='yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.show_labels', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS, _CHARTWIDGET_VISUALIZATIONSETTINGS_HEATMAPSETTINGS, _CHARTWIDGET_VISUALIZATIONSETTINGS_YAXIS, _CHARTWIDGET_VISUALIZATIONSETTINGS_YAXISSETTINGS, ],
  enum_types=[
    _CHARTWIDGET_VISUALIZATIONSETTINGS_VISUALIZATIONTYPE,
    _CHARTWIDGET_VISUALIZATIONSETTINGS_INTERPOLATE,
    _CHARTWIDGET_VISUALIZATIONSETTINGS_YAXISTYPE,
    _CHARTWIDGET_VISUALIZATIONSETTINGS_SERIESAGGREGATION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=906,
  serialized_end=3400,
)

_CHARTWIDGET_SERIESOVERRIDES_SERIESOVERRIDESETTINGS = _descriptor.Descriptor(
  name='SeriesOverrideSettings',
  full_name='yandex.cloud.monitoring.v3.ChartWidget.SeriesOverrides.SeriesOverrideSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.monitoring.v3.ChartWidget.SeriesOverrides.SeriesOverrideSettings.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='color', full_name='yandex.cloud.monitoring.v3.ChartWidget.SeriesOverrides.SeriesOverrideSettings.color', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.monitoring.v3.ChartWidget.SeriesOverrides.SeriesOverrideSettings.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stack_name', full_name='yandex.cloud.monitoring.v3.ChartWidget.SeriesOverrides.SeriesOverrideSettings.stack_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grow_down', full_name='yandex.cloud.monitoring.v3.ChartWidget.SeriesOverrides.SeriesOverrideSettings.grow_down', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaxis_position', full_name='yandex.cloud.monitoring.v3.ChartWidget.SeriesOverrides.SeriesOverrideSettings.yaxis_position', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3561,
  serialized_end=3843,
)

_CHARTWIDGET_SERIESOVERRIDES = _descriptor.Descriptor(
  name='SeriesOverrides',
  full_name='yandex.cloud.monitoring.v3.ChartWidget.SeriesOverrides',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.monitoring.v3.ChartWidget.SeriesOverrides.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_index', full_name='yandex.cloud.monitoring.v3.ChartWidget.SeriesOverrides.target_index', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settings', full_name='yandex.cloud.monitoring.v3.ChartWidget.SeriesOverrides.settings', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CHARTWIDGET_SERIESOVERRIDES_SERIESOVERRIDESETTINGS, ],
  enum_types=[
    _CHARTWIDGET_SERIESOVERRIDES_YAXISPOSITION,
    _CHARTWIDGET_SERIESOVERRIDES_SERIESVISUALIZATIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='yandex.cloud.monitoring.v3.ChartWidget.SeriesOverrides.type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3403,
  serialized_end=4171,
)

_CHARTWIDGET_NAMEHIDINGSETTINGS = _descriptor.Descriptor(
  name='NameHidingSettings',
  full_name='yandex.cloud.monitoring.v3.ChartWidget.NameHidingSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='positive', full_name='yandex.cloud.monitoring.v3.ChartWidget.NameHidingSettings.positive', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='names', full_name='yandex.cloud.monitoring.v3.ChartWidget.NameHidingSettings.names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4173,
  serialized_end=4226,
)

_CHARTWIDGET = _descriptor.Descriptor(
  name='ChartWidget',
  full_name='yandex.cloud.monitoring.v3.ChartWidget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.monitoring.v3.ChartWidget.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='queries', full_name='yandex.cloud.monitoring.v3.ChartWidget.queries', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visualization_settings', full_name='yandex.cloud.monitoring.v3.ChartWidget.visualization_settings', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='series_overrides', full_name='yandex.cloud.monitoring.v3.ChartWidget.series_overrides', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name_hiding_settings', full_name='yandex.cloud.monitoring.v3.ChartWidget.name_hiding_settings', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.monitoring.v3.ChartWidget.description', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='yandex.cloud.monitoring.v3.ChartWidget.title', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_legend', full_name='yandex.cloud.monitoring.v3.ChartWidget.display_legend', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='freeze', full_name='yandex.cloud.monitoring.v3.ChartWidget.freeze', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CHARTWIDGET_QUERIES, _CHARTWIDGET_VISUALIZATIONSETTINGS, _CHARTWIDGET_SERIESOVERRIDES, _CHARTWIDGET_NAMEHIDINGSETTINGS, ],
  enum_types=[
    _CHARTWIDGET_FREEZEDURATION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=203,
  serialized_end=4382,
)

_CHARTWIDGET_QUERIES_TARGET.containing_type = _CHARTWIDGET_QUERIES
_CHARTWIDGET_QUERIES.fields_by_name['targets'].message_type = _CHARTWIDGET_QUERIES_TARGET
_CHARTWIDGET_QUERIES.fields_by_name['downsampling'].message_type = yandex_dot_cloud_dot_monitoring_dot_v3_dot_downsampling__pb2._DOWNSAMPLING
_CHARTWIDGET_QUERIES.containing_type = _CHARTWIDGET
_CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_AUTOMATICCOLORSCHEME.containing_type = _CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS
_CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_STANDARDCOLORSCHEME.containing_type = _CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS
_CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_GRADIENTCOLORSCHEME.containing_type = _CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS
_CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS.fields_by_name['automatic'].message_type = _CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_AUTOMATICCOLORSCHEME
_CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS.fields_by_name['standard'].message_type = _CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_STANDARDCOLORSCHEME
_CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS.fields_by_name['gradient'].message_type = _CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_GRADIENTCOLORSCHEME
_CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS.containing_type = _CHARTWIDGET_VISUALIZATIONSETTINGS
_CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS.oneofs_by_name['scheme'].fields.append(
  _CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS.fields_by_name['automatic'])
_CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS.fields_by_name['automatic'].containing_oneof = _CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS.oneofs_by_name['scheme']
_CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS.oneofs_by_name['scheme'].fields.append(
  _CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS.fields_by_name['standard'])
_CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS.fields_by_name['standard'].containing_oneof = _CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS.oneofs_by_name['scheme']
_CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS.oneofs_by_name['scheme'].fields.append(
  _CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS.fields_by_name['gradient'])
_CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS.fields_by_name['gradient'].containing_oneof = _CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS.oneofs_by_name['scheme']
_CHARTWIDGET_VISUALIZATIONSETTINGS_HEATMAPSETTINGS.containing_type = _CHARTWIDGET_VISUALIZATIONSETTINGS
_CHARTWIDGET_VISUALIZATIONSETTINGS_YAXIS.fields_by_name['type'].enum_type = _CHARTWIDGET_VISUALIZATIONSETTINGS_YAXISTYPE
_CHARTWIDGET_VISUALIZATIONSETTINGS_YAXIS.fields_by_name['unit_format'].enum_type = yandex_dot_cloud_dot_monitoring_dot_v3_dot_unit__format__pb2._UNITFORMAT
_CHARTWIDGET_VISUALIZATIONSETTINGS_YAXIS.fields_by_name['precision'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CHARTWIDGET_VISUALIZATIONSETTINGS_YAXIS.containing_type = _CHARTWIDGET_VISUALIZATIONSETTINGS
_CHARTWIDGET_VISUALIZATIONSETTINGS_YAXISSETTINGS.fields_by_name['left'].message_type = _CHARTWIDGET_VISUALIZATIONSETTINGS_YAXIS
_CHARTWIDGET_VISUALIZATIONSETTINGS_YAXISSETTINGS.fields_by_name['right'].message_type = _CHARTWIDGET_VISUALIZATIONSETTINGS_YAXIS
_CHARTWIDGET_VISUALIZATIONSETTINGS_YAXISSETTINGS.containing_type = _CHARTWIDGET_VISUALIZATIONSETTINGS
_CHARTWIDGET_VISUALIZATIONSETTINGS.fields_by_name['type'].enum_type = _CHARTWIDGET_VISUALIZATIONSETTINGS_VISUALIZATIONTYPE
_CHARTWIDGET_VISUALIZATIONSETTINGS.fields_by_name['interpolate'].enum_type = _CHARTWIDGET_VISUALIZATIONSETTINGS_INTERPOLATE
_CHARTWIDGET_VISUALIZATIONSETTINGS.fields_by_name['aggregation'].enum_type = _CHARTWIDGET_VISUALIZATIONSETTINGS_SERIESAGGREGATION
_CHARTWIDGET_VISUALIZATIONSETTINGS.fields_by_name['color_scheme_settings'].message_type = _CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS
_CHARTWIDGET_VISUALIZATIONSETTINGS.fields_by_name['heatmap_settings'].message_type = _CHARTWIDGET_VISUALIZATIONSETTINGS_HEATMAPSETTINGS
_CHARTWIDGET_VISUALIZATIONSETTINGS.fields_by_name['yaxis_settings'].message_type = _CHARTWIDGET_VISUALIZATIONSETTINGS_YAXISSETTINGS
_CHARTWIDGET_VISUALIZATIONSETTINGS.containing_type = _CHARTWIDGET
_CHARTWIDGET_VISUALIZATIONSETTINGS_VISUALIZATIONTYPE.containing_type = _CHARTWIDGET_VISUALIZATIONSETTINGS
_CHARTWIDGET_VISUALIZATIONSETTINGS_INTERPOLATE.containing_type = _CHARTWIDGET_VISUALIZATIONSETTINGS
_CHARTWIDGET_VISUALIZATIONSETTINGS_YAXISTYPE.containing_type = _CHARTWIDGET_VISUALIZATIONSETTINGS
_CHARTWIDGET_VISUALIZATIONSETTINGS_SERIESAGGREGATION.containing_type = _CHARTWIDGET_VISUALIZATIONSETTINGS
_CHARTWIDGET_SERIESOVERRIDES_SERIESOVERRIDESETTINGS.fields_by_name['type'].enum_type = _CHARTWIDGET_SERIESOVERRIDES_SERIESVISUALIZATIONTYPE
_CHARTWIDGET_SERIESOVERRIDES_SERIESOVERRIDESETTINGS.fields_by_name['yaxis_position'].enum_type = _CHARTWIDGET_SERIESOVERRIDES_YAXISPOSITION
_CHARTWIDGET_SERIESOVERRIDES_SERIESOVERRIDESETTINGS.containing_type = _CHARTWIDGET_SERIESOVERRIDES
_CHARTWIDGET_SERIESOVERRIDES.fields_by_name['settings'].message_type = _CHARTWIDGET_SERIESOVERRIDES_SERIESOVERRIDESETTINGS
_CHARTWIDGET_SERIESOVERRIDES.containing_type = _CHARTWIDGET
_CHARTWIDGET_SERIESOVERRIDES_YAXISPOSITION.containing_type = _CHARTWIDGET_SERIESOVERRIDES
_CHARTWIDGET_SERIESOVERRIDES_SERIESVISUALIZATIONTYPE.containing_type = _CHARTWIDGET_SERIESOVERRIDES
_CHARTWIDGET_SERIESOVERRIDES.oneofs_by_name['type'].fields.append(
  _CHARTWIDGET_SERIESOVERRIDES.fields_by_name['name'])
_CHARTWIDGET_SERIESOVERRIDES.fields_by_name['name'].containing_oneof = _CHARTWIDGET_SERIESOVERRIDES.oneofs_by_name['type']
_CHARTWIDGET_SERIESOVERRIDES.oneofs_by_name['type'].fields.append(
  _CHARTWIDGET_SERIESOVERRIDES.fields_by_name['target_index'])
_CHARTWIDGET_SERIESOVERRIDES.fields_by_name['target_index'].containing_oneof = _CHARTWIDGET_SERIESOVERRIDES.oneofs_by_name['type']
_CHARTWIDGET_NAMEHIDINGSETTINGS.containing_type = _CHARTWIDGET
_CHARTWIDGET.fields_by_name['queries'].message_type = _CHARTWIDGET_QUERIES
_CHARTWIDGET.fields_by_name['visualization_settings'].message_type = _CHARTWIDGET_VISUALIZATIONSETTINGS
_CHARTWIDGET.fields_by_name['series_overrides'].message_type = _CHARTWIDGET_SERIESOVERRIDES
_CHARTWIDGET.fields_by_name['name_hiding_settings'].message_type = _CHARTWIDGET_NAMEHIDINGSETTINGS
_CHARTWIDGET.fields_by_name['freeze'].enum_type = _CHARTWIDGET_FREEZEDURATION
_CHARTWIDGET_FREEZEDURATION.containing_type = _CHARTWIDGET
DESCRIPTOR.message_types_by_name['ChartWidget'] = _CHARTWIDGET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ChartWidget = _reflection.GeneratedProtocolMessageType('ChartWidget', (_message.Message,), {

  'Queries' : _reflection.GeneratedProtocolMessageType('Queries', (_message.Message,), {

    'Target' : _reflection.GeneratedProtocolMessageType('Target', (_message.Message,), {
      'DESCRIPTOR' : _CHARTWIDGET_QUERIES_TARGET,
      '__module__' : 'yandex.cloud.monitoring.v3.chart_widget_pb2'
      # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.ChartWidget.Queries.Target)
      })
    ,
    'DESCRIPTOR' : _CHARTWIDGET_QUERIES,
    '__module__' : 'yandex.cloud.monitoring.v3.chart_widget_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.ChartWidget.Queries)
    })
  ,

  'VisualizationSettings' : _reflection.GeneratedProtocolMessageType('VisualizationSettings', (_message.Message,), {

    'ColorSchemeSettings' : _reflection.GeneratedProtocolMessageType('ColorSchemeSettings', (_message.Message,), {

      'AutomaticColorScheme' : _reflection.GeneratedProtocolMessageType('AutomaticColorScheme', (_message.Message,), {
        'DESCRIPTOR' : _CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_AUTOMATICCOLORSCHEME,
        '__module__' : 'yandex.cloud.monitoring.v3.chart_widget_pb2'
        # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.ColorSchemeSettings.AutomaticColorScheme)
        })
      ,

      'StandardColorScheme' : _reflection.GeneratedProtocolMessageType('StandardColorScheme', (_message.Message,), {
        'DESCRIPTOR' : _CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_STANDARDCOLORSCHEME,
        '__module__' : 'yandex.cloud.monitoring.v3.chart_widget_pb2'
        # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.ColorSchemeSettings.StandardColorScheme)
        })
      ,

      'GradientColorScheme' : _reflection.GeneratedProtocolMessageType('GradientColorScheme', (_message.Message,), {
        'DESCRIPTOR' : _CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_GRADIENTCOLORSCHEME,
        '__module__' : 'yandex.cloud.monitoring.v3.chart_widget_pb2'
        # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.ColorSchemeSettings.GradientColorScheme)
        })
      ,
      'DESCRIPTOR' : _CHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS,
      '__module__' : 'yandex.cloud.monitoring.v3.chart_widget_pb2'
      # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.ColorSchemeSettings)
      })
    ,

    'HeatmapSettings' : _reflection.GeneratedProtocolMessageType('HeatmapSettings', (_message.Message,), {
      'DESCRIPTOR' : _CHARTWIDGET_VISUALIZATIONSETTINGS_HEATMAPSETTINGS,
      '__module__' : 'yandex.cloud.monitoring.v3.chart_widget_pb2'
      # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.HeatmapSettings)
      })
    ,

    'Yaxis' : _reflection.GeneratedProtocolMessageType('Yaxis', (_message.Message,), {
      'DESCRIPTOR' : _CHARTWIDGET_VISUALIZATIONSETTINGS_YAXIS,
      '__module__' : 'yandex.cloud.monitoring.v3.chart_widget_pb2'
      # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.Yaxis)
      })
    ,

    'YaxisSettings' : _reflection.GeneratedProtocolMessageType('YaxisSettings', (_message.Message,), {
      'DESCRIPTOR' : _CHARTWIDGET_VISUALIZATIONSETTINGS_YAXISSETTINGS,
      '__module__' : 'yandex.cloud.monitoring.v3.chart_widget_pb2'
      # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings.YaxisSettings)
      })
    ,
    'DESCRIPTOR' : _CHARTWIDGET_VISUALIZATIONSETTINGS,
    '__module__' : 'yandex.cloud.monitoring.v3.chart_widget_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.ChartWidget.VisualizationSettings)
    })
  ,

  'SeriesOverrides' : _reflection.GeneratedProtocolMessageType('SeriesOverrides', (_message.Message,), {

    'SeriesOverrideSettings' : _reflection.GeneratedProtocolMessageType('SeriesOverrideSettings', (_message.Message,), {
      'DESCRIPTOR' : _CHARTWIDGET_SERIESOVERRIDES_SERIESOVERRIDESETTINGS,
      '__module__' : 'yandex.cloud.monitoring.v3.chart_widget_pb2'
      # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.ChartWidget.SeriesOverrides.SeriesOverrideSettings)
      })
    ,
    'DESCRIPTOR' : _CHARTWIDGET_SERIESOVERRIDES,
    '__module__' : 'yandex.cloud.monitoring.v3.chart_widget_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.ChartWidget.SeriesOverrides)
    })
  ,

  'NameHidingSettings' : _reflection.GeneratedProtocolMessageType('NameHidingSettings', (_message.Message,), {
    'DESCRIPTOR' : _CHARTWIDGET_NAMEHIDINGSETTINGS,
    '__module__' : 'yandex.cloud.monitoring.v3.chart_widget_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.ChartWidget.NameHidingSettings)
    })
  ,
  'DESCRIPTOR' : _CHARTWIDGET,
  '__module__' : 'yandex.cloud.monitoring.v3.chart_widget_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.ChartWidget)
  })
_sym_db.RegisterMessage(ChartWidget)
_sym_db.RegisterMessage(ChartWidget.Queries)
_sym_db.RegisterMessage(ChartWidget.Queries.Target)
_sym_db.RegisterMessage(ChartWidget.VisualizationSettings)
_sym_db.RegisterMessage(ChartWidget.VisualizationSettings.ColorSchemeSettings)
_sym_db.RegisterMessage(ChartWidget.VisualizationSettings.ColorSchemeSettings.AutomaticColorScheme)
_sym_db.RegisterMessage(ChartWidget.VisualizationSettings.ColorSchemeSettings.StandardColorScheme)
_sym_db.RegisterMessage(ChartWidget.VisualizationSettings.ColorSchemeSettings.GradientColorScheme)
_sym_db.RegisterMessage(ChartWidget.VisualizationSettings.HeatmapSettings)
_sym_db.RegisterMessage(ChartWidget.VisualizationSettings.Yaxis)
_sym_db.RegisterMessage(ChartWidget.VisualizationSettings.YaxisSettings)
_sym_db.RegisterMessage(ChartWidget.SeriesOverrides)
_sym_db.RegisterMessage(ChartWidget.SeriesOverrides.SeriesOverrideSettings)
_sym_db.RegisterMessage(ChartWidget.NameHidingSettings)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
