# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datatransfer/v1/endpoint/common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/datatransfer/v1/endpoint/common.proto',
  package='yandex.cloud.datatransfer.v1.endpoint',
  syntax='proto3',
  serialized_options=b'\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\252\002%Yandex.Cloud.Datatransfer.V1.EndPoint',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n2yandex/cloud/datatransfer/v1/endpoint/common.proto\x12%yandex.cloud.datatransfer.v1.endpoint\x1a\x1bgoogle/protobuf/empty.proto\"-\n\x07\x41ltName\x12\x11\n\tfrom_name\x18\x01 \x01(\t\x12\x0f\n\x07to_name\x18\x02 \x01(\t\" \n\x06Secret\x12\r\n\x03raw\x18\x01 \x01(\tH\x00\x42\x07\n\x05value\"\x87\x01\n\tColSchema\x12\x0c\n\x04name\x18\x01 \x01(\t\x12?\n\x04type\x18\x02 \x01(\x0e\x32\x31.yandex.cloud.datatransfer.v1.endpoint.ColumnType\x12\x0b\n\x03key\x18\x03 \x01(\x08\x12\x10\n\x08required\x18\x04 \x01(\x08\x12\x0c\n\x04path\x18\x05 \x01(\t\"\x86\x01\n\x07TLSMode\x12*\n\x08\x64isabled\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x43\n\x07\x65nabled\x18\x02 \x01(\x0b\x32\x30.yandex.cloud.datatransfer.v1.endpoint.TLSConfigH\x00\x42\n\n\x08tls_mode\"#\n\tTLSConfig\x12\x16\n\x0e\x63\x61_certificate\x18\x01 \x01(\t\".\n\x0b\x43olumnValue\x12\x16\n\x0cstring_value\x18\x01 \x01(\tH\x00\x42\x07\n\x05value\"\xba\x01\n\x19\x44\x61taTransformationOptions\x12\x16\n\x0e\x63loud_function\x18\x01 \x01(\t\x12\x1a\n\x12service_account_id\x18\x08 \x01(\t\x12\x19\n\x11number_of_retries\x18\x02 \x01(\x03\x12\x13\n\x0b\x62uffer_size\x18\x03 \x01(\t\x12\x1d\n\x15\x62uffer_flush_interval\x18\x04 \x01(\t\x12\x1a\n\x12invocation_timeout\x18\x05 \x01(\t\"M\n\tFieldList\x12@\n\x06\x66ields\x18\x02 \x03(\x0b\x32\x30.yandex.cloud.datatransfer.v1.endpoint.ColSchema\"q\n\nDataSchema\x12\x42\n\x06\x66ields\x18\x02 \x01(\x0b\x32\x30.yandex.cloud.datatransfer.v1.endpoint.FieldListH\x00\x12\x15\n\x0bjson_fields\x18\x01 \x01(\tH\x00\x42\x08\n\x06schema\"\x08\n\x06NoAuth*h\n\x13ObjectTransferStage\x12%\n!OBJECT_TRANSFER_STAGE_UNSPECIFIED\x10\x00\x12\x0f\n\x0b\x42\x45\x46ORE_DATA\x10\x01\x12\x0e\n\nAFTER_DATA\x10\x02\x12\t\n\x05NEVER\x10\x03*U\n\rCleanupPolicy\x12\x1e\n\x1a\x43LEANUP_POLICY_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x44ISABLED\x10\x01\x12\x08\n\x04\x44ROP\x10\x02\x12\x0c\n\x08TRUNCATE\x10\x03*\xc9\x01\n\nColumnType\x12\x1b\n\x17\x43OLUMN_TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05INT64\x10\x0e\x12\t\n\x05INT32\x10\x01\x12\t\n\x05INT16\x10\x02\x12\x08\n\x04INT8\x10\x03\x12\n\n\x06UINT64\x10\x04\x12\n\n\x06UINT32\x10\x05\x12\n\n\x06UINT16\x10\x06\x12\t\n\x05UINT8\x10\x07\x12\n\n\x06\x44OUBLE\x10\x08\x12\x0b\n\x07\x42OOLEAN\x10\t\x12\n\n\x06STRING\x10\n\x12\x08\n\x04UTF8\x10\x0b\x12\x07\n\x03\x41NY\x10\x0c\x12\x0c\n\x08\x44\x41TETIME\x10\rB\xa7\x01\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\xaa\x02%Yandex.Cloud.Datatransfer.V1.EndPointb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])

_OBJECTTRANSFERSTAGE = _descriptor.EnumDescriptor(
  name='ObjectTransferStage',
  full_name='yandex.cloud.datatransfer.v1.endpoint.ObjectTransferStage',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OBJECT_TRANSFER_STAGE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BEFORE_DATA', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AFTER_DATA', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NEVER', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=956,
  serialized_end=1060,
)
_sym_db.RegisterEnumDescriptor(_OBJECTTRANSFERSTAGE)

ObjectTransferStage = enum_type_wrapper.EnumTypeWrapper(_OBJECTTRANSFERSTAGE)
_CLEANUPPOLICY = _descriptor.EnumDescriptor(
  name='CleanupPolicy',
  full_name='yandex.cloud.datatransfer.v1.endpoint.CleanupPolicy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CLEANUP_POLICY_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISABLED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DROP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRUNCATE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1062,
  serialized_end=1147,
)
_sym_db.RegisterEnumDescriptor(_CLEANUPPOLICY)

CleanupPolicy = enum_type_wrapper.EnumTypeWrapper(_CLEANUPPOLICY)
_COLUMNTYPE = _descriptor.EnumDescriptor(
  name='ColumnType',
  full_name='yandex.cloud.datatransfer.v1.endpoint.ColumnType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COLUMN_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INT64', index=1, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INT32', index=2, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INT16', index=3, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INT8', index=4, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UINT64', index=5, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UINT32', index=6, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UINT16', index=7, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UINT8', index=8, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOUBLE', index=9, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BOOLEAN', index=10, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=11, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UTF8', index=12, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ANY', index=13, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATETIME', index=14, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1150,
  serialized_end=1351,
)
_sym_db.RegisterEnumDescriptor(_COLUMNTYPE)

ColumnType = enum_type_wrapper.EnumTypeWrapper(_COLUMNTYPE)
OBJECT_TRANSFER_STAGE_UNSPECIFIED = 0
BEFORE_DATA = 1
AFTER_DATA = 2
NEVER = 3
CLEANUP_POLICY_UNSPECIFIED = 0
DISABLED = 1
DROP = 2
TRUNCATE = 3
COLUMN_TYPE_UNSPECIFIED = 0
INT64 = 14
INT32 = 1
INT16 = 2
INT8 = 3
UINT64 = 4
UINT32 = 5
UINT16 = 6
UINT8 = 7
DOUBLE = 8
BOOLEAN = 9
STRING = 10
UTF8 = 11
ANY = 12
DATETIME = 13



_ALTNAME = _descriptor.Descriptor(
  name='AltName',
  full_name='yandex.cloud.datatransfer.v1.endpoint.AltName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='from_name', full_name='yandex.cloud.datatransfer.v1.endpoint.AltName.from_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_name', full_name='yandex.cloud.datatransfer.v1.endpoint.AltName.to_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=122,
  serialized_end=167,
)


_SECRET = _descriptor.Descriptor(
  name='Secret',
  full_name='yandex.cloud.datatransfer.v1.endpoint.Secret',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='raw', full_name='yandex.cloud.datatransfer.v1.endpoint.Secret.raw', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='yandex.cloud.datatransfer.v1.endpoint.Secret.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=169,
  serialized_end=201,
)


_COLSCHEMA = _descriptor.Descriptor(
  name='ColSchema',
  full_name='yandex.cloud.datatransfer.v1.endpoint.ColSchema',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.datatransfer.v1.endpoint.ColSchema.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.datatransfer.v1.endpoint.ColSchema.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.datatransfer.v1.endpoint.ColSchema.key', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='required', full_name='yandex.cloud.datatransfer.v1.endpoint.ColSchema.required', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='yandex.cloud.datatransfer.v1.endpoint.ColSchema.path', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=204,
  serialized_end=339,
)


_TLSMODE = _descriptor.Descriptor(
  name='TLSMode',
  full_name='yandex.cloud.datatransfer.v1.endpoint.TLSMode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disabled', full_name='yandex.cloud.datatransfer.v1.endpoint.TLSMode.disabled', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='yandex.cloud.datatransfer.v1.endpoint.TLSMode.enabled', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='tls_mode', full_name='yandex.cloud.datatransfer.v1.endpoint.TLSMode.tls_mode',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=342,
  serialized_end=476,
)


_TLSCONFIG = _descriptor.Descriptor(
  name='TLSConfig',
  full_name='yandex.cloud.datatransfer.v1.endpoint.TLSConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ca_certificate', full_name='yandex.cloud.datatransfer.v1.endpoint.TLSConfig.ca_certificate', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=478,
  serialized_end=513,
)


_COLUMNVALUE = _descriptor.Descriptor(
  name='ColumnValue',
  full_name='yandex.cloud.datatransfer.v1.endpoint.ColumnValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='string_value', full_name='yandex.cloud.datatransfer.v1.endpoint.ColumnValue.string_value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='yandex.cloud.datatransfer.v1.endpoint.ColumnValue.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=515,
  serialized_end=561,
)


_DATATRANSFORMATIONOPTIONS = _descriptor.Descriptor(
  name='DataTransformationOptions',
  full_name='yandex.cloud.datatransfer.v1.endpoint.DataTransformationOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cloud_function', full_name='yandex.cloud.datatransfer.v1.endpoint.DataTransformationOptions.cloud_function', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.datatransfer.v1.endpoint.DataTransformationOptions.service_account_id', index=1,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number_of_retries', full_name='yandex.cloud.datatransfer.v1.endpoint.DataTransformationOptions.number_of_retries', index=2,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buffer_size', full_name='yandex.cloud.datatransfer.v1.endpoint.DataTransformationOptions.buffer_size', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buffer_flush_interval', full_name='yandex.cloud.datatransfer.v1.endpoint.DataTransformationOptions.buffer_flush_interval', index=4,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invocation_timeout', full_name='yandex.cloud.datatransfer.v1.endpoint.DataTransformationOptions.invocation_timeout', index=5,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=564,
  serialized_end=750,
)


_FIELDLIST = _descriptor.Descriptor(
  name='FieldList',
  full_name='yandex.cloud.datatransfer.v1.endpoint.FieldList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fields', full_name='yandex.cloud.datatransfer.v1.endpoint.FieldList.fields', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=752,
  serialized_end=829,
)


_DATASCHEMA = _descriptor.Descriptor(
  name='DataSchema',
  full_name='yandex.cloud.datatransfer.v1.endpoint.DataSchema',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fields', full_name='yandex.cloud.datatransfer.v1.endpoint.DataSchema.fields', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='json_fields', full_name='yandex.cloud.datatransfer.v1.endpoint.DataSchema.json_fields', index=1,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='schema', full_name='yandex.cloud.datatransfer.v1.endpoint.DataSchema.schema',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=831,
  serialized_end=944,
)


_NOAUTH = _descriptor.Descriptor(
  name='NoAuth',
  full_name='yandex.cloud.datatransfer.v1.endpoint.NoAuth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=946,
  serialized_end=954,
)

_SECRET.oneofs_by_name['value'].fields.append(
  _SECRET.fields_by_name['raw'])
_SECRET.fields_by_name['raw'].containing_oneof = _SECRET.oneofs_by_name['value']
_COLSCHEMA.fields_by_name['type'].enum_type = _COLUMNTYPE
_TLSMODE.fields_by_name['disabled'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TLSMODE.fields_by_name['enabled'].message_type = _TLSCONFIG
_TLSMODE.oneofs_by_name['tls_mode'].fields.append(
  _TLSMODE.fields_by_name['disabled'])
_TLSMODE.fields_by_name['disabled'].containing_oneof = _TLSMODE.oneofs_by_name['tls_mode']
_TLSMODE.oneofs_by_name['tls_mode'].fields.append(
  _TLSMODE.fields_by_name['enabled'])
_TLSMODE.fields_by_name['enabled'].containing_oneof = _TLSMODE.oneofs_by_name['tls_mode']
_COLUMNVALUE.oneofs_by_name['value'].fields.append(
  _COLUMNVALUE.fields_by_name['string_value'])
_COLUMNVALUE.fields_by_name['string_value'].containing_oneof = _COLUMNVALUE.oneofs_by_name['value']
_FIELDLIST.fields_by_name['fields'].message_type = _COLSCHEMA
_DATASCHEMA.fields_by_name['fields'].message_type = _FIELDLIST
_DATASCHEMA.oneofs_by_name['schema'].fields.append(
  _DATASCHEMA.fields_by_name['fields'])
_DATASCHEMA.fields_by_name['fields'].containing_oneof = _DATASCHEMA.oneofs_by_name['schema']
_DATASCHEMA.oneofs_by_name['schema'].fields.append(
  _DATASCHEMA.fields_by_name['json_fields'])
_DATASCHEMA.fields_by_name['json_fields'].containing_oneof = _DATASCHEMA.oneofs_by_name['schema']
DESCRIPTOR.message_types_by_name['AltName'] = _ALTNAME
DESCRIPTOR.message_types_by_name['Secret'] = _SECRET
DESCRIPTOR.message_types_by_name['ColSchema'] = _COLSCHEMA
DESCRIPTOR.message_types_by_name['TLSMode'] = _TLSMODE
DESCRIPTOR.message_types_by_name['TLSConfig'] = _TLSCONFIG
DESCRIPTOR.message_types_by_name['ColumnValue'] = _COLUMNVALUE
DESCRIPTOR.message_types_by_name['DataTransformationOptions'] = _DATATRANSFORMATIONOPTIONS
DESCRIPTOR.message_types_by_name['FieldList'] = _FIELDLIST
DESCRIPTOR.message_types_by_name['DataSchema'] = _DATASCHEMA
DESCRIPTOR.message_types_by_name['NoAuth'] = _NOAUTH
DESCRIPTOR.enum_types_by_name['ObjectTransferStage'] = _OBJECTTRANSFERSTAGE
DESCRIPTOR.enum_types_by_name['CleanupPolicy'] = _CLEANUPPOLICY
DESCRIPTOR.enum_types_by_name['ColumnType'] = _COLUMNTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AltName = _reflection.GeneratedProtocolMessageType('AltName', (_message.Message,), {
  'DESCRIPTOR' : _ALTNAME,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.common_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.AltName)
  })
_sym_db.RegisterMessage(AltName)

Secret = _reflection.GeneratedProtocolMessageType('Secret', (_message.Message,), {
  'DESCRIPTOR' : _SECRET,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.common_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.Secret)
  })
_sym_db.RegisterMessage(Secret)

ColSchema = _reflection.GeneratedProtocolMessageType('ColSchema', (_message.Message,), {
  'DESCRIPTOR' : _COLSCHEMA,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.common_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.ColSchema)
  })
_sym_db.RegisterMessage(ColSchema)

TLSMode = _reflection.GeneratedProtocolMessageType('TLSMode', (_message.Message,), {
  'DESCRIPTOR' : _TLSMODE,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.common_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.TLSMode)
  })
_sym_db.RegisterMessage(TLSMode)

TLSConfig = _reflection.GeneratedProtocolMessageType('TLSConfig', (_message.Message,), {
  'DESCRIPTOR' : _TLSCONFIG,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.common_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.TLSConfig)
  })
_sym_db.RegisterMessage(TLSConfig)

ColumnValue = _reflection.GeneratedProtocolMessageType('ColumnValue', (_message.Message,), {
  'DESCRIPTOR' : _COLUMNVALUE,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.common_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.ColumnValue)
  })
_sym_db.RegisterMessage(ColumnValue)

DataTransformationOptions = _reflection.GeneratedProtocolMessageType('DataTransformationOptions', (_message.Message,), {
  'DESCRIPTOR' : _DATATRANSFORMATIONOPTIONS,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.common_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.DataTransformationOptions)
  })
_sym_db.RegisterMessage(DataTransformationOptions)

FieldList = _reflection.GeneratedProtocolMessageType('FieldList', (_message.Message,), {
  'DESCRIPTOR' : _FIELDLIST,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.common_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.FieldList)
  })
_sym_db.RegisterMessage(FieldList)

DataSchema = _reflection.GeneratedProtocolMessageType('DataSchema', (_message.Message,), {
  'DESCRIPTOR' : _DATASCHEMA,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.common_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.DataSchema)
  })
_sym_db.RegisterMessage(DataSchema)

NoAuth = _reflection.GeneratedProtocolMessageType('NoAuth', (_message.Message,), {
  'DESCRIPTOR' : _NOAUTH,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.common_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.NoAuth)
  })
_sym_db.RegisterMessage(NoAuth)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
