# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/logging/v1/sink.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/logging/v1/sink.proto',
  package='yandex.cloud.logging.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;logging',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"yandex/cloud/logging/v1/sink.proto\x12\x17yandex.cloud.logging.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xfd\x03\n\x04Sink\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x10\n\x08\x63loud_id\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x39\n\x06labels\x18\x07 \x03(\x0b\x32).yandex.cloud.logging.v1.Sink.LabelsEntry\x12\x1a\n\x12service_account_id\x18\x08 \x01(\t\x12\x30\n\x03yds\x18\t \x01(\x0b\x32!.yandex.cloud.logging.v1.Sink.YdsH\x00\x12.\n\x02s3\x18\n \x01(\x0b\x32 .yandex.cloud.logging.v1.Sink.S3H\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a%\n\x03Yds\x12\x1e\n\x0bstream_name\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05<=512\x1aT\n\x02S3\x12\x32\n\x06\x62ucket\x18\x01 \x01(\tB\"\xf2\xc7\x31\x1e[a-zA-Z0-9][-a-zA-Z0-9.]{2,62}\x12\x1a\n\x06prefix\x18\x02 \x01(\tB\n\x8a\xc8\x31\x06<=1024B\x0c\n\x04sink\x12\x04\xc0\xc1\x31\x01\x42\x62\n\x1byandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;loggingb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_SINK_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.logging.v1.Sink.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.logging.v1.Sink.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.logging.v1.Sink.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=453,
  serialized_end=498,
)

_SINK_YDS = _descriptor.Descriptor(
  name='Yds',
  full_name='yandex.cloud.logging.v1.Sink.Yds',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stream_name', full_name='yandex.cloud.logging.v1.Sink.Yds.stream_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=512', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=500,
  serialized_end=537,
)

_SINK_S3 = _descriptor.Descriptor(
  name='S3',
  full_name='yandex.cloud.logging.v1.Sink.S3',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucket', full_name='yandex.cloud.logging.v1.Sink.S3.bucket', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\036[a-zA-Z0-9][-a-zA-Z0-9.]{2,62}', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefix', full_name='yandex.cloud.logging.v1.Sink.S3.prefix', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1024', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=539,
  serialized_end=623,
)

_SINK = _descriptor.Descriptor(
  name='Sink',
  full_name='yandex.cloud.logging.v1.Sink',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.logging.v1.Sink.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.logging.v1.Sink.folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cloud_id', full_name='yandex.cloud.logging.v1.Sink.cloud_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.logging.v1.Sink.created_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.logging.v1.Sink.name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.logging.v1.Sink.description', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.logging.v1.Sink.labels', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.logging.v1.Sink.service_account_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yds', full_name='yandex.cloud.logging.v1.Sink.yds', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s3', full_name='yandex.cloud.logging.v1.Sink.s3', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SINK_LABELSENTRY, _SINK_YDS, _SINK_S3, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='sink', full_name='yandex.cloud.logging.v1.Sink.sink',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=128,
  serialized_end=637,
)

_SINK_LABELSENTRY.containing_type = _SINK
_SINK_YDS.containing_type = _SINK
_SINK_S3.containing_type = _SINK
_SINK.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SINK.fields_by_name['labels'].message_type = _SINK_LABELSENTRY
_SINK.fields_by_name['yds'].message_type = _SINK_YDS
_SINK.fields_by_name['s3'].message_type = _SINK_S3
_SINK.oneofs_by_name['sink'].fields.append(
  _SINK.fields_by_name['yds'])
_SINK.fields_by_name['yds'].containing_oneof = _SINK.oneofs_by_name['sink']
_SINK.oneofs_by_name['sink'].fields.append(
  _SINK.fields_by_name['s3'])
_SINK.fields_by_name['s3'].containing_oneof = _SINK.oneofs_by_name['sink']
DESCRIPTOR.message_types_by_name['Sink'] = _SINK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Sink = _reflection.GeneratedProtocolMessageType('Sink', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SINK_LABELSENTRY,
    '__module__' : 'yandex.cloud.logging.v1.sink_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.Sink.LabelsEntry)
    })
  ,

  'Yds' : _reflection.GeneratedProtocolMessageType('Yds', (_message.Message,), {
    'DESCRIPTOR' : _SINK_YDS,
    '__module__' : 'yandex.cloud.logging.v1.sink_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.Sink.Yds)
    })
  ,

  'S3' : _reflection.GeneratedProtocolMessageType('S3', (_message.Message,), {
    'DESCRIPTOR' : _SINK_S3,
    '__module__' : 'yandex.cloud.logging.v1.sink_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.Sink.S3)
    })
  ,
  'DESCRIPTOR' : _SINK,
  '__module__' : 'yandex.cloud.logging.v1.sink_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.Sink)
  })
_sym_db.RegisterMessage(Sink)
_sym_db.RegisterMessage(Sink.LabelsEntry)
_sym_db.RegisterMessage(Sink.Yds)
_sym_db.RegisterMessage(Sink.S3)


DESCRIPTOR._options = None
_SINK_LABELSENTRY._options = None
_SINK_YDS.fields_by_name['stream_name']._options = None
_SINK_S3.fields_by_name['bucket']._options = None
_SINK_S3.fields_by_name['prefix']._options = None
_SINK.oneofs_by_name['sink']._options = None
# @@protoc_insertion_point(module_scope)
